package Bio::Emboss::Methods;

# automatically generated by scripts/get_methods.pl on Tue Jul 18 16:23:55 2006

# This file defines the methods that are available for certain classes
# (i.e. certain EMBOSS types "AjP...")
#
# If an EMBOSS library function has an AjP... type as a first parameter,
# this function can be used as a method on that data type.
#
# This information is extracted from .xs files by "scripts/get_methods.pl"
#
# Bio::Emboss.pm can EXPORT several functions on request into the callers
# namespace. Lists of functions are created for some EXPORT tags.


*Bio::Emboss::3dVector::aj3dVectorDel = *Bio::Emboss::aj3dVectorDel;
*Bio::Emboss::3dVector::aj3dVectorCrossProduct = *Bio::Emboss::aj3dVectorCrossProduct;
*Bio::Emboss::3dVector::aj3dVectorBetweenPoints = *Bio::Emboss::aj3dVectorBetweenPoints;
*Bio::Emboss::3dVector::aj3dVectorLength = *Bio::Emboss::aj3dVectorLength;
*Bio::Emboss::3dVector::aj3dVectorAngle = *Bio::Emboss::aj3dVectorAngle;
*Bio::Emboss::3dVector::aj3dVectorDihedralAngle = *Bio::Emboss::aj3dVectorDihedralAngle;
*Bio::Emboss::3dVector::aj3dVectorDotProduct = *Bio::Emboss::aj3dVectorDotProduct;
*Bio::Emboss::3dVector::aj3dVectorSum = *Bio::Emboss::aj3dVectorSum;

*Bio::Emboss::Align::ajAlignDefine = *Bio::Emboss::ajAlignDefine;
*Bio::Emboss::Align::ajAlignDefineSS = *Bio::Emboss::ajAlignDefineSS;
*Bio::Emboss::Align::ajAlignDefineCC = *Bio::Emboss::ajAlignDefineCC;
*Bio::Emboss::Align::ajAlignDel = *Bio::Emboss::ajAlignDel;
*Bio::Emboss::Align::ajAlignReset = *Bio::Emboss::ajAlignReset;
*Bio::Emboss::Align::ajAlignOpen = *Bio::Emboss::ajAlignOpen;
*Bio::Emboss::Align::ajAlignGetFilename = *Bio::Emboss::ajAlignGetFilename;
*Bio::Emboss::Align::ajAlignGetFormat = *Bio::Emboss::ajAlignGetFormat;
*Bio::Emboss::Align::ajAlignValid = *Bio::Emboss::ajAlignValid;
*Bio::Emboss::Align::ajAlignWrite = *Bio::Emboss::ajAlignWrite;
*Bio::Emboss::Align::ajAlignClose = *Bio::Emboss::ajAlignClose;
*Bio::Emboss::Align::ajAlignWriteHeader = *Bio::Emboss::ajAlignWriteHeader;
*Bio::Emboss::Align::ajAlignWriteTail = *Bio::Emboss::ajAlignWriteTail;
*Bio::Emboss::Align::ajAlignSetHeader = *Bio::Emboss::ajAlignSetHeader;
*Bio::Emboss::Align::ajAlignSetHeaderC = *Bio::Emboss::ajAlignSetHeaderC;
*Bio::Emboss::Align::ajAlignSetHeaderApp = *Bio::Emboss::ajAlignSetHeaderApp;
*Bio::Emboss::Align::ajAlignSetTail = *Bio::Emboss::ajAlignSetTail;
*Bio::Emboss::Align::ajAlignSetTailC = *Bio::Emboss::ajAlignSetTailC;
*Bio::Emboss::Align::ajAlignSetTailApp = *Bio::Emboss::ajAlignSetTailApp;
*Bio::Emboss::Align::ajAlignSetSubTail = *Bio::Emboss::ajAlignSetSubTail;
*Bio::Emboss::Align::ajAlignSetSubTailC = *Bio::Emboss::ajAlignSetSubTailC;
*Bio::Emboss::Align::ajAlignSetSubTailApp = *Bio::Emboss::ajAlignSetSubTailApp;
*Bio::Emboss::Align::ajAlignSetSubHeader = *Bio::Emboss::ajAlignSetSubHeader;
*Bio::Emboss::Align::ajAlignSetSubHeaderC = *Bio::Emboss::ajAlignSetSubHeaderC;
*Bio::Emboss::Align::ajAlignSetSubHeaderApp = *Bio::Emboss::ajAlignSetSubHeaderApp;
*Bio::Emboss::Align::ajAlignSetSubHeaderPre = *Bio::Emboss::ajAlignSetSubHeaderPre;
*Bio::Emboss::Align::ajAlignSetMatrixName = *Bio::Emboss::ajAlignSetMatrixName;
*Bio::Emboss::Align::ajAlignSetMatrixNameC = *Bio::Emboss::ajAlignSetMatrixNameC;
*Bio::Emboss::Align::ajAlignSetMatrixInt = *Bio::Emboss::ajAlignSetMatrixInt;
*Bio::Emboss::Align::ajAlignSetMatrixFloat = *Bio::Emboss::ajAlignSetMatrixFloat;
*Bio::Emboss::Align::ajAlignSetGapI = *Bio::Emboss::ajAlignSetGapI;
*Bio::Emboss::Align::ajAlignSetGapR = *Bio::Emboss::ajAlignSetGapR;
*Bio::Emboss::Align::ajAlignSetScoreI = *Bio::Emboss::ajAlignSetScoreI;
*Bio::Emboss::Align::ajAlignSetScoreL = *Bio::Emboss::ajAlignSetScoreL;
*Bio::Emboss::Align::ajAlignSetScoreR = *Bio::Emboss::ajAlignSetScoreR;
*Bio::Emboss::Align::ajAlignSetStats = *Bio::Emboss::ajAlignSetStats;
*Bio::Emboss::Align::ajAlignSetSubStandard = *Bio::Emboss::ajAlignSetSubStandard;
*Bio::Emboss::Align::ajAlignSetType = *Bio::Emboss::ajAlignSetType;
*Bio::Emboss::Align::ajAlignSetExternal = *Bio::Emboss::ajAlignSetExternal;
*Bio::Emboss::Align::ajAlignSetRange = *Bio::Emboss::ajAlignSetRange;
*Bio::Emboss::Align::ajAlignSetSubRange = *Bio::Emboss::ajAlignSetSubRange;
*Bio::Emboss::Align::ajAlignTraceT = *Bio::Emboss::ajAlignTraceT;
*Bio::Emboss::Align::ajAlignTrace = *Bio::Emboss::ajAlignTrace;

*Bio::Emboss::Atom::ajAtomDel = *Bio::Emboss::ajAtomDel;
*Bio::Emboss::Atom::ajAtomCopy = *Bio::Emboss::ajAtomCopy;

*Bio::Emboss::BtHybrid::ajBtreeHybDel = *Bio::Emboss::ajBtreeHybDel;

*Bio::Emboss::BtId::ajBtreeIdDel = *Bio::Emboss::ajBtreeIdDel;

*Bio::Emboss::BtKeyWild::ajBtreeKeyWildDel = *Bio::Emboss::ajBtreeKeyWildDel;

*Bio::Emboss::BtPri::ajBtreePriDel = *Bio::Emboss::ajBtreePriDel;

*Bio::Emboss::BtWild::ajBtreeWildDel = *Bio::Emboss::ajBtreeWildDel;

*Bio::Emboss::Btcache::ajBtreeCacheDel = *Bio::Emboss::ajBtreeCacheDel;
*Bio::Emboss::Btcache::ajBtreeCacheRead = *Bio::Emboss::ajBtreeCacheRead;
*Bio::Emboss::Btcache::ajBtreeCacheSync = *Bio::Emboss::ajBtreeCacheSync;
*Bio::Emboss::Btcache::ajBtreeCacheWrite = *Bio::Emboss::ajBtreeCacheWrite;
*Bio::Emboss::Btcache::ajBtreeCreateRootNode = *Bio::Emboss::ajBtreeCreateRootNode;
*Bio::Emboss::Btcache::ajBtreeFindInsert = *Bio::Emboss::ajBtreeFindInsert;
*Bio::Emboss::Btcache::ajBtreeInsertId = *Bio::Emboss::ajBtreeInsertId;
*Bio::Emboss::Btcache::ajBtreeIdFromKey = *Bio::Emboss::ajBtreeIdFromKey;
*Bio::Emboss::Btcache::ajBtreeWriteParams = *Bio::Emboss::ajBtreeWriteParams;
*Bio::Emboss::Btcache::ajBtreeDeleteId = *Bio::Emboss::ajBtreeDeleteId;
*Bio::Emboss::Btcache::ajBtreeWildNew = *Bio::Emboss::ajBtreeWildNew;
*Bio::Emboss::Btcache::ajBtreeKeyWildNew = *Bio::Emboss::ajBtreeKeyWildNew;
*Bio::Emboss::Btcache::ajBtreeFindInsertW = *Bio::Emboss::ajBtreeFindInsertW;
*Bio::Emboss::Btcache::ajBtreeIdFromKeyW = *Bio::Emboss::ajBtreeIdFromKeyW;
*Bio::Emboss::Btcache::ajBtreeListFromKeyW = *Bio::Emboss::ajBtreeListFromKeyW;
*Bio::Emboss::Btcache::ajBtreeReplaceId = *Bio::Emboss::ajBtreeReplaceId;
*Bio::Emboss::Btcache::ajBtreeInsertDupId = *Bio::Emboss::ajBtreeInsertDupId;
*Bio::Emboss::Btcache::ajBtreeDupFromKey = *Bio::Emboss::ajBtreeDupFromKey;
*Bio::Emboss::Btcache::ajBtreeInsertKeyword = *Bio::Emboss::ajBtreeInsertKeyword;
*Bio::Emboss::Btcache::ajBtreePriFromKeyword = *Bio::Emboss::ajBtreePriFromKeyword;
*Bio::Emboss::Btcache::ajBtreeInsertSecId = *Bio::Emboss::ajBtreeInsertSecId;
*Bio::Emboss::Btcache::ajBtreeSecFromId = *Bio::Emboss::ajBtreeSecFromId;
*Bio::Emboss::Btcache::ajBtreeSecFindInsert = *Bio::Emboss::ajBtreeSecFindInsert;
*Bio::Emboss::Btcache::ajBtreeLockTest = *Bio::Emboss::ajBtreeLockTest;
*Bio::Emboss::Btcache::ajBtreeSecLeafList = *Bio::Emboss::ajBtreeSecLeafList;
*Bio::Emboss::Btcache::ajBtreeVerifyId = *Bio::Emboss::ajBtreeVerifyId;
*Bio::Emboss::Btcache::ajBtreeIdFromKeywordW = *Bio::Emboss::ajBtreeIdFromKeywordW;
*Bio::Emboss::Btcache::ajBtreeListFromKeywordW = *Bio::Emboss::ajBtreeListFromKeywordW;
*Bio::Emboss::Btcache::ajBtreeHybFindInsert = *Bio::Emboss::ajBtreeHybFindInsert;
*Bio::Emboss::Btcache::ajBtreeHybInsertId = *Bio::Emboss::ajBtreeHybInsertId;
*Bio::Emboss::Btcache::ajBtreeNumFindInsert = *Bio::Emboss::ajBtreeNumFindInsert;
*Bio::Emboss::Btcache::ajBtreeInsertNum = *Bio::Emboss::ajBtreeInsertNum;
*Bio::Emboss::Btcache::ajBtreeFreePriArray = *Bio::Emboss::ajBtreeFreePriArray;
*Bio::Emboss::Btcache::ajBtreeFreeSecArray = *Bio::Emboss::ajBtreeFreeSecArray;
*Bio::Emboss::Btcache::ajBtreeHybLeafList = *Bio::Emboss::ajBtreeHybLeafList;

*Bio::Emboss::Cath::ajCathDel = *Bio::Emboss::ajCathDel;
*Bio::Emboss::Cath::ajCathCopy = *Bio::Emboss::ajCathCopy;
*Bio::Emboss::Cath::ajCathArrFindPdbid = *Bio::Emboss::ajCathArrFindPdbid;

*Bio::Emboss::Chain::ajChainDel = *Bio::Emboss::ajChainDel;

*Bio::Emboss::Char::ajChararrDel = *Bio::Emboss::ajChararrDel;
*Bio::Emboss::Char::ajChararrGet = *Bio::Emboss::ajChararrGet;
*Bio::Emboss::Char::ajChararrPut = *Bio::Emboss::ajChararrPut;
*Bio::Emboss::Char::ajChararrChararr = *Bio::Emboss::ajChararrChararr;

*Bio::Emboss::Cmap::ajCmapDel = *Bio::Emboss::ajCmapDel;

*Bio::Emboss::Cod::ajCodDup = *Bio::Emboss::ajCodDup;
*Bio::Emboss::Cod::ajCodDel = *Bio::Emboss::ajCodDel;
*Bio::Emboss::Cod::ajCodCalcGribskov = *Bio::Emboss::ajCodCalcGribskov;
*Bio::Emboss::Cod::ajCodCalcNc = *Bio::Emboss::ajCodCalcNc;
*Bio::Emboss::Cod::ajCodCalculateUsage = *Bio::Emboss::ajCodCalculateUsage;
*Bio::Emboss::Cod::ajCodClear = *Bio::Emboss::ajCodClear;
*Bio::Emboss::Cod::ajCodClearData = *Bio::Emboss::ajCodClearData;
*Bio::Emboss::Cod::ajCodCountTriplets = *Bio::Emboss::ajCodCountTriplets;
*Bio::Emboss::Cod::ajCodRead = *Bio::Emboss::ajCodRead;
*Bio::Emboss::Cod::ajCodSetBacktranslate = *Bio::Emboss::ajCodSetBacktranslate;
*Bio::Emboss::Cod::ajCodWriteOut = *Bio::Emboss::ajCodWriteOut;
*Bio::Emboss::Cod::ajCodWrite = *Bio::Emboss::ajCodWrite;
*Bio::Emboss::Cod::ajCodCalcCai = *Bio::Emboss::ajCodCalcCai;
*Bio::Emboss::Cod::ajCodCaiW = *Bio::Emboss::ajCodCaiW;
*Bio::Emboss::Cod::ajCodCai = *Bio::Emboss::ajCodCai;
*Bio::Emboss::Cod::ajCodGetName = *Bio::Emboss::ajCodGetName;
*Bio::Emboss::Cod::ajCodGetNameC = *Bio::Emboss::ajCodGetNameC;
*Bio::Emboss::Cod::ajCodGetDesc = *Bio::Emboss::ajCodGetDesc;
*Bio::Emboss::Cod::ajCodGetDescC = *Bio::Emboss::ajCodGetDescC;
*Bio::Emboss::Cod::ajCodGetSpecies = *Bio::Emboss::ajCodGetSpecies;
*Bio::Emboss::Cod::ajCodGetSpeciesC = *Bio::Emboss::ajCodGetSpeciesC;
*Bio::Emboss::Cod::ajCodGetDivision = *Bio::Emboss::ajCodGetDivision;
*Bio::Emboss::Cod::ajCodGetDivisionC = *Bio::Emboss::ajCodGetDivisionC;
*Bio::Emboss::Cod::ajCodGetRelease = *Bio::Emboss::ajCodGetRelease;
*Bio::Emboss::Cod::ajCodGetReleaseC = *Bio::Emboss::ajCodGetReleaseC;
*Bio::Emboss::Cod::ajCodGetNumcodon = *Bio::Emboss::ajCodGetNumcodon;
*Bio::Emboss::Cod::ajCodGetNumcds = *Bio::Emboss::ajCodGetNumcds;
*Bio::Emboss::Cod::ajCodGetCode = *Bio::Emboss::ajCodGetCode;
*Bio::Emboss::Cod::ajCodAssName = *Bio::Emboss::ajCodAssName;
*Bio::Emboss::Cod::ajCodAssNameC = *Bio::Emboss::ajCodAssNameC;
*Bio::Emboss::Cod::ajCodAssDesc = *Bio::Emboss::ajCodAssDesc;
*Bio::Emboss::Cod::ajCodAssDescC = *Bio::Emboss::ajCodAssDescC;
*Bio::Emboss::Cod::ajCodAssSpecies = *Bio::Emboss::ajCodAssSpecies;
*Bio::Emboss::Cod::ajCodAssSpeciesC = *Bio::Emboss::ajCodAssSpeciesC;
*Bio::Emboss::Cod::ajCodAssRelease = *Bio::Emboss::ajCodAssRelease;
*Bio::Emboss::Cod::ajCodAssReleaseC = *Bio::Emboss::ajCodAssReleaseC;
*Bio::Emboss::Cod::ajCodAssDivision = *Bio::Emboss::ajCodAssDivision;
*Bio::Emboss::Cod::ajCodAssDivisionC = *Bio::Emboss::ajCodAssDivisionC;
*Bio::Emboss::Cod::ajCodAssNumcodon = *Bio::Emboss::ajCodAssNumcodon;
*Bio::Emboss::Cod::ajCodAssNumcds = *Bio::Emboss::ajCodAssNumcds;
*Bio::Emboss::Cod::ajCodAssCode = *Bio::Emboss::ajCodAssCode;
*Bio::Emboss::Cod::ajCodGetCodonlist = *Bio::Emboss::ajCodGetCodonlist;

*Bio::Emboss::Dir::ajDirName = *Bio::Emboss::ajDirName;
*Bio::Emboss::Dir::ajDirExt = *Bio::Emboss::ajDirExt;
*Bio::Emboss::Dir::ajFileNewOutDir = *Bio::Emboss::ajFileNewOutDir;
*Bio::Emboss::Dir::ajDirDel = *Bio::Emboss::ajDirDel;
*Bio::Emboss::Dir::ajDiroutDel = *Bio::Emboss::ajDiroutDel;
*Bio::Emboss::Dir::ajFileNewDirF = *Bio::Emboss::ajFileNewDirF;

*Bio::Emboss::Domain::ajDomainDel = *Bio::Emboss::ajDomainDel;
*Bio::Emboss::Domain::ajDomainCopy = *Bio::Emboss::ajDomainCopy;
*Bio::Emboss::Domain::ajDomainGetId = *Bio::Emboss::ajDomainGetId;
*Bio::Emboss::Domain::ajDomainGetSeqPdb = *Bio::Emboss::ajDomainGetSeqPdb;
*Bio::Emboss::Domain::ajDomainGetSeqSpr = *Bio::Emboss::ajDomainGetSeqSpr;
*Bio::Emboss::Domain::ajDomainGetPdb = *Bio::Emboss::ajDomainGetPdb;
*Bio::Emboss::Domain::ajDomainGetAcc = *Bio::Emboss::ajDomainGetAcc;
*Bio::Emboss::Domain::ajDomainGetSpr = *Bio::Emboss::ajDomainGetSpr;
*Bio::Emboss::Domain::ajDomainGetN = *Bio::Emboss::ajDomainGetN;

*Bio::Emboss::Double::ajDoubleDel = *Bio::Emboss::ajDoubleDel;
*Bio::Emboss::Double::ajDoubleGet = *Bio::Emboss::ajDoubleGet;
*Bio::Emboss::Double::ajDoublePut = *Bio::Emboss::ajDoublePut;
*Bio::Emboss::Double::ajDoubleDouble = *Bio::Emboss::ajDoubleDouble;
*Bio::Emboss::Double::ajDoubleLen = *Bio::Emboss::ajDoubleLen;

*Bio::Emboss::Double2d::ajDouble2dDel = *Bio::Emboss::ajDouble2dDel;
*Bio::Emboss::Double2d::ajDouble2dGet = *Bio::Emboss::ajDouble2dGet;
*Bio::Emboss::Double2d::ajDouble2dPut = *Bio::Emboss::ajDouble2dPut;
*Bio::Emboss::Double2d::ajDouble2dLen = *Bio::Emboss::ajDouble2dLen;
*Bio::Emboss::Double2d::ajDouble2dDouble = *Bio::Emboss::ajDouble2dDouble;

*Bio::Emboss::Double3d::ajDouble3dDel = *Bio::Emboss::ajDouble3dDel;
*Bio::Emboss::Double3d::ajDouble3dGet = *Bio::Emboss::ajDouble3dGet;
*Bio::Emboss::Double3d::ajDouble3dPut = *Bio::Emboss::ajDouble3dPut;
*Bio::Emboss::Double3d::ajDouble3dLen = *Bio::Emboss::ajDouble3dLen;
*Bio::Emboss::Double3d::ajDouble3dDouble = *Bio::Emboss::ajDouble3dDouble;

*Bio::Emboss::FeattabIn::ajFeatRead = *Bio::Emboss::ajFeatRead;
*Bio::Emboss::FeattabIn::ajFeattabInDel = *Bio::Emboss::ajFeattabInDel;
*Bio::Emboss::FeattabIn::ajFeattabInClear = *Bio::Emboss::ajFeattabInClear;
*Bio::Emboss::FeattabIn::ajFeattabInSetType = *Bio::Emboss::ajFeattabInSetType;
*Bio::Emboss::FeattabIn::ajFeattabInSetTypeC = *Bio::Emboss::ajFeattabInSetTypeC;
*Bio::Emboss::FeattabIn::ajFeatUfoRead = *Bio::Emboss::ajFeatUfoRead;

*Bio::Emboss::FeattabOut::ajFeattabOutOpen = *Bio::Emboss::ajFeattabOutOpen;
*Bio::Emboss::FeattabOut::ajFeattabOutFile = *Bio::Emboss::ajFeattabOutFile;
*Bio::Emboss::FeattabOut::ajFeattabOutFilename = *Bio::Emboss::ajFeattabOutFilename;
*Bio::Emboss::FeattabOut::ajFeattabOutIsOpen = *Bio::Emboss::ajFeattabOutIsOpen;
*Bio::Emboss::FeattabOut::ajFeattabOutIsLocal = *Bio::Emboss::ajFeattabOutIsLocal;
*Bio::Emboss::FeattabOut::ajFeattabOutSet = *Bio::Emboss::ajFeattabOutSet;
*Bio::Emboss::FeattabOut::ajFeattabOutSetBasename = *Bio::Emboss::ajFeattabOutSetBasename;
*Bio::Emboss::FeattabOut::ajFeatWrite = *Bio::Emboss::ajFeatWrite;
*Bio::Emboss::FeattabOut::ajFeattabOutSetType = *Bio::Emboss::ajFeattabOutSetType;
*Bio::Emboss::FeattabOut::ajFeattabOutSetTypeC = *Bio::Emboss::ajFeattabOutSetTypeC;
*Bio::Emboss::FeattabOut::ajFeattabOutDel = *Bio::Emboss::ajFeattabOutDel;

*Bio::Emboss::Feattable::ajFeatNew = *Bio::Emboss::ajFeatNew;
*Bio::Emboss::Feattable::ajFeatNewII = *Bio::Emboss::ajFeatNewII;
*Bio::Emboss::Feattable::ajFeatNewIIRev = *Bio::Emboss::ajFeatNewIIRev;
*Bio::Emboss::Feattable::ajFeatNewProt = *Bio::Emboss::ajFeatNewProt;
*Bio::Emboss::Feattable::ajFeattableDel = *Bio::Emboss::ajFeattableDel;
*Bio::Emboss::Feattable::ajFeatUfoWrite = *Bio::Emboss::ajFeatUfoWrite;
*Bio::Emboss::Feattable::ajFeattableWrite = *Bio::Emboss::ajFeattableWrite;
*Bio::Emboss::Feattable::ajFeatSortByType = *Bio::Emboss::ajFeatSortByType;
*Bio::Emboss::Feattable::ajFeatSortByStart = *Bio::Emboss::ajFeatSortByStart;
*Bio::Emboss::Feattable::ajFeatSortByEnd = *Bio::Emboss::ajFeatSortByEnd;
*Bio::Emboss::Feattable::ajFeattableAdd = *Bio::Emboss::ajFeattableAdd;
*Bio::Emboss::Feattable::ajFeattableClear = *Bio::Emboss::ajFeattableClear;
*Bio::Emboss::Feattable::ajFeattableWriteGff = *Bio::Emboss::ajFeattableWriteGff;
*Bio::Emboss::Feattable::ajFeattableWriteDdbj = *Bio::Emboss::ajFeattableWriteDdbj;
*Bio::Emboss::Feattable::ajFeattableWriteEmbl = *Bio::Emboss::ajFeattableWriteEmbl;
*Bio::Emboss::Feattable::ajFeattableWriteGenbank = *Bio::Emboss::ajFeattableWriteGenbank;
*Bio::Emboss::Feattable::ajFeattableWriteSwiss = *Bio::Emboss::ajFeattableWriteSwiss;
*Bio::Emboss::Feattable::ajFeattableWritePir = *Bio::Emboss::ajFeattableWritePir;
*Bio::Emboss::Feattable::ajFeattableGetName = *Bio::Emboss::ajFeattableGetName;
*Bio::Emboss::Feattable::ajFeattableGetTypeC = *Bio::Emboss::ajFeattableGetTypeC;
*Bio::Emboss::Feattable::ajFeattableGetTypeS = *Bio::Emboss::ajFeattableGetTypeS;
*Bio::Emboss::Feattable::ajFeattableIsNuc = *Bio::Emboss::ajFeattableIsNuc;
*Bio::Emboss::Feattable::ajFeattableIsProt = *Bio::Emboss::ajFeattableIsProt;
*Bio::Emboss::Feattable::ajFeattableBegin = *Bio::Emboss::ajFeattableBegin;
*Bio::Emboss::Feattable::ajFeattableEnd = *Bio::Emboss::ajFeattableEnd;
*Bio::Emboss::Feattable::ajFeattableLen = *Bio::Emboss::ajFeattableLen;
*Bio::Emboss::Feattable::ajFeattableSize = *Bio::Emboss::ajFeattableSize;
*Bio::Emboss::Feattable::ajFeattableSetNuc = *Bio::Emboss::ajFeattableSetNuc;
*Bio::Emboss::Feattable::ajFeattableSetProt = *Bio::Emboss::ajFeattableSetProt;
*Bio::Emboss::Feattable::ajFeattableReverse = *Bio::Emboss::ajFeattableReverse;
*Bio::Emboss::Feattable::ajFeattableSetRange = *Bio::Emboss::ajFeattableSetRange;
*Bio::Emboss::Feattable::ajFeattableCopy = *Bio::Emboss::ajFeattableCopy;
*Bio::Emboss::Feattable::ajFeattableTrace = *Bio::Emboss::ajFeattableTrace;
*Bio::Emboss::Feattable::ajFeattablePos = *Bio::Emboss::ajFeattablePos;
*Bio::Emboss::Feattable::ajFeattablePosI = *Bio::Emboss::ajFeattablePosI;
*Bio::Emboss::Feattable::ajFeattableTrimOff = *Bio::Emboss::ajFeattableTrimOff;
*Bio::Emboss::Feattable::ajFeatDefName = *Bio::Emboss::ajFeatDefName;
*Bio::Emboss::Feattable::ajFeattableSetDna = *Bio::Emboss::ajFeattableSetDna;

*Bio::Emboss::Feature::ajFeatDel = *Bio::Emboss::ajFeatDel;
*Bio::Emboss::Feature::ajFeatGetNote = *Bio::Emboss::ajFeatGetNote;
*Bio::Emboss::Feature::ajFeatGetNoteC = *Bio::Emboss::ajFeatGetNoteC;
*Bio::Emboss::Feature::ajFeatGetNoteCI = *Bio::Emboss::ajFeatGetNoteCI;
*Bio::Emboss::Feature::ajFeatGetNoteI = *Bio::Emboss::ajFeatGetNoteI;
*Bio::Emboss::Feature::ajFeatGetTag = *Bio::Emboss::ajFeatGetTag;
*Bio::Emboss::Feature::ajFeatGetType = *Bio::Emboss::ajFeatGetType;
*Bio::Emboss::Feature::ajFeatGetSource = *Bio::Emboss::ajFeatGetSource;
*Bio::Emboss::Feature::ajFeatGetStart = *Bio::Emboss::ajFeatGetStart;
*Bio::Emboss::Feature::ajFeatGetStrand = *Bio::Emboss::ajFeatGetStrand;
*Bio::Emboss::Feature::ajFeatGetEnd = *Bio::Emboss::ajFeatGetEnd;
*Bio::Emboss::Feature::ajFeatGetLength = *Bio::Emboss::ajFeatGetLength;
*Bio::Emboss::Feature::ajFeatGetScore = *Bio::Emboss::ajFeatGetScore;
*Bio::Emboss::Feature::ajFeatGetForward = *Bio::Emboss::ajFeatGetForward;
*Bio::Emboss::Feature::ajFeatGetFrame = *Bio::Emboss::ajFeatGetFrame;
*Bio::Emboss::Feature::ajFeatSetDescApp = *Bio::Emboss::ajFeatSetDescApp;
*Bio::Emboss::Feature::ajFeatSetDesc = *Bio::Emboss::ajFeatSetDesc;
*Bio::Emboss::Feature::ajFeatSetScore = *Bio::Emboss::ajFeatSetScore;
*Bio::Emboss::Feature::ajFeatSetStrand = *Bio::Emboss::ajFeatSetStrand;
*Bio::Emboss::Feature::ajFeatTagSetC = *Bio::Emboss::ajFeatTagSetC;
*Bio::Emboss::Feature::ajFeatTagSet = *Bio::Emboss::ajFeatTagSet;
*Bio::Emboss::Feature::ajFeatTagAddCC = *Bio::Emboss::ajFeatTagAddCC;
*Bio::Emboss::Feature::ajFeatTagAddC = *Bio::Emboss::ajFeatTagAddC;
*Bio::Emboss::Feature::ajFeatTagAdd = *Bio::Emboss::ajFeatTagAdd;
*Bio::Emboss::Feature::ajFeatReverse = *Bio::Emboss::ajFeatReverse;
*Bio::Emboss::Feature::ajFeatCopy = *Bio::Emboss::ajFeatCopy;
*Bio::Emboss::Feature::ajFeatTrace = *Bio::Emboss::ajFeatTrace;
*Bio::Emboss::Feature::ajFeatTagTrace = *Bio::Emboss::ajFeatTagTrace;
*Bio::Emboss::Feature::ajFeatTagIter = *Bio::Emboss::ajFeatTagIter;
*Bio::Emboss::Feature::ajFeatIsLocal = *Bio::Emboss::ajFeatIsLocal;
*Bio::Emboss::Feature::ajFeatIsLocalRange = *Bio::Emboss::ajFeatIsLocalRange;
*Bio::Emboss::Feature::ajFeatIsChild = *Bio::Emboss::ajFeatIsChild;
*Bio::Emboss::Feature::ajFeatIsMultiple = *Bio::Emboss::ajFeatIsMultiple;
*Bio::Emboss::Feature::ajFeatIsCompMult = *Bio::Emboss::ajFeatIsCompMult;
*Bio::Emboss::Feature::ajFeatTrimOffRange = *Bio::Emboss::ajFeatTrimOffRange;

*Bio::Emboss::File::ajAcdPrintAppl = *Bio::Emboss::ajAcdPrintAppl;
*Bio::Emboss::File::ajAcdPrintQual = *Bio::Emboss::ajAcdPrintQual;
*Bio::Emboss::File::ajAcdPrintType = *Bio::Emboss::ajAcdPrintType;
*Bio::Emboss::File::ajAlignPrintFormat = *Bio::Emboss::ajAlignPrintFormat;
*Bio::Emboss::File::ajCodPrintFormat = *Bio::Emboss::ajCodPrintFormat;
*Bio::Emboss::File::ajDmxScopalgRead = *Bio::Emboss::ajDmxScopalgRead;
*Bio::Emboss::File::ajDmxScophitsWrite = *Bio::Emboss::ajDmxScophitsWrite;
*Bio::Emboss::File::ajDmxScophitsWriteFasta = *Bio::Emboss::ajDmxScophitsWriteFasta;
*Bio::Emboss::File::ajDmxScophitReadFasta = *Bio::Emboss::ajDmxScophitReadFasta;
*Bio::Emboss::File::ajCathReadAllNew = *Bio::Emboss::ajCathReadAllNew;
*Bio::Emboss::File::ajCathReadAllRawNew = *Bio::Emboss::ajCathReadAllRawNew;
*Bio::Emboss::File::ajCathReadCNew = *Bio::Emboss::ajCathReadCNew;
*Bio::Emboss::File::ajCathReadNew = *Bio::Emboss::ajCathReadNew;
*Bio::Emboss::File::ajDomainReadAllNew = *Bio::Emboss::ajDomainReadAllNew;
*Bio::Emboss::File::ajScopReadAllNew = *Bio::Emboss::ajScopReadAllNew;
*Bio::Emboss::File::ajScopReadAllRawNew = *Bio::Emboss::ajScopReadAllRawNew;
*Bio::Emboss::File::ajDomainReadNew = *Bio::Emboss::ajDomainReadNew;
*Bio::Emboss::File::ajScopReadNew = *Bio::Emboss::ajScopReadNew;
*Bio::Emboss::File::ajDomainReadCNew = *Bio::Emboss::ajDomainReadCNew;
*Bio::Emboss::File::ajScopReadCNew = *Bio::Emboss::ajScopReadCNew;
*Bio::Emboss::File::ajPdbWriteDomain = *Bio::Emboss::ajPdbWriteDomain;
*Bio::Emboss::File::ajCathWrite = *Bio::Emboss::ajCathWrite;
*Bio::Emboss::File::ajDomainWrite = *Bio::Emboss::ajDomainWrite;
*Bio::Emboss::File::ajScopWrite = *Bio::Emboss::ajScopWrite;
*Bio::Emboss::File::ajDomainDCFType = *Bio::Emboss::ajDomainDCFType;
*Bio::Emboss::File::ajFeatPrintFormat = *Bio::Emboss::ajFeatPrintFormat;
*Bio::Emboss::File::ajFileClose = *Bio::Emboss::ajFileClose;
*Bio::Emboss::File::ajFileOutClose = *Bio::Emboss::ajFileOutClose;
*Bio::Emboss::File::ajFileSeek = *Bio::Emboss::ajFileSeek;
*Bio::Emboss::File::ajFileReadUint = *Bio::Emboss::ajFileReadUint;
*Bio::Emboss::File::ajFileWrite = *Bio::Emboss::ajFileWrite;
*Bio::Emboss::File::ajFileNext = *Bio::Emboss::ajFileNext;
*Bio::Emboss::File::ajFileReopen = *Bio::Emboss::ajFileReopen;
*Bio::Emboss::File::ajFileReadLine = *Bio::Emboss::ajFileReadLine;
*Bio::Emboss::File::ajFileGetsTrimL = *Bio::Emboss::ajFileGetsTrimL;
*Bio::Emboss::File::ajFileGetsTrim = *Bio::Emboss::ajFileGetsTrim;
*Bio::Emboss::File::ajFileGets = *Bio::Emboss::ajFileGets;
*Bio::Emboss::File::ajFileGetsL = *Bio::Emboss::ajFileGetsL;
*Bio::Emboss::File::ajFileUnbuffer = *Bio::Emboss::ajFileUnbuffer;
*Bio::Emboss::File::ajFileReadAppend = *Bio::Emboss::ajFileReadAppend;
*Bio::Emboss::File::ajFileOutHeader = *Bio::Emboss::ajFileOutHeader;
*Bio::Emboss::File::ajFileTrace = *Bio::Emboss::ajFileTrace;
*Bio::Emboss::File::ajFileName = *Bio::Emboss::ajFileName;
*Bio::Emboss::File::ajFileNameS = *Bio::Emboss::ajFileNameS;
*Bio::Emboss::File::ajFileGetApp = *Bio::Emboss::ajFileGetApp;
*Bio::Emboss::File::ajFileGetName = *Bio::Emboss::ajFileGetName;
*Bio::Emboss::File::ajFileTell = *Bio::Emboss::ajFileTell;
*Bio::Emboss::File::ajFileStdout = *Bio::Emboss::ajFileStdout;
*Bio::Emboss::File::ajFileStderr = *Bio::Emboss::ajFileStderr;
*Bio::Emboss::File::ajFileStdin = *Bio::Emboss::ajFileStdin;
*Bio::Emboss::File::ajFileFp = *Bio::Emboss::ajFileFp;
*Bio::Emboss::File::ajFileEof = *Bio::Emboss::ajFileEof;
*Bio::Emboss::File::ajFileBuffNewFile = *Bio::Emboss::ajFileBuffNewFile;
*Bio::Emboss::File::ajFileWriteByte = *Bio::Emboss::ajFileWriteByte;
*Bio::Emboss::File::ajFileWriteChar = *Bio::Emboss::ajFileWriteChar;
*Bio::Emboss::File::ajFileWriteInt2 = *Bio::Emboss::ajFileWriteInt2;
*Bio::Emboss::File::ajFileWriteInt4 = *Bio::Emboss::ajFileWriteInt4;
*Bio::Emboss::File::ajFileWriteInt8 = *Bio::Emboss::ajFileWriteInt8;
*Bio::Emboss::File::ajFileWriteStr = *Bio::Emboss::ajFileWriteStr;
*Bio::Emboss::File::ajFmtPrintF = *Bio::Emboss::ajFmtPrintF;
*Bio::Emboss::File::ajFmtPrintSplit = *Bio::Emboss::ajFmtPrintSplit;
*Bio::Emboss::File::ajFmtScanF = *Bio::Emboss::ajFmtScanF;
*Bio::Emboss::File::ajGraphPrintType = *Bio::Emboss::ajGraphPrintType;
*Bio::Emboss::File::ajNamPrintDbAttr = *Bio::Emboss::ajNamPrintDbAttr;
*Bio::Emboss::File::ajNamPrintRsAttr = *Bio::Emboss::ajNamPrintRsAttr;
*Bio::Emboss::File::ajPdbtospReadAllRawNew = *Bio::Emboss::ajPdbtospReadAllRawNew;
*Bio::Emboss::File::ajPdbtospReadNew = *Bio::Emboss::ajPdbtospReadNew;
*Bio::Emboss::File::ajPdbtospReadCNew = *Bio::Emboss::ajPdbtospReadCNew;
*Bio::Emboss::File::ajPdbtospReadAllNew = *Bio::Emboss::ajPdbtospReadAllNew;
*Bio::Emboss::File::ajCmapReadINew = *Bio::Emboss::ajCmapReadINew;
*Bio::Emboss::File::ajCmapReadCNew = *Bio::Emboss::ajCmapReadCNew;
*Bio::Emboss::File::ajCmapReadAllNew = *Bio::Emboss::ajCmapReadAllNew;
*Bio::Emboss::File::ajCmapReadNew = *Bio::Emboss::ajCmapReadNew;
*Bio::Emboss::File::ajVdwallReadNew = *Bio::Emboss::ajVdwallReadNew;
*Bio::Emboss::File::ajHetReadNew = *Bio::Emboss::ajHetReadNew;
*Bio::Emboss::File::ajHetReadRawNew = *Bio::Emboss::ajHetReadRawNew;
*Bio::Emboss::File::ajPdbReadFirstModelNew = *Bio::Emboss::ajPdbReadFirstModelNew;
*Bio::Emboss::File::ajPdbReadAllModelsNew = *Bio::Emboss::ajPdbReadAllModelsNew;
*Bio::Emboss::File::ajPdbReadNew = *Bio::Emboss::ajPdbReadNew;
*Bio::Emboss::File::ajPdbReadoldNew = *Bio::Emboss::ajPdbReadoldNew;
*Bio::Emboss::File::ajPdbReadoldFirstModelNew = *Bio::Emboss::ajPdbReadoldFirstModelNew;
*Bio::Emboss::File::ajPdbWriteAll = *Bio::Emboss::ajPdbWriteAll;
*Bio::Emboss::File::ajPdbWriteSegment = *Bio::Emboss::ajPdbWriteSegment;
*Bio::Emboss::File::ajHetWrite = *Bio::Emboss::ajHetWrite;
*Bio::Emboss::File::ajPdbtospWrite = *Bio::Emboss::ajPdbtospWrite;
*Bio::Emboss::File::ajCmapWrite = *Bio::Emboss::ajCmapWrite;
*Bio::Emboss::File::ajReportPrintFormat = *Bio::Emboss::ajReportPrintFormat;
*Bio::Emboss::File::ajSeqoutNewF = *Bio::Emboss::ajSeqoutNewF;
*Bio::Emboss::File::ajSeqABITest = *Bio::Emboss::ajSeqABITest;
*Bio::Emboss::File::ajSeqABIReadSeq = *Bio::Emboss::ajSeqABIReadSeq;
*Bio::Emboss::File::ajSeqABIMachineName = *Bio::Emboss::ajSeqABIMachineName;
*Bio::Emboss::File::ajSeqABIGetNData = *Bio::Emboss::ajSeqABIGetNData;
*Bio::Emboss::File::ajSeqABIGetNBase = *Bio::Emboss::ajSeqABIGetNBase;
*Bio::Emboss::File::ajSeqABIGetData = *Bio::Emboss::ajSeqABIGetData;
*Bio::Emboss::File::ajSeqABIGetBasePosition = *Bio::Emboss::ajSeqABIGetBasePosition;
*Bio::Emboss::File::ajSeqABIGetSignal = *Bio::Emboss::ajSeqABIGetSignal;
*Bio::Emboss::File::ajSeqABIGetBaseSpace = *Bio::Emboss::ajSeqABIGetBaseSpace;
*Bio::Emboss::File::ajSeqABIGetBaseOffset = *Bio::Emboss::ajSeqABIGetBaseOffset;
*Bio::Emboss::File::ajSeqABIGetBasePosOffset = *Bio::Emboss::ajSeqABIGetBasePosOffset;
*Bio::Emboss::File::ajSeqABIGetFWO = *Bio::Emboss::ajSeqABIGetFWO;
*Bio::Emboss::File::ajSeqABIGetPrimerOffset = *Bio::Emboss::ajSeqABIGetPrimerOffset;
*Bio::Emboss::File::ajSeqABIGetPrimerPosition = *Bio::Emboss::ajSeqABIGetPrimerPosition;
*Bio::Emboss::File::ajSeqABIGetTraceOffset = *Bio::Emboss::ajSeqABIGetTraceOffset;
*Bio::Emboss::File::ajSeqABISampleName = *Bio::Emboss::ajSeqABISampleName;
*Bio::Emboss::File::ajSeqPrintAccess = *Bio::Emboss::ajSeqPrintAccess;
*Bio::Emboss::File::ajSeqPrintInFormat = *Bio::Emboss::ajSeqPrintInFormat;
*Bio::Emboss::File::ajSeqPrintType = *Bio::Emboss::ajSeqPrintType;
*Bio::Emboss::File::ajSeqPrintOutFormat = *Bio::Emboss::ajSeqPrintOutFormat;
*Bio::Emboss::File::ajSeqWriteXyz = *Bio::Emboss::ajSeqWriteXyz;
*Bio::Emboss::File::ajSssWriteXyz = *Bio::Emboss::ajSssWriteXyz;

*Bio::Emboss::FileBuff::ajFileBuffSetFile = *Bio::Emboss::ajFileBuffSetFile;
*Bio::Emboss::FileBuff::ajFileBuffDel = *Bio::Emboss::ajFileBuffDel;
*Bio::Emboss::FileBuff::ajFileBuffGet = *Bio::Emboss::ajFileBuffGet;
*Bio::Emboss::FileBuff::ajFileBuffGetStore = *Bio::Emboss::ajFileBuffGetStore;
*Bio::Emboss::FileBuff::ajFileBuffGetStoreL = *Bio::Emboss::ajFileBuffGetStoreL;
*Bio::Emboss::FileBuff::ajFileBuffGetL = *Bio::Emboss::ajFileBuffGetL;
*Bio::Emboss::FileBuff::ajFileBuffStripHtml = *Bio::Emboss::ajFileBuffStripHtml;
*Bio::Emboss::FileBuff::ajFileBuffLoadC = *Bio::Emboss::ajFileBuffLoadC;
*Bio::Emboss::FileBuff::ajFileBuffLoadS = *Bio::Emboss::ajFileBuffLoadS;
*Bio::Emboss::FileBuff::ajFileBuffEof = *Bio::Emboss::ajFileBuffEof;
*Bio::Emboss::FileBuff::ajFileBuffEnd = *Bio::Emboss::ajFileBuffEnd;
*Bio::Emboss::FileBuff::ajFileBuffReset = *Bio::Emboss::ajFileBuffReset;
*Bio::Emboss::FileBuff::ajFileBuffResetStore = *Bio::Emboss::ajFileBuffResetStore;
*Bio::Emboss::FileBuff::ajFileBuffResetPos = *Bio::Emboss::ajFileBuffResetPos;
*Bio::Emboss::FileBuff::ajFileBuffFix = *Bio::Emboss::ajFileBuffFix;
*Bio::Emboss::FileBuff::ajFileBuffFreeClear = *Bio::Emboss::ajFileBuffFreeClear;
*Bio::Emboss::FileBuff::ajFileBuffClear = *Bio::Emboss::ajFileBuffClear;
*Bio::Emboss::FileBuff::ajFileBuffClearStore = *Bio::Emboss::ajFileBuffClearStore;
*Bio::Emboss::FileBuff::ajFileBuffNobuff = *Bio::Emboss::ajFileBuffNobuff;
*Bio::Emboss::FileBuff::ajFileBuffBuff = *Bio::Emboss::ajFileBuffBuff;
*Bio::Emboss::FileBuff::ajFileBuffEmpty = *Bio::Emboss::ajFileBuffEmpty;
*Bio::Emboss::FileBuff::ajFileBuffTrace = *Bio::Emboss::ajFileBuffTrace;
*Bio::Emboss::FileBuff::ajFileBuffTraceFull = *Bio::Emboss::ajFileBuffTraceFull;
*Bio::Emboss::FileBuff::ajFileBuffPrint = *Bio::Emboss::ajFileBuffPrint;
*Bio::Emboss::FileBuff::ajFileBuffIsBuffered = *Bio::Emboss::ajFileBuffIsBuffered;
*Bio::Emboss::FileBuff::ajFileBuffFp = *Bio::Emboss::ajFileBuffFp;
*Bio::Emboss::FileBuff::ajFileBuffFile = *Bio::Emboss::ajFileBuffFile;
*Bio::Emboss::FileBuff::ajFileBuffLoad = *Bio::Emboss::ajFileBuffLoad;
*Bio::Emboss::FileBuff::ajFileBuffStripHtmlPre = *Bio::Emboss::ajFileBuffStripHtmlPre;
*Bio::Emboss::FileBuff::ajNexusParse = *Bio::Emboss::ajNexusParse;

*Bio::Emboss::Float::ajFloatDel = *Bio::Emboss::ajFloatDel;
*Bio::Emboss::Float::ajFloatGet = *Bio::Emboss::ajFloatGet;
*Bio::Emboss::Float::ajFloatPut = *Bio::Emboss::ajFloatPut;
*Bio::Emboss::Float::ajFloatFloat = *Bio::Emboss::ajFloatFloat;
*Bio::Emboss::Float::ajFloatLen = *Bio::Emboss::ajFloatLen;
*Bio::Emboss::Float::ajFloatStr = *Bio::Emboss::ajFloatStr;
*Bio::Emboss::Float::ajFloatTrace = *Bio::Emboss::ajFloatTrace;

*Bio::Emboss::Float2d::ajFloat2dDel = *Bio::Emboss::ajFloat2dDel;
*Bio::Emboss::Float2d::ajFloat2dGet = *Bio::Emboss::ajFloat2dGet;
*Bio::Emboss::Float2d::ajFloat2dPut = *Bio::Emboss::ajFloat2dPut;
*Bio::Emboss::Float2d::ajFloat2dLen = *Bio::Emboss::ajFloat2dLen;
*Bio::Emboss::Float2d::ajFloat2dFloat = *Bio::Emboss::ajFloat2dFloat;

*Bio::Emboss::Float3d::ajFloat3dDel = *Bio::Emboss::ajFloat3dDel;
*Bio::Emboss::Float3d::ajFloat3dGet = *Bio::Emboss::ajFloat3dGet;
*Bio::Emboss::Float3d::ajFloat3dPut = *Bio::Emboss::ajFloat3dPut;
*Bio::Emboss::Float3d::ajFloat3dLen = *Bio::Emboss::ajFloat3dLen;
*Bio::Emboss::Float3d::ajFloat3dFloat = *Bio::Emboss::ajFloat3dFloat;

*Bio::Emboss::Graph::ajGraphSetDevice = *Bio::Emboss::ajGraphSetDevice;
*Bio::Emboss::Graph::ajGraphSetName = *Bio::Emboss::ajGraphSetName;
*Bio::Emboss::Graph::ajGraphOpenPlot = *Bio::Emboss::ajGraphOpenPlot;
*Bio::Emboss::Graph::ajGraphOpenWin = *Bio::Emboss::ajGraphOpenWin;
*Bio::Emboss::Graph::ajGraphOpen = *Bio::Emboss::ajGraphOpen;
*Bio::Emboss::Graph::ajGraphSet = *Bio::Emboss::ajGraphSet;
*Bio::Emboss::Graph::ajGraphxySet = *Bio::Emboss::ajGraphxySet;
*Bio::Emboss::Graph::ajGraphTraceInt = *Bio::Emboss::ajGraphTraceInt;
*Bio::Emboss::Graph::ajGraphTrace = *Bio::Emboss::ajGraphTrace;
*Bio::Emboss::Graph::ajGraphGetSubTitle = *Bio::Emboss::ajGraphGetSubTitle;
*Bio::Emboss::Graph::ajGraphGetSubTitleC = *Bio::Emboss::ajGraphGetSubTitleC;
*Bio::Emboss::Graph::ajGraphGetTitle = *Bio::Emboss::ajGraphGetTitle;
*Bio::Emboss::Graph::ajGraphGetTitleC = *Bio::Emboss::ajGraphGetTitleC;
*Bio::Emboss::Graph::ajGraphGetXTitle = *Bio::Emboss::ajGraphGetXTitle;
*Bio::Emboss::Graph::ajGraphGetXTitleC = *Bio::Emboss::ajGraphGetXTitleC;
*Bio::Emboss::Graph::ajGraphGetYTitle = *Bio::Emboss::ajGraphGetYTitle;
*Bio::Emboss::Graph::ajGraphGetYTitleC = *Bio::Emboss::ajGraphGetYTitleC;
*Bio::Emboss::Graph::ajGraphInitSeq = *Bio::Emboss::ajGraphInitSeq;
*Bio::Emboss::Graph::ajGraphSetOut = *Bio::Emboss::ajGraphSetOut;
*Bio::Emboss::Graph::ajGraphSetOutC = *Bio::Emboss::ajGraphSetOutC;
*Bio::Emboss::Graph::ajGraphSetDir = *Bio::Emboss::ajGraphSetDir;
*Bio::Emboss::Graph::ajGraphxySetXStart = *Bio::Emboss::ajGraphxySetXStart;
*Bio::Emboss::Graph::ajGraphxySetXEnd = *Bio::Emboss::ajGraphxySetXEnd;
*Bio::Emboss::Graph::ajGraphxySetYStart = *Bio::Emboss::ajGraphxySetYStart;
*Bio::Emboss::Graph::ajGraphxySetYEnd = *Bio::Emboss::ajGraphxySetYEnd;
*Bio::Emboss::Graph::ajGraphSetYTitle = *Bio::Emboss::ajGraphSetYTitle;
*Bio::Emboss::Graph::ajGraphSetYTitleC = *Bio::Emboss::ajGraphSetYTitleC;
*Bio::Emboss::Graph::ajGraphSetXTitle = *Bio::Emboss::ajGraphSetXTitle;
*Bio::Emboss::Graph::ajGraphSetXTitleC = *Bio::Emboss::ajGraphSetXTitleC;
*Bio::Emboss::Graph::ajGraphSetTitle = *Bio::Emboss::ajGraphSetTitle;
*Bio::Emboss::Graph::ajGraphSetTitleC = *Bio::Emboss::ajGraphSetTitleC;
*Bio::Emboss::Graph::ajGraphSetSubTitle = *Bio::Emboss::ajGraphSetSubTitle;
*Bio::Emboss::Graph::ajGraphSetSubTitleC = *Bio::Emboss::ajGraphSetSubTitleC;
*Bio::Emboss::Graph::ajGraphxyDel = *Bio::Emboss::ajGraphxyDel;
*Bio::Emboss::Graph::ajGraphxySetXRangeII = *Bio::Emboss::ajGraphxySetXRangeII;
*Bio::Emboss::Graph::ajGraphxySetYRangeII = *Bio::Emboss::ajGraphxySetYRangeII;
*Bio::Emboss::Graph::ajGraphDataAdd = *Bio::Emboss::ajGraphDataAdd;
*Bio::Emboss::Graph::ajGraphDataReplace = *Bio::Emboss::ajGraphDataReplace;
*Bio::Emboss::Graph::ajGraphSetMulti = *Bio::Emboss::ajGraphSetMulti;
*Bio::Emboss::Graph::ajGraphSetFlag = *Bio::Emboss::ajGraphSetFlag;
*Bio::Emboss::Graph::ajGraphxySetOverLap = *Bio::Emboss::ajGraphxySetOverLap;
*Bio::Emboss::Graph::ajGraphxySetGaps = *Bio::Emboss::ajGraphxySetGaps;
*Bio::Emboss::Graph::ajGraphxySetXBottom = *Bio::Emboss::ajGraphxySetXBottom;
*Bio::Emboss::Graph::ajGraphxySetXTop = *Bio::Emboss::ajGraphxySetXTop;
*Bio::Emboss::Graph::ajGraphxySetYRight = *Bio::Emboss::ajGraphxySetYRight;
*Bio::Emboss::Graph::ajGraphxySetYLeft = *Bio::Emboss::ajGraphxySetYLeft;
*Bio::Emboss::Graph::ajGraphxySetXTick = *Bio::Emboss::ajGraphxySetXTick;
*Bio::Emboss::Graph::ajGraphxySetYTick = *Bio::Emboss::ajGraphxySetYTick;
*Bio::Emboss::Graph::ajGraphxySetXLabel = *Bio::Emboss::ajGraphxySetXLabel;
*Bio::Emboss::Graph::ajGraphxySetYLabel = *Bio::Emboss::ajGraphxySetYLabel;
*Bio::Emboss::Graph::ajGraphSetTitleDo = *Bio::Emboss::ajGraphSetTitleDo;
*Bio::Emboss::Graph::ajGraphSetSubTitleDo = *Bio::Emboss::ajGraphSetSubTitleDo;
*Bio::Emboss::Graph::ajGraphxySetCirclePoints = *Bio::Emboss::ajGraphxySetCirclePoints;
*Bio::Emboss::Graph::ajGraphxySetJoinPoints = *Bio::Emboss::ajGraphxySetJoinPoints;
*Bio::Emboss::Graph::ajGraphxySetXLabelTop = *Bio::Emboss::ajGraphxySetXLabelTop;
*Bio::Emboss::Graph::ajGraphxySetYLabelLeft = *Bio::Emboss::ajGraphxySetYLabelLeft;
*Bio::Emboss::Graph::ajGraphxySetXInvTicks = *Bio::Emboss::ajGraphxySetXInvTicks;
*Bio::Emboss::Graph::ajGraphxySetYInvTicks = *Bio::Emboss::ajGraphxySetYInvTicks;
*Bio::Emboss::Graph::ajGraphxySetXGrid = *Bio::Emboss::ajGraphxySetXGrid;
*Bio::Emboss::Graph::ajGraphxySetYGrid = *Bio::Emboss::ajGraphxySetYGrid;
*Bio::Emboss::Graph::ajGraphxySetMaxMin = *Bio::Emboss::ajGraphxySetMaxMin;
*Bio::Emboss::Graph::ajGraphxyCheckMaxMin = *Bio::Emboss::ajGraphxyCheckMaxMin;
*Bio::Emboss::Graph::ajGraphxyDisplay = *Bio::Emboss::ajGraphxyDisplay;
*Bio::Emboss::Graph::ajGraphAddRect = *Bio::Emboss::ajGraphAddRect;
*Bio::Emboss::Graph::ajGraphAddText = *Bio::Emboss::ajGraphAddText;
*Bio::Emboss::Graph::ajGraphAddLine = *Bio::Emboss::ajGraphAddLine;
*Bio::Emboss::Graph::ajGraphClear = *Bio::Emboss::ajGraphClear;
*Bio::Emboss::Graph::ajGraphIsData = *Bio::Emboss::ajGraphIsData;

*Bio::Emboss::GraphPlpData::ajGraphPlpDataTrace = *Bio::Emboss::ajGraphPlpDataTrace;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetLineType = *Bio::Emboss::ajGraphPlpDataSetLineType;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetColour = *Bio::Emboss::ajGraphPlpDataSetColour;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetYTitle = *Bio::Emboss::ajGraphPlpDataSetYTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetYTitleC = *Bio::Emboss::ajGraphPlpDataSetYTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXTitle = *Bio::Emboss::ajGraphPlpDataSetXTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXTitleC = *Bio::Emboss::ajGraphPlpDataSetXTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetXY = *Bio::Emboss::ajGraphPlpDataSetXY;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataCalcXY = *Bio::Emboss::ajGraphPlpDataCalcXY;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTitle = *Bio::Emboss::ajGraphPlpDataSetTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTitleC = *Bio::Emboss::ajGraphPlpDataSetTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetSubTitle = *Bio::Emboss::ajGraphPlpDataSetSubTitle;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetSubTitleC = *Bio::Emboss::ajGraphPlpDataSetSubTitleC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetMaxMin = *Bio::Emboss::ajGraphPlpDataSetMaxMin;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetMaxima = *Bio::Emboss::ajGraphPlpDataSetMaxima;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataSetTypeC = *Bio::Emboss::ajGraphPlpDataSetTypeC;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataDel = *Bio::Emboss::ajGraphPlpDataDel;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddRect = *Bio::Emboss::ajGraphPlpDataAddRect;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddText = *Bio::Emboss::ajGraphPlpDataAddText;
*Bio::Emboss::GraphPlpData::ajGraphPlpDataAddLine = *Bio::Emboss::ajGraphPlpDataAddLine;

*Bio::Emboss::Het::ajHetDel = *Bio::Emboss::ajHetDel;

*Bio::Emboss::Hetent::ajHetentDel = *Bio::Emboss::ajHetentDel;

*Bio::Emboss::Hist::ajHistDisplay = *Bio::Emboss::ajHistDisplay;
*Bio::Emboss::Hist::ajHistDelete = *Bio::Emboss::ajHistDelete;
*Bio::Emboss::Hist::ajHistSetMultiTitle = *Bio::Emboss::ajHistSetMultiTitle;
*Bio::Emboss::Hist::ajHistSetMultiTitleC = *Bio::Emboss::ajHistSetMultiTitleC;
*Bio::Emboss::Hist::ajHistSetMultiXTitle = *Bio::Emboss::ajHistSetMultiXTitle;
*Bio::Emboss::Hist::ajHistSetMultiXTitleC = *Bio::Emboss::ajHistSetMultiXTitleC;
*Bio::Emboss::Hist::ajHistSetMultiYTitle = *Bio::Emboss::ajHistSetMultiYTitle;
*Bio::Emboss::Hist::ajHistSetMultiYTitleC = *Bio::Emboss::ajHistSetMultiYTitleC;
*Bio::Emboss::Hist::ajHistSetPtrToData = *Bio::Emboss::ajHistSetPtrToData;
*Bio::Emboss::Hist::ajHistCopyData = *Bio::Emboss::ajHistCopyData;
*Bio::Emboss::Hist::ajHistSetTitleC = *Bio::Emboss::ajHistSetTitleC;
*Bio::Emboss::Hist::ajHistSetXAxisC = *Bio::Emboss::ajHistSetXAxisC;
*Bio::Emboss::Hist::ajHistSetYAxisLeftC = *Bio::Emboss::ajHistSetYAxisLeftC;
*Bio::Emboss::Hist::ajHistSetYAxisRightC = *Bio::Emboss::ajHistSetYAxisRightC;
*Bio::Emboss::Hist::ajHistSetBlackandWhite = *Bio::Emboss::ajHistSetBlackandWhite;
*Bio::Emboss::Hist::ajHistSetColour = *Bio::Emboss::ajHistSetColour;
*Bio::Emboss::Hist::ajHistSetPattern = *Bio::Emboss::ajHistSetPattern;

*Bio::Emboss::Int::ajIntDel = *Bio::Emboss::ajIntDel;
*Bio::Emboss::Int::ajIntGet = *Bio::Emboss::ajIntGet;
*Bio::Emboss::Int::ajIntPut = *Bio::Emboss::ajIntPut;
*Bio::Emboss::Int::ajIntInc = *Bio::Emboss::ajIntInc;
*Bio::Emboss::Int::ajIntDec = *Bio::Emboss::ajIntDec;
*Bio::Emboss::Int::ajIntInt = *Bio::Emboss::ajIntInt;
*Bio::Emboss::Int::ajIntLen = *Bio::Emboss::ajIntLen;

*Bio::Emboss::Int2d::ajInt2dDel = *Bio::Emboss::ajInt2dDel;
*Bio::Emboss::Int2d::ajInt2dGet = *Bio::Emboss::ajInt2dGet;
*Bio::Emboss::Int2d::ajInt2dPut = *Bio::Emboss::ajInt2dPut;
*Bio::Emboss::Int2d::ajInt2dLen = *Bio::Emboss::ajInt2dLen;
*Bio::Emboss::Int2d::ajInt2dInt = *Bio::Emboss::ajInt2dInt;

*Bio::Emboss::Int3d::ajInt3dDel = *Bio::Emboss::ajInt3dDel;
*Bio::Emboss::Int3d::ajInt3dGet = *Bio::Emboss::ajInt3dGet;
*Bio::Emboss::Int3d::ajInt3dPut = *Bio::Emboss::ajInt3dPut;
*Bio::Emboss::Int3d::ajInt3dLen = *Bio::Emboss::ajInt3dLen;
*Bio::Emboss::Int3d::ajInt3dInt = *Bio::Emboss::ajInt3dInt;

*Bio::Emboss::List::ajDmxScophitListCopy = *Bio::Emboss::ajDmxScophitListCopy;
*Bio::Emboss::List::ajFileNewInList = *Bio::Emboss::ajFileNewInList;
*Bio::Emboss::List::ajFileBuffNewInList = *Bio::Emboss::ajFileBuffNewInList;
*Bio::Emboss::List::ajGraphInfo = *Bio::Emboss::ajGraphInfo;
*Bio::Emboss::List::ajListPush = *Bio::Emboss::ajListPush;
*Bio::Emboss::List::ajListstrPush = *Bio::Emboss::ajListstrPush;
*Bio::Emboss::List::ajListTrace = *Bio::Emboss::ajListTrace;
*Bio::Emboss::List::ajListstrTrace = *Bio::Emboss::ajListstrTrace;
*Bio::Emboss::List::ajListAppend = *Bio::Emboss::ajListAppend;
*Bio::Emboss::List::ajListPushApp = *Bio::Emboss::ajListPushApp;
*Bio::Emboss::List::ajListstrPushApp = *Bio::Emboss::ajListstrPushApp;
*Bio::Emboss::List::ajListstrCopy = *Bio::Emboss::ajListstrCopy;
*Bio::Emboss::List::ajListCopy = *Bio::Emboss::ajListCopy;
*Bio::Emboss::List::ajListstrClone = *Bio::Emboss::ajListstrClone;
*Bio::Emboss::List::ajListFirst = *Bio::Emboss::ajListFirst;
*Bio::Emboss::List::ajListLast = *Bio::Emboss::ajListLast;
*Bio::Emboss::List::ajListNth = *Bio::Emboss::ajListNth;
*Bio::Emboss::List::ajListPop = *Bio::Emboss::ajListPop;
*Bio::Emboss::List::ajListPeek = *Bio::Emboss::ajListPeek;
*Bio::Emboss::List::ajListstrPop = *Bio::Emboss::ajListstrPop;
*Bio::Emboss::List::ajListstrPeek = *Bio::Emboss::ajListstrPeek;
*Bio::Emboss::List::ajListReverse = *Bio::Emboss::ajListReverse;
*Bio::Emboss::List::ajListstrReverse = *Bio::Emboss::ajListstrReverse;
*Bio::Emboss::List::ajListLength = *Bio::Emboss::ajListLength;
*Bio::Emboss::List::ajListstrLength = *Bio::Emboss::ajListstrLength;
*Bio::Emboss::List::ajListFree = *Bio::Emboss::ajListFree;
*Bio::Emboss::List::ajListstrFree = *Bio::Emboss::ajListstrFree;
*Bio::Emboss::List::ajListDel = *Bio::Emboss::ajListDel;
*Bio::Emboss::List::ajListstrDel = *Bio::Emboss::ajListstrDel;
*Bio::Emboss::List::ajListToArray = *Bio::Emboss::ajListToArray;
*Bio::Emboss::List::ajListstrToArray = *Bio::Emboss::ajListstrToArray;
*Bio::Emboss::List::ajListstrToArrayApp = *Bio::Emboss::ajListstrToArrayApp;
*Bio::Emboss::List::ajListIter = *Bio::Emboss::ajListIter;
*Bio::Emboss::List::ajListIterRead = *Bio::Emboss::ajListIterRead;
*Bio::Emboss::List::ajListIterBack = *Bio::Emboss::ajListIterBack;
*Bio::Emboss::List::ajListIterBackRead = *Bio::Emboss::ajListIterBackRead;
*Bio::Emboss::List::ajListPushList = *Bio::Emboss::ajListPushList;
*Bio::Emboss::List::ajListstrPushList = *Bio::Emboss::ajListstrPushList;
*Bio::Emboss::List::ajListPopEnd = *Bio::Emboss::ajListPopEnd;
*Bio::Emboss::List::ajListstrPopEnd = *Bio::Emboss::ajListstrPopEnd;
*Bio::Emboss::List::ajNamListListDatabases = *Bio::Emboss::ajNamListListDatabases;
*Bio::Emboss::List::ajNamListListResources = *Bio::Emboss::ajNamListListResources;
*Bio::Emboss::List::ajAtomListCopy = *Bio::Emboss::ajAtomListCopy;
*Bio::Emboss::List::ajResidueListCopy = *Bio::Emboss::ajResidueListCopy;
*Bio::Emboss::List::ajSeqsetallRead = *Bio::Emboss::ajSeqsetallRead;

*Bio::Emboss::Long::ajLongDel = *Bio::Emboss::ajLongDel;
*Bio::Emboss::Long::ajLongGet = *Bio::Emboss::ajLongGet;
*Bio::Emboss::Long::ajLongPut = *Bio::Emboss::ajLongPut;
*Bio::Emboss::Long::ajLongLong = *Bio::Emboss::ajLongLong;
*Bio::Emboss::Long::ajLongLen = *Bio::Emboss::ajLongLen;

*Bio::Emboss::Long2d::ajLong2dDel = *Bio::Emboss::ajLong2dDel;
*Bio::Emboss::Long2d::ajLong2dGet = *Bio::Emboss::ajLong2dGet;
*Bio::Emboss::Long2d::ajLong2dPut = *Bio::Emboss::ajLong2dPut;
*Bio::Emboss::Long2d::ajLong2dLen = *Bio::Emboss::ajLong2dLen;
*Bio::Emboss::Long2d::ajLong2dLong = *Bio::Emboss::ajLong2dLong;

*Bio::Emboss::Long3d::ajLong3dDel = *Bio::Emboss::ajLong3dDel;
*Bio::Emboss::Long3d::ajLong3dGet = *Bio::Emboss::ajLong3dGet;
*Bio::Emboss::Long3d::ajLong3dPut = *Bio::Emboss::ajLong3dPut;
*Bio::Emboss::Long3d::ajLong3dLen = *Bio::Emboss::ajLong3dLen;
*Bio::Emboss::Long3d::ajLong3dLong = *Bio::Emboss::ajLong3dLong;

*Bio::Emboss::Matrix::ajMatrixDel = *Bio::Emboss::ajMatrixDel;
*Bio::Emboss::Matrix::ajMatrixArray = *Bio::Emboss::ajMatrixArray;
*Bio::Emboss::Matrix::ajMatrixSize = *Bio::Emboss::ajMatrixSize;
*Bio::Emboss::Matrix::ajMatrixCvt = *Bio::Emboss::ajMatrixCvt;
*Bio::Emboss::Matrix::ajMatrixChar = *Bio::Emboss::ajMatrixChar;
*Bio::Emboss::Matrix::ajMatrixName = *Bio::Emboss::ajMatrixName;
*Bio::Emboss::Matrix::ajMatrixRead = *Bio::Emboss::ajMatrixRead;
*Bio::Emboss::Matrix::ajMatrixSeqNum = *Bio::Emboss::ajMatrixSeqNum;
*Bio::Emboss::Matrix::ajMatrixGetCodes = *Bio::Emboss::ajMatrixGetCodes;

*Bio::Emboss::Matrixf::ajMatrixfDel = *Bio::Emboss::ajMatrixfDel;
*Bio::Emboss::Matrixf::ajMatrixfArray = *Bio::Emboss::ajMatrixfArray;
*Bio::Emboss::Matrixf::ajMatrixfSize = *Bio::Emboss::ajMatrixfSize;
*Bio::Emboss::Matrixf::ajMatrixfCvt = *Bio::Emboss::ajMatrixfCvt;
*Bio::Emboss::Matrixf::ajMatrixfChar = *Bio::Emboss::ajMatrixfChar;
*Bio::Emboss::Matrixf::ajMatrixfName = *Bio::Emboss::ajMatrixfName;
*Bio::Emboss::Matrixf::ajMatrixfRead = *Bio::Emboss::ajMatrixfRead;
*Bio::Emboss::Matrixf::ajMatrixfSeqNum = *Bio::Emboss::ajMatrixfSeqNum;
*Bio::Emboss::Matrixf::ajMatrixfGetCodes = *Bio::Emboss::ajMatrixfGetCodes;

*Bio::Emboss::Nexus::ajNexusDel = *Bio::Emboss::ajNexusDel;
*Bio::Emboss::Nexus::ajNexusTrace = *Bio::Emboss::ajNexusTrace;
*Bio::Emboss::Nexus::ajNexusGetTaxa = *Bio::Emboss::ajNexusGetTaxa;
*Bio::Emboss::Nexus::ajNexusGetNtaxa = *Bio::Emboss::ajNexusGetNtaxa;
*Bio::Emboss::Nexus::ajNexusGetSequences = *Bio::Emboss::ajNexusGetSequences;

*Bio::Emboss::Outfile::ajOutfileClose = *Bio::Emboss::ajOutfileClose;
*Bio::Emboss::Outfile::ajOutfileDel = *Bio::Emboss::ajOutfileDel;
*Bio::Emboss::Outfile::ajOutfileFile = *Bio::Emboss::ajOutfileFile;
*Bio::Emboss::Outfile::ajOutfileFp = *Bio::Emboss::ajOutfileFp;
*Bio::Emboss::Outfile::ajOutfileFormat = *Bio::Emboss::ajOutfileFormat;

*Bio::Emboss::PStr::ajMatrixNew = *Bio::Emboss::ajMatrixNew;
*Bio::Emboss::PStr::ajMatrixNewAsym = *Bio::Emboss::ajMatrixNewAsym;
*Bio::Emboss::PStr::ajMatrixfNew = *Bio::Emboss::ajMatrixfNew;
*Bio::Emboss::PStr::ajMatrixfNewAsym = *Bio::Emboss::ajMatrixfNewAsym;
*Bio::Emboss::PStr::ajSeqCvtNewZeroS = *Bio::Emboss::ajSeqCvtNewZeroS;
*Bio::Emboss::PStr::ajSeqCvtNewZeroSS = *Bio::Emboss::ajSeqCvtNewZeroSS;

*Bio::Emboss::Pdb::ajPdbDel = *Bio::Emboss::ajPdbDel;
*Bio::Emboss::Pdb::ajPdbCopy = *Bio::Emboss::ajPdbCopy;
*Bio::Emboss::Pdb::ajPdbGetEStrideType = *Bio::Emboss::ajPdbGetEStrideType;

*Bio::Emboss::Pdbtosp::ajPdbtospDel = *Bio::Emboss::ajPdbtospDel;
*Bio::Emboss::Pdbtosp::ajPdbtospArrFindPdbid = *Bio::Emboss::ajPdbtospArrFindPdbid;

*Bio::Emboss::PhyloDist::ajPhyloDistDel = *Bio::Emboss::ajPhyloDistDel;
*Bio::Emboss::PhyloDist::ajPhyloDistTrace = *Bio::Emboss::ajPhyloDistTrace;

*Bio::Emboss::PhyloFreq::ajPhyloFreqDel = *Bio::Emboss::ajPhyloFreqDel;
*Bio::Emboss::PhyloFreq::ajPhyloFreqTrace = *Bio::Emboss::ajPhyloFreqTrace;

*Bio::Emboss::PhyloProp::ajPhyloPropDel = *Bio::Emboss::ajPhyloPropDel;
*Bio::Emboss::PhyloProp::ajPhyloPropGetSize = *Bio::Emboss::ajPhyloPropGetSize;
*Bio::Emboss::PhyloProp::ajPhyloPropTrace = *Bio::Emboss::ajPhyloPropTrace;

*Bio::Emboss::PhyloState::ajPhyloStateDel = *Bio::Emboss::ajPhyloStateDel;
*Bio::Emboss::PhyloState::ajPhyloStateTrace = *Bio::Emboss::ajPhyloStateTrace;

*Bio::Emboss::PhyloTree::ajPhyloTreeDel = *Bio::Emboss::ajPhyloTreeDel;
*Bio::Emboss::PhyloTree::ajPhyloTreeTrace = *Bio::Emboss::ajPhyloTreeTrace;

*Bio::Emboss::Range::ajRangeCopy = *Bio::Emboss::ajRangeCopy;
*Bio::Emboss::Range::ajRangeDel = *Bio::Emboss::ajRangeDel;
*Bio::Emboss::Range::ajRangeNumber = *Bio::Emboss::ajRangeNumber;
*Bio::Emboss::Range::ajRangeValues = *Bio::Emboss::ajRangeValues;
*Bio::Emboss::Range::ajRangeText = *Bio::Emboss::ajRangeText;
*Bio::Emboss::Range::ajRangeChange = *Bio::Emboss::ajRangeChange;
*Bio::Emboss::Range::ajRangeBegin = *Bio::Emboss::ajRangeBegin;
*Bio::Emboss::Range::ajRangeSeqExtractList = *Bio::Emboss::ajRangeSeqExtractList;
*Bio::Emboss::Range::ajRangeSeqExtract = *Bio::Emboss::ajRangeSeqExtract;
*Bio::Emboss::Range::ajRangeSeqStuff = *Bio::Emboss::ajRangeSeqStuff;
*Bio::Emboss::Range::ajRangeSeqMask = *Bio::Emboss::ajRangeSeqMask;
*Bio::Emboss::Range::ajRangeSeqToLower = *Bio::Emboss::ajRangeSeqToLower;
*Bio::Emboss::Range::ajRangeStrExtractList = *Bio::Emboss::ajRangeStrExtractList;
*Bio::Emboss::Range::ajRangeStrExtract = *Bio::Emboss::ajRangeStrExtract;
*Bio::Emboss::Range::ajRangeStrStuff = *Bio::Emboss::ajRangeStrStuff;
*Bio::Emboss::Range::ajRangeStrMask = *Bio::Emboss::ajRangeStrMask;
*Bio::Emboss::Range::ajRangeStrToLower = *Bio::Emboss::ajRangeStrToLower;
*Bio::Emboss::Range::ajRangeOverlaps = *Bio::Emboss::ajRangeOverlaps;
*Bio::Emboss::Range::ajRangeOrdered = *Bio::Emboss::ajRangeOrdered;
*Bio::Emboss::Range::ajRangeDefault = *Bio::Emboss::ajRangeDefault;

*Bio::Emboss::Regexp::ajRegExec = *Bio::Emboss::ajRegExec;
*Bio::Emboss::Regexp::ajRegExecB = *Bio::Emboss::ajRegExecB;
*Bio::Emboss::Regexp::ajRegExecC = *Bio::Emboss::ajRegExecC;
*Bio::Emboss::Regexp::ajRegOffset = *Bio::Emboss::ajRegOffset;
*Bio::Emboss::Regexp::ajRegOffsetI = *Bio::Emboss::ajRegOffsetI;
*Bio::Emboss::Regexp::ajRegLenI = *Bio::Emboss::ajRegLenI;
*Bio::Emboss::Regexp::ajRegPost = *Bio::Emboss::ajRegPost;
*Bio::Emboss::Regexp::ajRegPostC = *Bio::Emboss::ajRegPostC;
*Bio::Emboss::Regexp::ajRegPre = *Bio::Emboss::ajRegPre;
*Bio::Emboss::Regexp::ajRegSubI = *Bio::Emboss::ajRegSubI;
*Bio::Emboss::Regexp::ajRegFree = *Bio::Emboss::ajRegFree;
*Bio::Emboss::Regexp::ajRegTrace = *Bio::Emboss::ajRegTrace;

*Bio::Emboss::Report::ajReportDel = *Bio::Emboss::ajReportDel;
*Bio::Emboss::Report::ajReportOpen = *Bio::Emboss::ajReportOpen;
*Bio::Emboss::Report::ajReportSetTags = *Bio::Emboss::ajReportSetTags;
*Bio::Emboss::Report::ajReportValid = *Bio::Emboss::ajReportValid;
*Bio::Emboss::Report::ajReportWrite = *Bio::Emboss::ajReportWrite;
*Bio::Emboss::Report::ajReportClose = *Bio::Emboss::ajReportClose;
*Bio::Emboss::Report::ajReportLists = *Bio::Emboss::ajReportLists;
*Bio::Emboss::Report::ajReportWriteHeader = *Bio::Emboss::ajReportWriteHeader;
*Bio::Emboss::Report::ajReportWriteTail = *Bio::Emboss::ajReportWriteTail;
*Bio::Emboss::Report::ajReportSetHeader = *Bio::Emboss::ajReportSetHeader;
*Bio::Emboss::Report::ajReportSetHeaderC = *Bio::Emboss::ajReportSetHeaderC;
*Bio::Emboss::Report::ajReportSetSubHeader = *Bio::Emboss::ajReportSetSubHeader;
*Bio::Emboss::Report::ajReportSetSubHeaderC = *Bio::Emboss::ajReportSetSubHeaderC;
*Bio::Emboss::Report::ajReportSetTail = *Bio::Emboss::ajReportSetTail;
*Bio::Emboss::Report::ajReportSetTailC = *Bio::Emboss::ajReportSetTailC;
*Bio::Emboss::Report::ajReportSetSubTail = *Bio::Emboss::ajReportSetSubTail;
*Bio::Emboss::Report::ajReportSetSubTailC = *Bio::Emboss::ajReportSetSubTailC;
*Bio::Emboss::Report::ajReportSetType = *Bio::Emboss::ajReportSetType;
*Bio::Emboss::Report::ajReportSeqName = *Bio::Emboss::ajReportSeqName;
*Bio::Emboss::Report::ajReportFileAdd = *Bio::Emboss::ajReportFileAdd;

*Bio::Emboss::Residue::ajResidueDel = *Bio::Emboss::ajResidueDel;
*Bio::Emboss::Residue::ajResidueCopy = *Bio::Emboss::ajResidueCopy;
*Bio::Emboss::Residue::ajResidueSSEnv = *Bio::Emboss::ajResidueSSEnv;
*Bio::Emboss::Residue::ajResidueEnv1 = *Bio::Emboss::ajResidueEnv1;
*Bio::Emboss::Residue::ajResidueEnv2 = *Bio::Emboss::ajResidueEnv2;
*Bio::Emboss::Residue::ajResidueEnv3 = *Bio::Emboss::ajResidueEnv3;
*Bio::Emboss::Residue::ajResidueEnv4 = *Bio::Emboss::ajResidueEnv4;
*Bio::Emboss::Residue::ajResidueEnv5 = *Bio::Emboss::ajResidueEnv5;
*Bio::Emboss::Residue::ajResidueEnv6 = *Bio::Emboss::ajResidueEnv6;
*Bio::Emboss::Residue::ajResidueEnv7 = *Bio::Emboss::ajResidueEnv7;
*Bio::Emboss::Residue::ajResidueEnv8 = *Bio::Emboss::ajResidueEnv8;
*Bio::Emboss::Residue::ajResidueEnv9 = *Bio::Emboss::ajResidueEnv9;
*Bio::Emboss::Residue::ajResidueEnv10 = *Bio::Emboss::ajResidueEnv10;
*Bio::Emboss::Residue::ajResidueEnv11 = *Bio::Emboss::ajResidueEnv11;
*Bio::Emboss::Residue::ajResidueEnv12 = *Bio::Emboss::ajResidueEnv12;
*Bio::Emboss::Residue::ajResidueEnv13 = *Bio::Emboss::ajResidueEnv13;
*Bio::Emboss::Residue::ajResidueEnv14 = *Bio::Emboss::ajResidueEnv14;
*Bio::Emboss::Residue::ajResidueEnv15 = *Bio::Emboss::ajResidueEnv15;
*Bio::Emboss::Residue::ajResidueEnv16 = *Bio::Emboss::ajResidueEnv16;

*Bio::Emboss::Scop::ajScopDel = *Bio::Emboss::ajScopDel;
*Bio::Emboss::Scop::ajScopCopy = *Bio::Emboss::ajScopCopy;
*Bio::Emboss::Scop::ajScopArrFindScopid = *Bio::Emboss::ajScopArrFindScopid;
*Bio::Emboss::Scop::ajScopArrFindSunid = *Bio::Emboss::ajScopArrFindSunid;
*Bio::Emboss::Scop::ajScopArrFindPdbid = *Bio::Emboss::ajScopArrFindPdbid;

*Bio::Emboss::Scopalg::ajDmxScopalgDel = *Bio::Emboss::ajDmxScopalgDel;
*Bio::Emboss::Scopalg::ajDmxScopalgGetseqs = *Bio::Emboss::ajDmxScopalgGetseqs;
*Bio::Emboss::Scopalg::ajDmxScopalgWrite = *Bio::Emboss::ajDmxScopalgWrite;
*Bio::Emboss::Scopalg::ajDmxScopalgWriteClustal = *Bio::Emboss::ajDmxScopalgWriteClustal;
*Bio::Emboss::Scopalg::ajDmxScopalgWriteClustal2 = *Bio::Emboss::ajDmxScopalgWriteClustal2;
*Bio::Emboss::Scopalg::ajDmxScopalgWriteFasta = *Bio::Emboss::ajDmxScopalgWriteFasta;

*Bio::Emboss::Scophit::ajDmxScophitDel = *Bio::Emboss::ajDmxScophitDel;
*Bio::Emboss::Scophit::ajDmxScophitCopy = *Bio::Emboss::ajDmxScophitCopy;
*Bio::Emboss::Scophit::ajDmxScophitTargetLowPriority = *Bio::Emboss::ajDmxScophitTargetLowPriority;
*Bio::Emboss::Scophit::ajDmxScophitTarget2 = *Bio::Emboss::ajDmxScophitTarget2;
*Bio::Emboss::Scophit::ajDmxScophitTarget = *Bio::Emboss::ajDmxScophitTarget;
*Bio::Emboss::Scophit::ajDmxScophitCheckTarget = *Bio::Emboss::ajDmxScophitCheckTarget;

*Bio::Emboss::Seq::ajFeattableNewSeq = *Bio::Emboss::ajFeattableNewSeq;
*Bio::Emboss::Seq::ajSeqNewSeq = *Bio::Emboss::ajSeqNewSeq;
*Bio::Emboss::Seq::ajSeqAssignAccC = *Bio::Emboss::ajSeqAssignAccC;
*Bio::Emboss::Seq::ajSeqAssignAccS = *Bio::Emboss::ajSeqAssignAccS;
*Bio::Emboss::Seq::ajSeqAssignDescC = *Bio::Emboss::ajSeqAssignDescC;
*Bio::Emboss::Seq::ajSeqAssignDescS = *Bio::Emboss::ajSeqAssignDescS;
*Bio::Emboss::Seq::ajSeqAssignEntryC = *Bio::Emboss::ajSeqAssignEntryC;
*Bio::Emboss::Seq::ajSeqAssignEntryS = *Bio::Emboss::ajSeqAssignEntryS;
*Bio::Emboss::Seq::ajSeqAssignFileC = *Bio::Emboss::ajSeqAssignFileC;
*Bio::Emboss::Seq::ajSeqAssignFileS = *Bio::Emboss::ajSeqAssignFileS;
*Bio::Emboss::Seq::ajSeqAssignFullC = *Bio::Emboss::ajSeqAssignFullC;
*Bio::Emboss::Seq::ajSeqAssignFullS = *Bio::Emboss::ajSeqAssignFullS;
*Bio::Emboss::Seq::ajSeqAssignGiC = *Bio::Emboss::ajSeqAssignGiC;
*Bio::Emboss::Seq::ajSeqAssignGiS = *Bio::Emboss::ajSeqAssignGiS;
*Bio::Emboss::Seq::ajSeqAssignNameC = *Bio::Emboss::ajSeqAssignNameC;
*Bio::Emboss::Seq::ajSeqAssignNameS = *Bio::Emboss::ajSeqAssignNameS;
*Bio::Emboss::Seq::ajSeqAssignSeqC = *Bio::Emboss::ajSeqAssignSeqC;
*Bio::Emboss::Seq::ajSeqAssignSeqLenC = *Bio::Emboss::ajSeqAssignSeqLenC;
*Bio::Emboss::Seq::ajSeqAssignSeqS = *Bio::Emboss::ajSeqAssignSeqS;
*Bio::Emboss::Seq::ajSeqAssignSvC = *Bio::Emboss::ajSeqAssignSvC;
*Bio::Emboss::Seq::ajSeqAssignSvS = *Bio::Emboss::ajSeqAssignSvS;
*Bio::Emboss::Seq::ajSeqAssignUfoC = *Bio::Emboss::ajSeqAssignUfoC;
*Bio::Emboss::Seq::ajSeqAssignUfoS = *Bio::Emboss::ajSeqAssignUfoS;
*Bio::Emboss::Seq::ajSeqAssignUsaC = *Bio::Emboss::ajSeqAssignUsaC;
*Bio::Emboss::Seq::ajSeqAssignUsaS = *Bio::Emboss::ajSeqAssignUsaS;
*Bio::Emboss::Seq::ajSeqSetOffsets = *Bio::Emboss::ajSeqSetOffsets;
*Bio::Emboss::Seq::ajSeqSetRange = *Bio::Emboss::ajSeqSetRange;
*Bio::Emboss::Seq::ajSeqSetRangeRev = *Bio::Emboss::ajSeqSetRangeRev;
*Bio::Emboss::Seq::ajSeqComplementOnly = *Bio::Emboss::ajSeqComplementOnly;
*Bio::Emboss::Seq::ajSeqFmtLower = *Bio::Emboss::ajSeqFmtLower;
*Bio::Emboss::Seq::ajSeqFmtUpper = *Bio::Emboss::ajSeqFmtUpper;
*Bio::Emboss::Seq::ajSeqReverseDo = *Bio::Emboss::ajSeqReverseDo;
*Bio::Emboss::Seq::ajSeqReverseForce = *Bio::Emboss::ajSeqReverseForce;
*Bio::Emboss::Seq::ajSeqReverseOnly = *Bio::Emboss::ajSeqReverseOnly;
*Bio::Emboss::Seq::ajSeqGetAccC = *Bio::Emboss::ajSeqGetAccC;
*Bio::Emboss::Seq::ajSeqGetAccS = *Bio::Emboss::ajSeqGetAccS;
*Bio::Emboss::Seq::ajSeqGetBegin = *Bio::Emboss::ajSeqGetBegin;
*Bio::Emboss::Seq::ajSeqGetBeginTrue = *Bio::Emboss::ajSeqGetBeginTrue;
*Bio::Emboss::Seq::ajSeqGetDescC = *Bio::Emboss::ajSeqGetDescC;
*Bio::Emboss::Seq::ajSeqGetDescS = *Bio::Emboss::ajSeqGetDescS;
*Bio::Emboss::Seq::ajSeqGetEnd = *Bio::Emboss::ajSeqGetEnd;
*Bio::Emboss::Seq::ajSeqGetEndTrue = *Bio::Emboss::ajSeqGetEndTrue;
*Bio::Emboss::Seq::ajSeqGetEntryC = *Bio::Emboss::ajSeqGetEntryC;
*Bio::Emboss::Seq::ajSeqGetEntryS = *Bio::Emboss::ajSeqGetEntryS;
*Bio::Emboss::Seq::ajSeqGetFeat = *Bio::Emboss::ajSeqGetFeat;
*Bio::Emboss::Seq::ajSeqGetFeatCopy = *Bio::Emboss::ajSeqGetFeatCopy;
*Bio::Emboss::Seq::ajSeqGetGiC = *Bio::Emboss::ajSeqGetGiC;
*Bio::Emboss::Seq::ajSeqGetGiS = *Bio::Emboss::ajSeqGetGiS;
*Bio::Emboss::Seq::ajSeqGetLen = *Bio::Emboss::ajSeqGetLen;
*Bio::Emboss::Seq::ajSeqGetLenTrue = *Bio::Emboss::ajSeqGetLenTrue;
*Bio::Emboss::Seq::ajSeqGetNameC = *Bio::Emboss::ajSeqGetNameC;
*Bio::Emboss::Seq::ajSeqGetNameS = *Bio::Emboss::ajSeqGetNameS;
*Bio::Emboss::Seq::ajSeqGetOffend = *Bio::Emboss::ajSeqGetOffend;
*Bio::Emboss::Seq::ajSeqGetOffset = *Bio::Emboss::ajSeqGetOffset;
*Bio::Emboss::Seq::ajSeqGetRange = *Bio::Emboss::ajSeqGetRange;
*Bio::Emboss::Seq::ajSeqGetRev = *Bio::Emboss::ajSeqGetRev;
*Bio::Emboss::Seq::ajSeqGetSeqC = *Bio::Emboss::ajSeqGetSeqC;
*Bio::Emboss::Seq::ajSeqGetSeqS = *Bio::Emboss::ajSeqGetSeqS;
*Bio::Emboss::Seq::ajSeqGetSeqCopyC = *Bio::Emboss::ajSeqGetSeqCopyC;
*Bio::Emboss::Seq::ajSeqGetSeqCopyS = *Bio::Emboss::ajSeqGetSeqCopyS;
*Bio::Emboss::Seq::ajSeqGetSvC = *Bio::Emboss::ajSeqGetSvC;
*Bio::Emboss::Seq::ajSeqGetSvS = *Bio::Emboss::ajSeqGetSvS;
*Bio::Emboss::Seq::ajSeqGetTaxC = *Bio::Emboss::ajSeqGetTaxC;
*Bio::Emboss::Seq::ajSeqGetTaxS = *Bio::Emboss::ajSeqGetTaxS;
*Bio::Emboss::Seq::ajSeqGetUsaC = *Bio::Emboss::ajSeqGetUsaC;
*Bio::Emboss::Seq::ajSeqGetUsaS = *Bio::Emboss::ajSeqGetUsaS;
*Bio::Emboss::Seq::ajSeqIsNuc = *Bio::Emboss::ajSeqIsNuc;
*Bio::Emboss::Seq::ajSeqIsProt = *Bio::Emboss::ajSeqIsProt;
*Bio::Emboss::Seq::ajSeqIsReversedTrue = *Bio::Emboss::ajSeqIsReversedTrue;
*Bio::Emboss::Seq::ajSeqIsReversed = *Bio::Emboss::ajSeqIsReversed;
*Bio::Emboss::Seq::ajSeqIsTrimmed = *Bio::Emboss::ajSeqIsTrimmed;
*Bio::Emboss::Seq::ajSeqCalcCheckgcg = *Bio::Emboss::ajSeqCalcCheckgcg;
*Bio::Emboss::Seq::ajSeqCalcCount = *Bio::Emboss::ajSeqCalcCount;
*Bio::Emboss::Seq::ajSeqCalcCrc = *Bio::Emboss::ajSeqCalcCrc;
*Bio::Emboss::Seq::ajSeqCalcMolwt = *Bio::Emboss::ajSeqCalcMolwt;
*Bio::Emboss::Seq::ajSeqCalcTrueposMin = *Bio::Emboss::ajSeqCalcTrueposMin;
*Bio::Emboss::Seq::ajSeqCalcTruepos = *Bio::Emboss::ajSeqCalcTruepos;
*Bio::Emboss::Seq::ajSeqDel = *Bio::Emboss::ajSeqDel;
*Bio::Emboss::Seq::ajSeqClear = *Bio::Emboss::ajSeqClear;
*Bio::Emboss::Seq::ajSeqMod = *Bio::Emboss::ajSeqMod;
*Bio::Emboss::Seq::ajSeqTrace = *Bio::Emboss::ajSeqTrace;
*Bio::Emboss::Seq::ajSeqTraceT = *Bio::Emboss::ajSeqTraceT;
*Bio::Emboss::Seq::ajSeqNum = *Bio::Emboss::ajSeqNum;
*Bio::Emboss::Seq::ajSeqIsGarbage = *Bio::Emboss::ajSeqIsGarbage;
*Bio::Emboss::Seq::ajSeqTrim = *Bio::Emboss::ajSeqTrim;
*Bio::Emboss::Seq::ajSeqGapCount = *Bio::Emboss::ajSeqGapCount;
*Bio::Emboss::Seq::ajSeqGapStandard = *Bio::Emboss::ajSeqGapStandard;
*Bio::Emboss::Seq::ajSeqFill = *Bio::Emboss::ajSeqFill;
*Bio::Emboss::Seq::ajSeqDefName = *Bio::Emboss::ajSeqDefName;
*Bio::Emboss::Seq::ajSeqstrCalcMolwt = *Bio::Emboss::ajSeqstrCalcMolwt;
*Bio::Emboss::Seq::ajSeqGarbageOn = *Bio::Emboss::ajSeqGarbageOn;
*Bio::Emboss::Seq::ajSeqGarbageOff = *Bio::Emboss::ajSeqGarbageOff;
*Bio::Emboss::Seq::ajSeqAllRead = *Bio::Emboss::ajSeqAllRead;
*Bio::Emboss::Seq::ajSeqRead = *Bio::Emboss::ajSeqRead;
*Bio::Emboss::Seq::ajSeqTypeCheckIn = *Bio::Emboss::ajSeqTypeCheckIn;
*Bio::Emboss::Seq::ajSeqGap = *Bio::Emboss::ajSeqGap;
*Bio::Emboss::Seq::ajSeqGapLen = *Bio::Emboss::ajSeqGapLen;
*Bio::Emboss::Seq::ajSeqSetNuc = *Bio::Emboss::ajSeqSetNuc;
*Bio::Emboss::Seq::ajSeqSetProt = *Bio::Emboss::ajSeqSetProt;
*Bio::Emboss::Seq::ajSeqType = *Bio::Emboss::ajSeqType;
*Bio::Emboss::Seq::ajTrnNewPep = *Bio::Emboss::ajTrnNewPep;
*Bio::Emboss::Seq::ajSeqAssAcc = *Bio::Emboss::ajSeqAssAcc;
*Bio::Emboss::Seq::ajSeqAssAccC = *Bio::Emboss::ajSeqAssAccC;
*Bio::Emboss::Seq::ajSeqAssDesc = *Bio::Emboss::ajSeqAssDesc;
*Bio::Emboss::Seq::ajSeqAssDescC = *Bio::Emboss::ajSeqAssDescC;
*Bio::Emboss::Seq::ajSeqAssEntry = *Bio::Emboss::ajSeqAssEntry;
*Bio::Emboss::Seq::ajSeqAssEntryC = *Bio::Emboss::ajSeqAssEntryC;
*Bio::Emboss::Seq::ajSeqAssFile = *Bio::Emboss::ajSeqAssFile;
*Bio::Emboss::Seq::ajSeqAssFull = *Bio::Emboss::ajSeqAssFull;
*Bio::Emboss::Seq::ajSeqAssFullC = *Bio::Emboss::ajSeqAssFullC;
*Bio::Emboss::Seq::ajSeqAssGi = *Bio::Emboss::ajSeqAssGi;
*Bio::Emboss::Seq::ajSeqAssGiC = *Bio::Emboss::ajSeqAssGiC;
*Bio::Emboss::Seq::ajSeqAssName = *Bio::Emboss::ajSeqAssName;
*Bio::Emboss::Seq::ajSeqAssNameC = *Bio::Emboss::ajSeqAssNameC;
*Bio::Emboss::Seq::ajSeqAssSeq = *Bio::Emboss::ajSeqAssSeq;
*Bio::Emboss::Seq::ajSeqAssSeqC = *Bio::Emboss::ajSeqAssSeqC;
*Bio::Emboss::Seq::ajSeqAssSeqCI = *Bio::Emboss::ajSeqAssSeqCI;
*Bio::Emboss::Seq::ajSeqAssSv = *Bio::Emboss::ajSeqAssSv;
*Bio::Emboss::Seq::ajSeqAssSvC = *Bio::Emboss::ajSeqAssSvC;
*Bio::Emboss::Seq::ajSeqAssUfo = *Bio::Emboss::ajSeqAssUfo;
*Bio::Emboss::Seq::ajSeqAssUfoC = *Bio::Emboss::ajSeqAssUfoC;
*Bio::Emboss::Seq::ajSeqAssUsa = *Bio::Emboss::ajSeqAssUsa;
*Bio::Emboss::Seq::ajSeqAssUsaC = *Bio::Emboss::ajSeqAssUsaC;
*Bio::Emboss::Seq::ajSeqBegin = *Bio::Emboss::ajSeqBegin;
*Bio::Emboss::Seq::ajSeqChar = *Bio::Emboss::ajSeqChar;
*Bio::Emboss::Seq::ajSeqCharCopy = *Bio::Emboss::ajSeqCharCopy;
*Bio::Emboss::Seq::ajSeqCharCopyL = *Bio::Emboss::ajSeqCharCopyL;
*Bio::Emboss::Seq::ajSeqCheckGcg = *Bio::Emboss::ajSeqCheckGcg;
*Bio::Emboss::Seq::ajSeqCompOnly = *Bio::Emboss::ajSeqCompOnly;
*Bio::Emboss::Seq::ajSeqCopyFeat = *Bio::Emboss::ajSeqCopyFeat;
*Bio::Emboss::Seq::ajSeqEnd = *Bio::Emboss::ajSeqEnd;
*Bio::Emboss::Seq::ajSeqGetAcc = *Bio::Emboss::ajSeqGetAcc;
*Bio::Emboss::Seq::ajSeqGetDesc = *Bio::Emboss::ajSeqGetDesc;
*Bio::Emboss::Seq::ajSeqGetEntry = *Bio::Emboss::ajSeqGetEntry;
*Bio::Emboss::Seq::ajSeqGetGi = *Bio::Emboss::ajSeqGetGi;
*Bio::Emboss::Seq::ajSeqGetName = *Bio::Emboss::ajSeqGetName;
*Bio::Emboss::Seq::ajSeqGetReverse = *Bio::Emboss::ajSeqGetReverse;
*Bio::Emboss::Seq::ajSeqGetReversed = *Bio::Emboss::ajSeqGetReversed;
*Bio::Emboss::Seq::ajSeqGetSv = *Bio::Emboss::ajSeqGetSv;
*Bio::Emboss::Seq::ajSeqGetTax = *Bio::Emboss::ajSeqGetTax;
*Bio::Emboss::Seq::ajSeqGetUsa = *Bio::Emboss::ajSeqGetUsa;
*Bio::Emboss::Seq::ajSeqLen = *Bio::Emboss::ajSeqLen;
*Bio::Emboss::Seq::ajSeqMakeUsa = *Bio::Emboss::ajSeqMakeUsa;
*Bio::Emboss::Seq::ajSeqMakeUsaS = *Bio::Emboss::ajSeqMakeUsaS;
*Bio::Emboss::Seq::ajSeqName = *Bio::Emboss::ajSeqName;
*Bio::Emboss::Seq::ajSeqNewS = *Bio::Emboss::ajSeqNewS;
*Bio::Emboss::Seq::ajSeqOffset = *Bio::Emboss::ajSeqOffset;
*Bio::Emboss::Seq::ajSeqOffend = *Bio::Emboss::ajSeqOffend;
*Bio::Emboss::Seq::ajSeqPos = *Bio::Emboss::ajSeqPos;
*Bio::Emboss::Seq::ajSeqPosI = *Bio::Emboss::ajSeqPosI;
*Bio::Emboss::Seq::ajSeqReplace = *Bio::Emboss::ajSeqReplace;
*Bio::Emboss::Seq::ajSeqReplaceC = *Bio::Emboss::ajSeqReplaceC;
*Bio::Emboss::Seq::ajSeqRev = *Bio::Emboss::ajSeqRev;
*Bio::Emboss::Seq::ajSeqReverse = *Bio::Emboss::ajSeqReverse;
*Bio::Emboss::Seq::ajSeqRevOnly = *Bio::Emboss::ajSeqRevOnly;
*Bio::Emboss::Seq::ajSeqSetRangeDir = *Bio::Emboss::ajSeqSetRangeDir;
*Bio::Emboss::Seq::ajSeqStr = *Bio::Emboss::ajSeqStr;
*Bio::Emboss::Seq::ajSeqStrCopy = *Bio::Emboss::ajSeqStrCopy;
*Bio::Emboss::Seq::ajSeqToLower = *Bio::Emboss::ajSeqToLower;
*Bio::Emboss::Seq::ajSeqToUpper = *Bio::Emboss::ajSeqToUpper;
*Bio::Emboss::Seq::ajSeqTrueBegin = *Bio::Emboss::ajSeqTrueBegin;
*Bio::Emboss::Seq::ajSeqTrueEnd = *Bio::Emboss::ajSeqTrueEnd;
*Bio::Emboss::Seq::ajSeqTrueLen = *Bio::Emboss::ajSeqTrueLen;
*Bio::Emboss::Seq::ajSeqTruePos = *Bio::Emboss::ajSeqTruePos;
*Bio::Emboss::Seq::ajSeqTruePosI = *Bio::Emboss::ajSeqTruePosI;

*Bio::Emboss::SeqCvt::ajSeqCvtTrace = *Bio::Emboss::ajSeqCvtTrace;
*Bio::Emboss::SeqCvt::ajSeqCvtDel = *Bio::Emboss::ajSeqCvtDel;
*Bio::Emboss::SeqCvt::ajSeqCvtLen = *Bio::Emboss::ajSeqCvtLen;
*Bio::Emboss::SeqCvt::ajSeqCvtK = *Bio::Emboss::ajSeqCvtK;
*Bio::Emboss::SeqCvt::ajSeqCvtKS = *Bio::Emboss::ajSeqCvtKS;
*Bio::Emboss::SeqCvt::ajSeqCvtKSRow = *Bio::Emboss::ajSeqCvtKSRow;
*Bio::Emboss::SeqCvt::ajSeqCvtKSColumn = *Bio::Emboss::ajSeqCvtKSColumn;

*Bio::Emboss::SeqQuery::ajNamDbData = *Bio::Emboss::ajNamDbData;
*Bio::Emboss::SeqQuery::ajNamDbQuery = *Bio::Emboss::ajNamDbQuery;
*Bio::Emboss::SeqQuery::ajSeqQueryDel = *Bio::Emboss::ajSeqQueryDel;
*Bio::Emboss::SeqQuery::ajSeqQueryClear = *Bio::Emboss::ajSeqQueryClear;
*Bio::Emboss::SeqQuery::ajSeqQueryWild = *Bio::Emboss::ajSeqQueryWild;
*Bio::Emboss::SeqQuery::ajSeqQueryStarclear = *Bio::Emboss::ajSeqQueryStarclear;
*Bio::Emboss::SeqQuery::ajSeqQueryIs = *Bio::Emboss::ajSeqQueryIs;
*Bio::Emboss::SeqQuery::ajSeqQueryTrace = *Bio::Emboss::ajSeqQueryTrace;

*Bio::Emboss::Seqall::ajSeqallDel = *Bio::Emboss::ajSeqallDel;
*Bio::Emboss::Seqall::ajSeqallSetRange = *Bio::Emboss::ajSeqallSetRange;
*Bio::Emboss::Seqall::ajSeqallSetRangeRev = *Bio::Emboss::ajSeqallSetRangeRev;
*Bio::Emboss::Seqall::ajSeqallBegin = *Bio::Emboss::ajSeqallBegin;
*Bio::Emboss::Seqall::ajSeqallEnd = *Bio::Emboss::ajSeqallEnd;
*Bio::Emboss::Seqall::ajSeqallGetFilename = *Bio::Emboss::ajSeqallGetFilename;
*Bio::Emboss::Seqall::ajSeqallLen = *Bio::Emboss::ajSeqallLen;
*Bio::Emboss::Seqall::ajSeqallGetName = *Bio::Emboss::ajSeqallGetName;
*Bio::Emboss::Seqall::ajSeqallGetNameSeq = *Bio::Emboss::ajSeqallGetNameSeq;
*Bio::Emboss::Seqall::ajSeqallGetRange = *Bio::Emboss::ajSeqallGetRange;
*Bio::Emboss::Seqall::ajSeqallGetUsa = *Bio::Emboss::ajSeqallGetUsa;
*Bio::Emboss::Seqall::ajSeqallClear = *Bio::Emboss::ajSeqallClear;
*Bio::Emboss::Seqall::ajSeqallNext = *Bio::Emboss::ajSeqallNext;
*Bio::Emboss::Seqall::ajSeqallReverse = *Bio::Emboss::ajSeqallReverse;
*Bio::Emboss::Seqall::ajSeqallToLower = *Bio::Emboss::ajSeqallToLower;
*Bio::Emboss::Seqall::ajSeqallToUpper = *Bio::Emboss::ajSeqallToUpper;

*Bio::Emboss::Seqin::ajSeqAccessAsis = *Bio::Emboss::ajSeqAccessAsis;
*Bio::Emboss::Seqin::ajSeqAccessFile = *Bio::Emboss::ajSeqAccessFile;
*Bio::Emboss::Seqin::ajSeqAccessOffset = *Bio::Emboss::ajSeqAccessOffset;
*Bio::Emboss::Seqin::ajSeqinDel = *Bio::Emboss::ajSeqinDel;
*Bio::Emboss::Seqin::ajSeqinUsa = *Bio::Emboss::ajSeqinUsa;
*Bio::Emboss::Seqin::ajSeqinSetNuc = *Bio::Emboss::ajSeqinSetNuc;
*Bio::Emboss::Seqin::ajSeqinSetProt = *Bio::Emboss::ajSeqinSetProt;
*Bio::Emboss::Seqin::ajSeqinSetRange = *Bio::Emboss::ajSeqinSetRange;
*Bio::Emboss::Seqin::ajSeqinClearPos = *Bio::Emboss::ajSeqinClearPos;
*Bio::Emboss::Seqin::ajSeqinClear = *Bio::Emboss::ajSeqinClear;
*Bio::Emboss::Seqin::ajSeqinTrace = *Bio::Emboss::ajSeqinTrace;

*Bio::Emboss::Seqout::ajSeqoutDel = *Bio::Emboss::ajSeqoutDel;
*Bio::Emboss::Seqout::ajSeqAllWrite = *Bio::Emboss::ajSeqAllWrite;
*Bio::Emboss::Seqout::ajSeqsetWrite = *Bio::Emboss::ajSeqsetWrite;
*Bio::Emboss::Seqout::ajSeqWriteClose = *Bio::Emboss::ajSeqWriteClose;
*Bio::Emboss::Seqout::ajSeqWrite = *Bio::Emboss::ajSeqWrite;
*Bio::Emboss::Seqout::ajSeqFileNewOut = *Bio::Emboss::ajSeqFileNewOut;
*Bio::Emboss::Seqout::ajSeqoutOpen = *Bio::Emboss::ajSeqoutOpen;
*Bio::Emboss::Seqout::ajSeqOutSetFormat = *Bio::Emboss::ajSeqOutSetFormat;
*Bio::Emboss::Seqout::ajSeqOutSetFormatC = *Bio::Emboss::ajSeqOutSetFormatC;
*Bio::Emboss::Seqout::ajSeqoutUsa = *Bio::Emboss::ajSeqoutUsa;
*Bio::Emboss::Seqout::ajSeqoutClear = *Bio::Emboss::ajSeqoutClear;
*Bio::Emboss::Seqout::ajSeqoutCheckGcg = *Bio::Emboss::ajSeqoutCheckGcg;
*Bio::Emboss::Seqout::ajSeqoutDefName = *Bio::Emboss::ajSeqoutDefName;
*Bio::Emboss::Seqout::ajSeqoutTrace = *Bio::Emboss::ajSeqoutTrace;
*Bio::Emboss::Seqout::ajSeqoutCount = *Bio::Emboss::ajSeqoutCount;

*Bio::Emboss::Seqset::ajAlignConsStats = *Bio::Emboss::ajAlignConsStats;
*Bio::Emboss::Seqset::ajSeqsetDel = *Bio::Emboss::ajSeqsetDel;
*Bio::Emboss::Seqset::ajSeqsetDelarray = *Bio::Emboss::ajSeqsetDelarray;
*Bio::Emboss::Seqset::ajSeqsetGetFilename = *Bio::Emboss::ajSeqsetGetFilename;
*Bio::Emboss::Seqset::ajSeqsetGetFormat = *Bio::Emboss::ajSeqsetGetFormat;
*Bio::Emboss::Seqset::ajSeqsetGetRange = *Bio::Emboss::ajSeqsetGetRange;
*Bio::Emboss::Seqset::ajSeqsetGetUsa = *Bio::Emboss::ajSeqsetGetUsa;
*Bio::Emboss::Seqset::ajSeqsetFill = *Bio::Emboss::ajSeqsetFill;
*Bio::Emboss::Seqset::ajSeqsetReverse = *Bio::Emboss::ajSeqsetReverse;
*Bio::Emboss::Seqset::ajSeqsetSetRange = *Bio::Emboss::ajSeqsetSetRange;
*Bio::Emboss::Seqset::ajSeqsetToLower = *Bio::Emboss::ajSeqsetToLower;
*Bio::Emboss::Seqset::ajSeqsetToUpper = *Bio::Emboss::ajSeqsetToUpper;
*Bio::Emboss::Seqset::ajSeqsetTrim = *Bio::Emboss::ajSeqsetTrim;
*Bio::Emboss::Seqset::ajSeqsetAcc = *Bio::Emboss::ajSeqsetAcc;
*Bio::Emboss::Seqset::ajSeqsetBegin = *Bio::Emboss::ajSeqsetBegin;
*Bio::Emboss::Seqset::ajSeqsetEnd = *Bio::Emboss::ajSeqsetEnd;
*Bio::Emboss::Seqset::ajSeqsetLen = *Bio::Emboss::ajSeqsetLen;
*Bio::Emboss::Seqset::ajSeqsetGetName = *Bio::Emboss::ajSeqsetGetName;
*Bio::Emboss::Seqset::ajSeqsetName = *Bio::Emboss::ajSeqsetName;
*Bio::Emboss::Seqset::ajSeqsetSeq = *Bio::Emboss::ajSeqsetSeq;
*Bio::Emboss::Seqset::ajSeqsetGetSeq = *Bio::Emboss::ajSeqsetGetSeq;
*Bio::Emboss::Seqset::ajSeqsetGetSeqArray = *Bio::Emboss::ajSeqsetGetSeqArray;
*Bio::Emboss::Seqset::ajSeqsetSize = *Bio::Emboss::ajSeqsetSize;
*Bio::Emboss::Seqset::ajSeqsetTotweight = *Bio::Emboss::ajSeqsetTotweight;
*Bio::Emboss::Seqset::ajSeqsetWeight = *Bio::Emboss::ajSeqsetWeight;
*Bio::Emboss::Seqset::ajSeqsetIsDna = *Bio::Emboss::ajSeqsetIsDna;
*Bio::Emboss::Seqset::ajSeqsetIsNuc = *Bio::Emboss::ajSeqsetIsNuc;
*Bio::Emboss::Seqset::ajSeqsetIsProt = *Bio::Emboss::ajSeqsetIsProt;
*Bio::Emboss::Seqset::ajSeqsetIsRna = *Bio::Emboss::ajSeqsetIsRna;
*Bio::Emboss::Seqset::ajSeqsetRead = *Bio::Emboss::ajSeqsetRead;
*Bio::Emboss::Seqset::ajSeqsetFromList = *Bio::Emboss::ajSeqsetFromList;
*Bio::Emboss::Seqset::ajSeqsetFromPair = *Bio::Emboss::ajSeqsetFromPair;
*Bio::Emboss::Seqset::ajSeqsetApp = *Bio::Emboss::ajSeqsetApp;
*Bio::Emboss::Seqset::ajSeqsetSetNuc = *Bio::Emboss::ajSeqsetSetNuc;
*Bio::Emboss::Seqset::ajSeqsetSetProt = *Bio::Emboss::ajSeqsetSetProt;

*Bio::Emboss::Short::ajShortDel = *Bio::Emboss::ajShortDel;
*Bio::Emboss::Short::ajShortGet = *Bio::Emboss::ajShortGet;
*Bio::Emboss::Short::ajShortPut = *Bio::Emboss::ajShortPut;
*Bio::Emboss::Short::ajShortShort = *Bio::Emboss::ajShortShort;
*Bio::Emboss::Short::ajShortLen = *Bio::Emboss::ajShortLen;

*Bio::Emboss::Short2d::ajShort2dDel = *Bio::Emboss::ajShort2dDel;
*Bio::Emboss::Short2d::ajShort2dGet = *Bio::Emboss::ajShort2dGet;
*Bio::Emboss::Short2d::ajShort2dPut = *Bio::Emboss::ajShort2dPut;
*Bio::Emboss::Short2d::ajShort2dLen = *Bio::Emboss::ajShort2dLen;
*Bio::Emboss::Short2d::ajShort2dShort = *Bio::Emboss::ajShort2dShort;

*Bio::Emboss::Short3d::ajShort3dDel = *Bio::Emboss::ajShort3dDel;
*Bio::Emboss::Short3d::ajShort3dGet = *Bio::Emboss::ajShort3dGet;
*Bio::Emboss::Short3d::ajShort3dPut = *Bio::Emboss::ajShort3dPut;
*Bio::Emboss::Short3d::ajShort3dLen = *Bio::Emboss::ajShort3dLen;
*Bio::Emboss::Short3d::ajShort3dShort = *Bio::Emboss::ajShort3dShort;

*Bio::Emboss::Str::ajAlignFormatDefault = *Bio::Emboss::ajAlignFormatDefault;
*Bio::Emboss::Str::ajAlignFindFormat = *Bio::Emboss::ajAlignFindFormat;
*Bio::Emboss::Str::ajFloatParse = *Bio::Emboss::ajFloatParse;
*Bio::Emboss::Str::ajArrCommaList = *Bio::Emboss::ajArrCommaList;
*Bio::Emboss::Str::ajArrIntLine = *Bio::Emboss::ajArrIntLine;
*Bio::Emboss::Str::ajCodBacktranslate = *Bio::Emboss::ajCodBacktranslate;
*Bio::Emboss::Str::ajCodBacktranslateAmbig = *Bio::Emboss::ajCodBacktranslateAmbig;
*Bio::Emboss::Str::ajCodIndex = *Bio::Emboss::ajCodIndex;
*Bio::Emboss::Str::ajCodOutFormat = *Bio::Emboss::ajCodOutFormat;
*Bio::Emboss::Str::ajProbScore = *Bio::Emboss::ajProbScore;
*Bio::Emboss::Str::ajMeltEnergy = *Bio::Emboss::ajMeltEnergy;
*Bio::Emboss::Str::ajTm = *Bio::Emboss::ajTm;
*Bio::Emboss::Str::ajMeltGC = *Bio::Emboss::ajMeltGC;
*Bio::Emboss::Str::ajFeattabInNewSS = *Bio::Emboss::ajFeattabInNewSS;
*Bio::Emboss::Str::ajFeattabInNewSSF = *Bio::Emboss::ajFeattabInNewSSF;
*Bio::Emboss::Str::ajFeattabOutNewSSF = *Bio::Emboss::ajFeattabOutNewSSF;
*Bio::Emboss::Str::ajFeatOutFormatDefault = *Bio::Emboss::ajFeatOutFormatDefault;
*Bio::Emboss::Str::ajFeatLocToSeq = *Bio::Emboss::ajFeatLocToSeq;
*Bio::Emboss::Str::ajFeatGetLocs = *Bio::Emboss::ajFeatGetLocs;
*Bio::Emboss::Str::ajFeatGetTrans = *Bio::Emboss::ajFeatGetTrans;
*Bio::Emboss::Str::ajFeattableNew = *Bio::Emboss::ajFeattableNew;
*Bio::Emboss::Str::ajFeattableNewDna = *Bio::Emboss::ajFeattableNewDna;
*Bio::Emboss::Str::ajFeattableNewProt = *Bio::Emboss::ajFeattableNewProt;
*Bio::Emboss::Str::ajOutfileNew = *Bio::Emboss::ajOutfileNew;
*Bio::Emboss::Str::ajDirNew = *Bio::Emboss::ajDirNew;
*Bio::Emboss::Str::ajDirNewS = *Bio::Emboss::ajDirNewS;
*Bio::Emboss::Str::ajDirNewSS = *Bio::Emboss::ajDirNewSS;
*Bio::Emboss::Str::ajDiroutNew = *Bio::Emboss::ajDiroutNew;
*Bio::Emboss::Str::ajDiroutNewS = *Bio::Emboss::ajDiroutNewS;
*Bio::Emboss::Str::ajDiroutNewSS = *Bio::Emboss::ajDiroutNewSS;
*Bio::Emboss::Str::ajFileNewInPipe = *Bio::Emboss::ajFileNewInPipe;
*Bio::Emboss::Str::ajFileNewIn = *Bio::Emboss::ajFileNewIn;
*Bio::Emboss::Str::ajFileNewApp = *Bio::Emboss::ajFileNewApp;
*Bio::Emboss::Str::ajFileNewOut = *Bio::Emboss::ajFileNewOut;
*Bio::Emboss::Str::ajFileNewOutD = *Bio::Emboss::ajFileNewOutD;
*Bio::Emboss::Str::ajFileSetDir = *Bio::Emboss::ajFileSetDir;
*Bio::Emboss::Str::ajFileHasDir = *Bio::Emboss::ajFileHasDir;
*Bio::Emboss::Str::ajFileDataNew = *Bio::Emboss::ajFileDataNew;
*Bio::Emboss::Str::ajFileDataDirNew = *Bio::Emboss::ajFileDataDirNew;
*Bio::Emboss::Str::ajFileNameShorten = *Bio::Emboss::ajFileNameShorten;
*Bio::Emboss::Str::ajFileNameTrim = *Bio::Emboss::ajFileNameTrim;
*Bio::Emboss::Str::ajFileDataNewWrite = *Bio::Emboss::ajFileDataNewWrite;
*Bio::Emboss::Str::ajFileDir = *Bio::Emboss::ajFileDir;
*Bio::Emboss::Str::ajFileDirPath = *Bio::Emboss::ajFileDirPath;
*Bio::Emboss::Str::ajFileGetwd = *Bio::Emboss::ajFileGetwd;
*Bio::Emboss::Str::ajFileDirUp = *Bio::Emboss::ajFileDirUp;
*Bio::Emboss::Str::ajFileDirFix = *Bio::Emboss::ajFileDirFix;
*Bio::Emboss::Str::ajFileStat = *Bio::Emboss::ajFileStat;
*Bio::Emboss::Str::ajFileLength = *Bio::Emboss::ajFileLength;
*Bio::Emboss::Str::ajFileBuffNewIn = *Bio::Emboss::ajFileBuffNewIn;
*Bio::Emboss::Str::ajFileBuffNewS = *Bio::Emboss::ajFileBuffNewS;
*Bio::Emboss::Str::ajFileBuffNewDW = *Bio::Emboss::ajFileBuffNewDW;
*Bio::Emboss::Str::ajFileBuffNewDWE = *Bio::Emboss::ajFileBuffNewDWE;
*Bio::Emboss::Str::ajFileBuffNewDC = *Bio::Emboss::ajFileBuffNewDC;
*Bio::Emboss::Str::ajFileBuffNewDF = *Bio::Emboss::ajFileBuffNewDF;
*Bio::Emboss::Str::ajFileNewDW = *Bio::Emboss::ajFileNewDW;
*Bio::Emboss::Str::ajFileNewDWE = *Bio::Emboss::ajFileNewDWE;
*Bio::Emboss::Str::ajFileNewDF = *Bio::Emboss::ajFileNewDF;
*Bio::Emboss::Str::ajFileNewDC = *Bio::Emboss::ajFileNewDC;
*Bio::Emboss::Str::ajFileNameDir = *Bio::Emboss::ajFileNameDir;
*Bio::Emboss::Str::ajFileNameDirSet = *Bio::Emboss::ajFileNameDirSet;
*Bio::Emboss::Str::ajFileNameDirSetC = *Bio::Emboss::ajFileNameDirSetC;
*Bio::Emboss::Str::ajFileNameExt = *Bio::Emboss::ajFileNameExt;
*Bio::Emboss::Str::ajFileNameExtC = *Bio::Emboss::ajFileNameExtC;
*Bio::Emboss::Str::ajFileScan = *Bio::Emboss::ajFileScan;
*Bio::Emboss::Str::ajFileTestSkip = *Bio::Emboss::ajFileTestSkip;
*Bio::Emboss::Str::ajFileDirTrim = *Bio::Emboss::ajFileDirTrim;
*Bio::Emboss::Str::ajFileExtnTrim = *Bio::Emboss::ajFileExtnTrim;
*Bio::Emboss::Str::ajFileDirExtnTrim = *Bio::Emboss::ajFileDirExtnTrim;
*Bio::Emboss::Str::ajFileFileList = *Bio::Emboss::ajFileFileList;
*Bio::Emboss::Str::ajFmtPrintS = *Bio::Emboss::ajFmtPrintS;
*Bio::Emboss::Str::ajFmtPrintAppS = *Bio::Emboss::ajFmtPrintAppS;
*Bio::Emboss::Str::ajFmtScanS = *Bio::Emboss::ajFmtScanS;
*Bio::Emboss::Str::ajGraphCheckColour = *Bio::Emboss::ajGraphCheckColour;
*Bio::Emboss::Str::ajGraphGetBaseColourProt = *Bio::Emboss::ajGraphGetBaseColourProt;
*Bio::Emboss::Str::ajGraphGetBaseColourNuc = *Bio::Emboss::ajGraphGetBaseColourNuc;
*Bio::Emboss::Str::ajListstrNewArgs = *Bio::Emboss::ajListstrNewArgs;
*Bio::Emboss::Str::ajSp64Crc = *Bio::Emboss::ajSp64Crc;
*Bio::Emboss::Str::ajUserGet = *Bio::Emboss::ajUserGet;
*Bio::Emboss::Str::ajNamDbDetails = *Bio::Emboss::ajNamDbDetails;
*Bio::Emboss::Str::ajNamIsDbname = *Bio::Emboss::ajNamIsDbname;
*Bio::Emboss::Str::ajNamGetenv = *Bio::Emboss::ajNamGetenv;
*Bio::Emboss::Str::ajNamGetValue = *Bio::Emboss::ajNamGetValue;
*Bio::Emboss::Str::ajNamDatabase = *Bio::Emboss::ajNamDatabase;
*Bio::Emboss::Str::ajNamDbTest = *Bio::Emboss::ajNamDbTest;
*Bio::Emboss::Str::ajNamDbGetUrl = *Bio::Emboss::ajNamDbGetUrl;
*Bio::Emboss::Str::ajNamDbGetDbalias = *Bio::Emboss::ajNamDbGetDbalias;
*Bio::Emboss::Str::ajNamRootInstall = *Bio::Emboss::ajNamRootInstall;
*Bio::Emboss::Str::ajNamRootPack = *Bio::Emboss::ajNamRootPack;
*Bio::Emboss::Str::ajNamRootVersion = *Bio::Emboss::ajNamRootVersion;
*Bio::Emboss::Str::ajNamRoot = *Bio::Emboss::ajNamRoot;
*Bio::Emboss::Str::ajNamRootBase = *Bio::Emboss::ajNamRootBase;
*Bio::Emboss::Str::ajNamResolve = *Bio::Emboss::ajNamResolve;
*Bio::Emboss::Str::ajNamRsAttrValue = *Bio::Emboss::ajNamRsAttrValue;
*Bio::Emboss::Str::ajNamRsListValue = *Bio::Emboss::ajNamRsListValue;
*Bio::Emboss::Str::ajPhyloDistRead = *Bio::Emboss::ajPhyloDistRead;
*Bio::Emboss::Str::ajPhyloFreqRead = *Bio::Emboss::ajPhyloFreqRead;
*Bio::Emboss::Str::ajPhyloPropRead = *Bio::Emboss::ajPhyloPropRead;
*Bio::Emboss::Str::ajPhyloStateRead = *Bio::Emboss::ajPhyloStateRead;
*Bio::Emboss::Str::ajPhyloTreeRead = *Bio::Emboss::ajPhyloTreeRead;
*Bio::Emboss::Str::ajRangeGet = *Bio::Emboss::ajRangeGet;
*Bio::Emboss::Str::ajRangeGetLimits = *Bio::Emboss::ajRangeGetLimits;
*Bio::Emboss::Str::ajRangeFile = *Bio::Emboss::ajRangeFile;
*Bio::Emboss::Str::ajRangeFileLimits = *Bio::Emboss::ajRangeFileLimits;
*Bio::Emboss::Str::ajRegComp = *Bio::Emboss::ajRegComp;
*Bio::Emboss::Str::ajRegCompCase = *Bio::Emboss::ajRegCompCase;
*Bio::Emboss::Str::ajReportFormatDefault = *Bio::Emboss::ajReportFormatDefault;
*Bio::Emboss::Str::ajReportFindFormat = *Bio::Emboss::ajReportFindFormat;
*Bio::Emboss::Str::ajSeqNewNameS = *Bio::Emboss::ajSeqNewNameS;
*Bio::Emboss::Str::ajSeqNewRangeS = *Bio::Emboss::ajSeqNewRangeS;
*Bio::Emboss::Str::ajSeqNumS = *Bio::Emboss::ajSeqNumS;
*Bio::Emboss::Str::ajSeqGapCountS = *Bio::Emboss::ajSeqGapCountS;
*Bio::Emboss::Str::ajSeqGapStandardS = *Bio::Emboss::ajSeqGapStandardS;
*Bio::Emboss::Str::ajIsAccession = *Bio::Emboss::ajIsAccession;
*Bio::Emboss::Str::ajIsSeqversion = *Bio::Emboss::ajIsSeqversion;
*Bio::Emboss::Str::ajSeqstrReverse = *Bio::Emboss::ajSeqstrReverse;
*Bio::Emboss::Str::ajSeqstrComplementOnly = *Bio::Emboss::ajSeqstrComplementOnly;
*Bio::Emboss::Str::ajSeqstrCalcCrc = *Bio::Emboss::ajSeqstrCalcCrc;
*Bio::Emboss::Str::ajSeqMethodTest = *Bio::Emboss::ajSeqMethodTest;
*Bio::Emboss::Str::ajSeqMethod = *Bio::Emboss::ajSeqMethod;
*Bio::Emboss::Str::ajSeqallFile = *Bio::Emboss::ajSeqallFile;
*Bio::Emboss::Str::ajSeqFormatTest = *Bio::Emboss::ajSeqFormatTest;
*Bio::Emboss::Str::ajSeqParseFasta = *Bio::Emboss::ajSeqParseFasta;
*Bio::Emboss::Str::ajSeqParseNcbi = *Bio::Emboss::ajSeqParseNcbi;
*Bio::Emboss::Str::ajSeqGetFromUsa = *Bio::Emboss::ajSeqGetFromUsa;
*Bio::Emboss::Str::ajSeqsetGetFromUsa = *Bio::Emboss::ajSeqsetGetFromUsa;
*Bio::Emboss::Str::ajSeqTypeCheckS = *Bio::Emboss::ajSeqTypeCheckS;
*Bio::Emboss::Str::ajSeqTypeNucS = *Bio::Emboss::ajSeqTypeNucS;
*Bio::Emboss::Str::ajSeqTypeDnaS = *Bio::Emboss::ajSeqTypeDnaS;
*Bio::Emboss::Str::ajSeqTypeRnaS = *Bio::Emboss::ajSeqTypeRnaS;
*Bio::Emboss::Str::ajSeqTypeGapdnaS = *Bio::Emboss::ajSeqTypeGapdnaS;
*Bio::Emboss::Str::ajSeqTypeGaprnaS = *Bio::Emboss::ajSeqTypeGaprnaS;
*Bio::Emboss::Str::ajSeqTypeGapnucS = *Bio::Emboss::ajSeqTypeGapnucS;
*Bio::Emboss::Str::ajSeqTypeAnyprotS = *Bio::Emboss::ajSeqTypeAnyprotS;
*Bio::Emboss::Str::ajSeqTypeProtS = *Bio::Emboss::ajSeqTypeProtS;
*Bio::Emboss::Str::ajSeqTypeGapanyS = *Bio::Emboss::ajSeqTypeGapanyS;
*Bio::Emboss::Str::ajSeqGapS = *Bio::Emboss::ajSeqGapS;
*Bio::Emboss::Str::ajSeqTypeIsProt = *Bio::Emboss::ajSeqTypeIsProt;
*Bio::Emboss::Str::ajSeqTypeIsNuc = *Bio::Emboss::ajSeqTypeIsNuc;
*Bio::Emboss::Str::ajSeqTypeIsAny = *Bio::Emboss::ajSeqTypeIsAny;
*Bio::Emboss::Str::ajSeqTypeSummary = *Bio::Emboss::ajSeqTypeSummary;
*Bio::Emboss::Str::ajSeqOutFormatSingle = *Bio::Emboss::ajSeqOutFormatSingle;
*Bio::Emboss::Str::ajSeqOutFormatDefault = *Bio::Emboss::ajSeqOutFormatDefault;
*Bio::Emboss::Str::ajSeqFindOutFormat = *Bio::Emboss::ajSeqFindOutFormat;
*Bio::Emboss::Str::ajCharNewS = *Bio::Emboss::ajCharNewS;
*Bio::Emboss::Str::ajCharNewResS = *Bio::Emboss::ajCharNewResS;
*Bio::Emboss::Str::ajStrNewS = *Bio::Emboss::ajStrNewS;
*Bio::Emboss::Str::ajStrNewRef = *Bio::Emboss::ajStrNewRef;
*Bio::Emboss::Str::ajStrNewResS = *Bio::Emboss::ajStrNewResS;
*Bio::Emboss::Str::ajStrDel = *Bio::Emboss::ajStrDel;
*Bio::Emboss::Str::ajStrDelStatic = *Bio::Emboss::ajStrDelStatic;
*Bio::Emboss::Str::ajStrDelarray = *Bio::Emboss::ajStrDelarray;
*Bio::Emboss::Str::ajStrAssignC = *Bio::Emboss::ajStrAssignC;
*Bio::Emboss::Str::ajStrAssignK = *Bio::Emboss::ajStrAssignK;
*Bio::Emboss::Str::ajStrAssignS = *Bio::Emboss::ajStrAssignS;
*Bio::Emboss::Str::ajStrAssignEmptyC = *Bio::Emboss::ajStrAssignEmptyC;
*Bio::Emboss::Str::ajStrAssignEmptyS = *Bio::Emboss::ajStrAssignEmptyS;
*Bio::Emboss::Str::ajStrAssignLenC = *Bio::Emboss::ajStrAssignLenC;
*Bio::Emboss::Str::ajStrAssignRef = *Bio::Emboss::ajStrAssignRef;
*Bio::Emboss::Str::ajStrAssignResC = *Bio::Emboss::ajStrAssignResC;
*Bio::Emboss::Str::ajStrAssignResS = *Bio::Emboss::ajStrAssignResS;
*Bio::Emboss::Str::ajStrAssignSubC = *Bio::Emboss::ajStrAssignSubC;
*Bio::Emboss::Str::ajStrAssignSubS = *Bio::Emboss::ajStrAssignSubS;
*Bio::Emboss::Str::ajStrAppendC = *Bio::Emboss::ajStrAppendC;
*Bio::Emboss::Str::ajStrAppendK = *Bio::Emboss::ajStrAppendK;
*Bio::Emboss::Str::ajStrAppendS = *Bio::Emboss::ajStrAppendS;
*Bio::Emboss::Str::ajStrAppendCountK = *Bio::Emboss::ajStrAppendCountK;
*Bio::Emboss::Str::ajStrAppendLenC = *Bio::Emboss::ajStrAppendLenC;
*Bio::Emboss::Str::ajStrAppendSubS = *Bio::Emboss::ajStrAppendSubS;
*Bio::Emboss::Str::ajStrInsertC = *Bio::Emboss::ajStrInsertC;
*Bio::Emboss::Str::ajStrInsertK = *Bio::Emboss::ajStrInsertK;
*Bio::Emboss::Str::ajStrInsertS = *Bio::Emboss::ajStrInsertS;
*Bio::Emboss::Str::ajStrJoinC = *Bio::Emboss::ajStrJoinC;
*Bio::Emboss::Str::ajStrJoinS = *Bio::Emboss::ajStrJoinS;
*Bio::Emboss::Str::ajStrMask = *Bio::Emboss::ajStrMask;
*Bio::Emboss::Str::ajStrPasteS = *Bio::Emboss::ajStrPasteS;
*Bio::Emboss::Str::ajStrPasteCountK = *Bio::Emboss::ajStrPasteCountK;
*Bio::Emboss::Str::ajStrPasteMaxC = *Bio::Emboss::ajStrPasteMaxC;
*Bio::Emboss::Str::ajStrPasteMaxS = *Bio::Emboss::ajStrPasteMaxS;
*Bio::Emboss::Str::ajStrCutComments = *Bio::Emboss::ajStrCutComments;
*Bio::Emboss::Str::ajStrCutCommentsStart = *Bio::Emboss::ajStrCutCommentsStart;
*Bio::Emboss::Str::ajStrCutEnd = *Bio::Emboss::ajStrCutEnd;
*Bio::Emboss::Str::ajStrCutRange = *Bio::Emboss::ajStrCutRange;
*Bio::Emboss::Str::ajStrCutStart = *Bio::Emboss::ajStrCutStart;
*Bio::Emboss::Str::ajStrKeepRange = *Bio::Emboss::ajStrKeepRange;
*Bio::Emboss::Str::ajStrKeepSetC = *Bio::Emboss::ajStrKeepSetC;
*Bio::Emboss::Str::ajStrKeepSetAlphaC = *Bio::Emboss::ajStrKeepSetAlphaC;
*Bio::Emboss::Str::ajStrQuoteStrip = *Bio::Emboss::ajStrQuoteStrip;
*Bio::Emboss::Str::ajStrQuoteStripAll = *Bio::Emboss::ajStrQuoteStripAll;
*Bio::Emboss::Str::ajStrRemoveGap = *Bio::Emboss::ajStrRemoveGap;
*Bio::Emboss::Str::ajStrRemoveHtml = *Bio::Emboss::ajStrRemoveHtml;
*Bio::Emboss::Str::ajStrRemoveLastNewline = *Bio::Emboss::ajStrRemoveLastNewline;
*Bio::Emboss::Str::ajStrRemoveSetC = *Bio::Emboss::ajStrRemoveSetC;
*Bio::Emboss::Str::ajStrRemoveWhite = *Bio::Emboss::ajStrRemoveWhite;
*Bio::Emboss::Str::ajStrRemoveWhiteExcess = *Bio::Emboss::ajStrRemoveWhiteExcess;
*Bio::Emboss::Str::ajStrRemoveWild = *Bio::Emboss::ajStrRemoveWild;
*Bio::Emboss::Str::ajStrTrimC = *Bio::Emboss::ajStrTrimC;
*Bio::Emboss::Str::ajStrTrimEndC = *Bio::Emboss::ajStrTrimEndC;
*Bio::Emboss::Str::ajStrTrimStartC = *Bio::Emboss::ajStrTrimStartC;
*Bio::Emboss::Str::ajStrTrimWhite = *Bio::Emboss::ajStrTrimWhite;
*Bio::Emboss::Str::ajStrTrimWhiteEnd = *Bio::Emboss::ajStrTrimWhiteEnd;
*Bio::Emboss::Str::ajStrTruncateLen = *Bio::Emboss::ajStrTruncateLen;
*Bio::Emboss::Str::ajStrTruncatePos = *Bio::Emboss::ajStrTruncatePos;
*Bio::Emboss::Str::ajStrExchangeCC = *Bio::Emboss::ajStrExchangeCC;
*Bio::Emboss::Str::ajStrExchangeCS = *Bio::Emboss::ajStrExchangeCS;
*Bio::Emboss::Str::ajStrExchangeKK = *Bio::Emboss::ajStrExchangeKK;
*Bio::Emboss::Str::ajStrExchangeSC = *Bio::Emboss::ajStrExchangeSC;
*Bio::Emboss::Str::ajStrExchangeSS = *Bio::Emboss::ajStrExchangeSS;
*Bio::Emboss::Str::ajStrExchangeSetCC = *Bio::Emboss::ajStrExchangeSetCC;
*Bio::Emboss::Str::ajStrExchangeSetSS = *Bio::Emboss::ajStrExchangeSetSS;
*Bio::Emboss::Str::ajStrRandom = *Bio::Emboss::ajStrRandom;
*Bio::Emboss::Str::ajStrReverse = *Bio::Emboss::ajStrReverse;
*Bio::Emboss::Str::ajStrCalcCountC = *Bio::Emboss::ajStrCalcCountC;
*Bio::Emboss::Str::ajStrCalcCountK = *Bio::Emboss::ajStrCalcCountK;
*Bio::Emboss::Str::ajStrHasParentheses = *Bio::Emboss::ajStrHasParentheses;
*Bio::Emboss::Str::ajStrIsAlnum = *Bio::Emboss::ajStrIsAlnum;
*Bio::Emboss::Str::ajStrIsAlpha = *Bio::Emboss::ajStrIsAlpha;
*Bio::Emboss::Str::ajStrIsBool = *Bio::Emboss::ajStrIsBool;
*Bio::Emboss::Str::ajStrIsDouble = *Bio::Emboss::ajStrIsDouble;
*Bio::Emboss::Str::ajStrIsFloat = *Bio::Emboss::ajStrIsFloat;
*Bio::Emboss::Str::ajStrIsHex = *Bio::Emboss::ajStrIsHex;
*Bio::Emboss::Str::ajStrIsInt = *Bio::Emboss::ajStrIsInt;
*Bio::Emboss::Str::ajStrIsLong = *Bio::Emboss::ajStrIsLong;
*Bio::Emboss::Str::ajStrIsLower = *Bio::Emboss::ajStrIsLower;
*Bio::Emboss::Str::ajStrIsNum = *Bio::Emboss::ajStrIsNum;
*Bio::Emboss::Str::ajStrIsUpper = *Bio::Emboss::ajStrIsUpper;
*Bio::Emboss::Str::ajStrIsWhite = *Bio::Emboss::ajStrIsWhite;
*Bio::Emboss::Str::ajStrIsWild = *Bio::Emboss::ajStrIsWild;
*Bio::Emboss::Str::ajStrIsWord = *Bio::Emboss::ajStrIsWord;
*Bio::Emboss::Str::ajStrWhole = *Bio::Emboss::ajStrWhole;
*Bio::Emboss::Str::ajStrGetCharFirst = *Bio::Emboss::ajStrGetCharFirst;
*Bio::Emboss::Str::ajStrGetCharLast = *Bio::Emboss::ajStrGetCharLast;
*Bio::Emboss::Str::ajStrGetCharPos = *Bio::Emboss::ajStrGetCharPos;
*Bio::Emboss::Str::ajStrGetLen = *Bio::Emboss::ajStrGetLen;
*Bio::Emboss::Str::ajStrGetPtr = *Bio::Emboss::ajStrGetPtr;
*Bio::Emboss::Str::ajStrGetRes = *Bio::Emboss::ajStrGetRes;
*Bio::Emboss::Str::ajStrGetRoom = *Bio::Emboss::ajStrGetRoom;
*Bio::Emboss::Str::ajStrGetUse = *Bio::Emboss::ajStrGetUse;
*Bio::Emboss::Str::ajStrGetValid = *Bio::Emboss::ajStrGetValid;
*Bio::Emboss::Str::ajStrGetuniquePtr = *Bio::Emboss::ajStrGetuniquePtr;
*Bio::Emboss::Str::ajStrGetuniqueStr = *Bio::Emboss::ajStrGetuniqueStr;
*Bio::Emboss::Str::ajStrSetClear = *Bio::Emboss::ajStrSetClear;
*Bio::Emboss::Str::ajStrSetRes = *Bio::Emboss::ajStrSetRes;
*Bio::Emboss::Str::ajStrSetResRound = *Bio::Emboss::ajStrSetResRound;
*Bio::Emboss::Str::ajStrSetValid = *Bio::Emboss::ajStrSetValid;
*Bio::Emboss::Str::ajStrSetValidLen = *Bio::Emboss::ajStrSetValidLen;
*Bio::Emboss::Str::ajStrToBool = *Bio::Emboss::ajStrToBool;
*Bio::Emboss::Str::ajStrToDouble = *Bio::Emboss::ajStrToDouble;
*Bio::Emboss::Str::ajStrToFloat = *Bio::Emboss::ajStrToFloat;
*Bio::Emboss::Str::ajStrToHex = *Bio::Emboss::ajStrToHex;
*Bio::Emboss::Str::ajStrToInt = *Bio::Emboss::ajStrToInt;
*Bio::Emboss::Str::ajStrToLong = *Bio::Emboss::ajStrToLong;
*Bio::Emboss::Str::ajStrFromBool = *Bio::Emboss::ajStrFromBool;
*Bio::Emboss::Str::ajStrFromDouble = *Bio::Emboss::ajStrFromDouble;
*Bio::Emboss::Str::ajStrFromDoubleExp = *Bio::Emboss::ajStrFromDoubleExp;
*Bio::Emboss::Str::ajStrFromFloat = *Bio::Emboss::ajStrFromFloat;
*Bio::Emboss::Str::ajStrFromInt = *Bio::Emboss::ajStrFromInt;
*Bio::Emboss::Str::ajStrFromLong = *Bio::Emboss::ajStrFromLong;
*Bio::Emboss::Str::ajStrFmtBlock = *Bio::Emboss::ajStrFmtBlock;
*Bio::Emboss::Str::ajStrFmtLower = *Bio::Emboss::ajStrFmtLower;
*Bio::Emboss::Str::ajStrFmtLowerSub = *Bio::Emboss::ajStrFmtLowerSub;
*Bio::Emboss::Str::ajStrFmtQuote = *Bio::Emboss::ajStrFmtQuote;
*Bio::Emboss::Str::ajStrFmtTitle = *Bio::Emboss::ajStrFmtTitle;
*Bio::Emboss::Str::ajStrFmtUpper = *Bio::Emboss::ajStrFmtUpper;
*Bio::Emboss::Str::ajStrFmtUpperSub = *Bio::Emboss::ajStrFmtUpperSub;
*Bio::Emboss::Str::ajStrFmtWrap = *Bio::Emboss::ajStrFmtWrap;
*Bio::Emboss::Str::ajStrFmtWrapLeft = *Bio::Emboss::ajStrFmtWrapLeft;
*Bio::Emboss::Str::ajStrMatchC = *Bio::Emboss::ajStrMatchC;
*Bio::Emboss::Str::ajStrMatchS = *Bio::Emboss::ajStrMatchS;
*Bio::Emboss::Str::ajStrMatchCaseC = *Bio::Emboss::ajStrMatchCaseC;
*Bio::Emboss::Str::ajStrMatchCaseS = *Bio::Emboss::ajStrMatchCaseS;
*Bio::Emboss::Str::ajStrMatchWildC = *Bio::Emboss::ajStrMatchWildC;
*Bio::Emboss::Str::ajStrMatchWildS = *Bio::Emboss::ajStrMatchWildS;
*Bio::Emboss::Str::ajStrMatchWildWordC = *Bio::Emboss::ajStrMatchWildWordC;
*Bio::Emboss::Str::ajStrMatchWildWordS = *Bio::Emboss::ajStrMatchWildWordS;
*Bio::Emboss::Str::ajStrMatchWordAllS = *Bio::Emboss::ajStrMatchWordAllS;
*Bio::Emboss::Str::ajStrMatchWordOneS = *Bio::Emboss::ajStrMatchWordOneS;
*Bio::Emboss::Str::ajStrPrefixC = *Bio::Emboss::ajStrPrefixC;
*Bio::Emboss::Str::ajStrPrefixS = *Bio::Emboss::ajStrPrefixS;
*Bio::Emboss::Str::ajStrPrefixCaseC = *Bio::Emboss::ajStrPrefixCaseC;
*Bio::Emboss::Str::ajStrPrefixCaseS = *Bio::Emboss::ajStrPrefixCaseS;
*Bio::Emboss::Str::ajStrSuffixC = *Bio::Emboss::ajStrSuffixC;
*Bio::Emboss::Str::ajStrSuffixS = *Bio::Emboss::ajStrSuffixS;
*Bio::Emboss::Str::ajStrCmpC = *Bio::Emboss::ajStrCmpC;
*Bio::Emboss::Str::ajStrCmpLenC = *Bio::Emboss::ajStrCmpLenC;
*Bio::Emboss::Str::ajStrCmpS = *Bio::Emboss::ajStrCmpS;
*Bio::Emboss::Str::ajStrCmpCaseS = *Bio::Emboss::ajStrCmpCaseS;
*Bio::Emboss::Str::ajStrCmpLenS = *Bio::Emboss::ajStrCmpLenS;
*Bio::Emboss::Str::ajStrCmpWildC = *Bio::Emboss::ajStrCmpWildC;
*Bio::Emboss::Str::ajStrCmpWildS = *Bio::Emboss::ajStrCmpWildS;
*Bio::Emboss::Str::ajStrFindC = *Bio::Emboss::ajStrFindC;
*Bio::Emboss::Str::ajStrFindS = *Bio::Emboss::ajStrFindS;
*Bio::Emboss::Str::ajStrFindAnyC = *Bio::Emboss::ajStrFindAnyC;
*Bio::Emboss::Str::ajStrFindAnyK = *Bio::Emboss::ajStrFindAnyK;
*Bio::Emboss::Str::ajStrFindAnyS = *Bio::Emboss::ajStrFindAnyS;
*Bio::Emboss::Str::ajStrFindCaseC = *Bio::Emboss::ajStrFindCaseC;
*Bio::Emboss::Str::ajStrFindCaseS = *Bio::Emboss::ajStrFindCaseS;
*Bio::Emboss::Str::ajStrFindlastC = *Bio::Emboss::ajStrFindlastC;
*Bio::Emboss::Str::ajStrFindlastS = *Bio::Emboss::ajStrFindlastS;
*Bio::Emboss::Str::ajStrExtractFirst = *Bio::Emboss::ajStrExtractFirst;
*Bio::Emboss::Str::ajStrExtractWord = *Bio::Emboss::ajStrExtractWord;
*Bio::Emboss::Str::ajStrParseC = *Bio::Emboss::ajStrParseC;
*Bio::Emboss::Str::ajStrParseCount = *Bio::Emboss::ajStrParseCount;
*Bio::Emboss::Str::ajStrParseCountC = *Bio::Emboss::ajStrParseCountC;
*Bio::Emboss::Str::ajStrParseCountS = *Bio::Emboss::ajStrParseCountS;
*Bio::Emboss::Str::ajStrParseCountMultiC = *Bio::Emboss::ajStrParseCountMultiC;
*Bio::Emboss::Str::ajStrParseSplit = *Bio::Emboss::ajStrParseSplit;
*Bio::Emboss::Str::ajStrParseWhite = *Bio::Emboss::ajStrParseWhite;
*Bio::Emboss::Str::ajStrTrace = *Bio::Emboss::ajStrTrace;
*Bio::Emboss::Str::ajStrTraceFull = *Bio::Emboss::ajStrTraceFull;
*Bio::Emboss::Str::ajStrTraceTitle = *Bio::Emboss::ajStrTraceTitle;
*Bio::Emboss::Str::ajStrIterNew = *Bio::Emboss::ajStrIterNew;
*Bio::Emboss::Str::ajStrIterNewBack = *Bio::Emboss::ajStrIterNewBack;
*Bio::Emboss::Str::ajStrTokenNewC = *Bio::Emboss::ajStrTokenNewC;
*Bio::Emboss::Str::ajStrTokenNewS = *Bio::Emboss::ajStrTokenNewS;
*Bio::Emboss::Str::ajSysBasename = *Bio::Emboss::ajSysBasename;
*Bio::Emboss::Str::ajSysWhich = *Bio::Emboss::ajSysWhich;
*Bio::Emboss::Str::ajSystem = *Bio::Emboss::ajSystem;
*Bio::Emboss::Str::ajSysUnlink = *Bio::Emboss::ajSysUnlink;
*Bio::Emboss::Str::ajSysArglist = *Bio::Emboss::ajSysArglist;
*Bio::Emboss::Str::ajTrnNew = *Bio::Emboss::ajTrnNew;
*Bio::Emboss::Str::ajUtilUid = *Bio::Emboss::ajUtilUid;
*Bio::Emboss::Str::ajAcdProgramS = *Bio::Emboss::ajAcdProgramS;
*Bio::Emboss::Str::ajSeqCompOnlyStr = *Bio::Emboss::ajSeqCompOnlyStr;
*Bio::Emboss::Str::ajSeqCount = *Bio::Emboss::ajSeqCount;
*Bio::Emboss::Str::ajSeqCrc = *Bio::Emboss::ajSeqCrc;
*Bio::Emboss::Str::ajSeqMW = *Bio::Emboss::ajSeqMW;
*Bio::Emboss::Str::ajSeqNewRange = *Bio::Emboss::ajSeqNewRange;
*Bio::Emboss::Str::ajSeqNewStr = *Bio::Emboss::ajSeqNewStr;
*Bio::Emboss::Str::ajSeqReverseStr = *Bio::Emboss::ajSeqReverseStr;
*Bio::Emboss::Str::ajCharNew = *Bio::Emboss::ajCharNew;
*Bio::Emboss::Str::ajStrApp = *Bio::Emboss::ajStrApp;
*Bio::Emboss::Str::ajStrAppC = *Bio::Emboss::ajStrAppC;
*Bio::Emboss::Str::ajStrAppCI = *Bio::Emboss::ajStrAppCI;
*Bio::Emboss::Str::ajStrAppK = *Bio::Emboss::ajStrAppK;
*Bio::Emboss::Str::ajStrAppKI = *Bio::Emboss::ajStrAppKI;
*Bio::Emboss::Str::ajStrAppSub = *Bio::Emboss::ajStrAppSub;
*Bio::Emboss::Str::ajStrArrayDel = *Bio::Emboss::ajStrArrayDel;
*Bio::Emboss::Str::ajStrAss = *Bio::Emboss::ajStrAss;
*Bio::Emboss::Str::ajStrAssC = *Bio::Emboss::ajStrAssC;
*Bio::Emboss::Str::ajStrAssCI = *Bio::Emboss::ajStrAssCI;
*Bio::Emboss::Str::ajStrAssCL = *Bio::Emboss::ajStrAssCL;
*Bio::Emboss::Str::ajStrAssI = *Bio::Emboss::ajStrAssI;
*Bio::Emboss::Str::ajStrAssK = *Bio::Emboss::ajStrAssK;
*Bio::Emboss::Str::ajStrAssL = *Bio::Emboss::ajStrAssL;
*Bio::Emboss::Str::ajStrAssS = *Bio::Emboss::ajStrAssS;
*Bio::Emboss::Str::ajStrAssSub = *Bio::Emboss::ajStrAssSub;
*Bio::Emboss::Str::ajStrAssSubC = *Bio::Emboss::ajStrAssSubC;
*Bio::Emboss::Str::ajStrBlock = *Bio::Emboss::ajStrBlock;
*Bio::Emboss::Str::ajStrChar = *Bio::Emboss::ajStrChar;
*Bio::Emboss::Str::ajStrCheck = *Bio::Emboss::ajStrCheck;
*Bio::Emboss::Str::ajStrChomp = *Bio::Emboss::ajStrChomp;
*Bio::Emboss::Str::ajStrChompC = *Bio::Emboss::ajStrChompC;
*Bio::Emboss::Str::ajStrChompEnd = *Bio::Emboss::ajStrChompEnd;
*Bio::Emboss::Str::ajStrChop = *Bio::Emboss::ajStrChop;
*Bio::Emboss::Str::ajStrClean = *Bio::Emboss::ajStrClean;
*Bio::Emboss::Str::ajStrCleanWhite = *Bio::Emboss::ajStrCleanWhite;
*Bio::Emboss::Str::ajStrClear = *Bio::Emboss::ajStrClear;
*Bio::Emboss::Str::ajStrCmpCase = *Bio::Emboss::ajStrCmpCase;
*Bio::Emboss::Str::ajStrCmpO = *Bio::Emboss::ajStrCmpO;
*Bio::Emboss::Str::ajStrCmpWild = *Bio::Emboss::ajStrCmpWild;
*Bio::Emboss::Str::ajStrConvert = *Bio::Emboss::ajStrConvert;
*Bio::Emboss::Str::ajStrConvertCC = *Bio::Emboss::ajStrConvertCC;
*Bio::Emboss::Str::ajStrCopy = *Bio::Emboss::ajStrCopy;
*Bio::Emboss::Str::ajStrCopyC = *Bio::Emboss::ajStrCopyC;
*Bio::Emboss::Str::ajStrCountC = *Bio::Emboss::ajStrCountC;
*Bio::Emboss::Str::ajStrCountK = *Bio::Emboss::ajStrCountK;
*Bio::Emboss::Str::ajStrCut = *Bio::Emboss::ajStrCut;
*Bio::Emboss::Str::ajStrDegap = *Bio::Emboss::ajStrDegap;
*Bio::Emboss::Str::ajStrDelim = *Bio::Emboss::ajStrDelim;
*Bio::Emboss::Str::ajStrDelReuse = *Bio::Emboss::ajStrDelReuse;
*Bio::Emboss::Str::ajStrDup = *Bio::Emboss::ajStrDup;
*Bio::Emboss::Str::ajStrFind = *Bio::Emboss::ajStrFind;
*Bio::Emboss::Str::ajStrFindAny = *Bio::Emboss::ajStrFindAny;
*Bio::Emboss::Str::ajStrFindCase = *Bio::Emboss::ajStrFindCase;
*Bio::Emboss::Str::ajStrFindK = *Bio::Emboss::ajStrFindK;
*Bio::Emboss::Str::ajStrFill = *Bio::Emboss::ajStrFill;
*Bio::Emboss::Str::ajStrFix = *Bio::Emboss::ajStrFix;
*Bio::Emboss::Str::ajStrFixI = *Bio::Emboss::ajStrFixI;
*Bio::Emboss::Str::ajStrFixTestI = *Bio::Emboss::ajStrFixTestI;
*Bio::Emboss::Str::ajStrFromDoubleE = *Bio::Emboss::ajStrFromDoubleE;
*Bio::Emboss::Str::ajStrInsert = *Bio::Emboss::ajStrInsert;
*Bio::Emboss::Str::ajStrIsSpace = *Bio::Emboss::ajStrIsSpace;
*Bio::Emboss::Str::ajStrIter = *Bio::Emboss::ajStrIter;
*Bio::Emboss::Str::ajStrIterBack = *Bio::Emboss::ajStrIterBack;
*Bio::Emboss::Str::ajStrJoin = *Bio::Emboss::ajStrJoin;
*Bio::Emboss::Str::ajStrKeepAlphaC = *Bio::Emboss::ajStrKeepAlphaC;
*Bio::Emboss::Str::ajStrKeepC = *Bio::Emboss::ajStrKeepC;
*Bio::Emboss::Str::ajStrLen = *Bio::Emboss::ajStrLen;
*Bio::Emboss::Str::ajStrListToArray = *Bio::Emboss::ajStrListToArray;
*Bio::Emboss::Str::ajStrMatch = *Bio::Emboss::ajStrMatch;
*Bio::Emboss::Str::ajStrMatchCase = *Bio::Emboss::ajStrMatchCase;
*Bio::Emboss::Str::ajStrMatchWild = *Bio::Emboss::ajStrMatchWild;
*Bio::Emboss::Str::ajStrMatchWord = *Bio::Emboss::ajStrMatchWord;
*Bio::Emboss::Str::ajStrMatchWordC = *Bio::Emboss::ajStrMatchWordC;
*Bio::Emboss::Str::ajStrMod = *Bio::Emboss::ajStrMod;
*Bio::Emboss::Str::ajStrModL = *Bio::Emboss::ajStrModL;
*Bio::Emboss::Str::ajStrModMinL = *Bio::Emboss::ajStrModMinL;
*Bio::Emboss::Str::ajStrNCmpC = *Bio::Emboss::ajStrNCmpC;
*Bio::Emboss::Str::ajStrNCmpO = *Bio::Emboss::ajStrNCmpO;
*Bio::Emboss::Str::ajStrParentheses = *Bio::Emboss::ajStrParentheses;
*Bio::Emboss::Str::ajStrPos = *Bio::Emboss::ajStrPos;
*Bio::Emboss::Str::ajStrPosI = *Bio::Emboss::ajStrPosI;
*Bio::Emboss::Str::ajStrPrefix = *Bio::Emboss::ajStrPrefix;
*Bio::Emboss::Str::ajStrPrefixCase = *Bio::Emboss::ajStrPrefixCase;
*Bio::Emboss::Str::ajStrQuote = *Bio::Emboss::ajStrQuote;
*Bio::Emboss::Str::ajStrReplace = *Bio::Emboss::ajStrReplace;
*Bio::Emboss::Str::ajStrReplaceC = *Bio::Emboss::ajStrReplaceC;
*Bio::Emboss::Str::ajStrReplaceK = *Bio::Emboss::ajStrReplaceK;
*Bio::Emboss::Str::ajStrReplaceS = *Bio::Emboss::ajStrReplaceS;
*Bio::Emboss::Str::ajStrRef = *Bio::Emboss::ajStrRef;
*Bio::Emboss::Str::ajStrRemoveCharsC = *Bio::Emboss::ajStrRemoveCharsC;
*Bio::Emboss::Str::ajStrRemoveNewline = *Bio::Emboss::ajStrRemoveNewline;
*Bio::Emboss::Str::ajStrRev = *Bio::Emboss::ajStrRev;
*Bio::Emboss::Str::ajStrRFindC = *Bio::Emboss::ajStrRFindC;
*Bio::Emboss::Str::ajStrRoom = *Bio::Emboss::ajStrRoom;
*Bio::Emboss::Str::ajStrSet = *Bio::Emboss::ajStrSet;
*Bio::Emboss::Str::ajStrSetC = *Bio::Emboss::ajStrSetC;
*Bio::Emboss::Str::ajStrSize = *Bio::Emboss::ajStrSize;
*Bio::Emboss::Str::ajStrStr = *Bio::Emboss::ajStrStr;
*Bio::Emboss::Str::ajStrStrMod = *Bio::Emboss::ajStrStrMod;
*Bio::Emboss::Str::ajStrSub = *Bio::Emboss::ajStrSub;
*Bio::Emboss::Str::ajStrSubstitute = *Bio::Emboss::ajStrSubstitute;
*Bio::Emboss::Str::ajStrSubstituteCC = *Bio::Emboss::ajStrSubstituteCC;
*Bio::Emboss::Str::ajStrSubstituteKK = *Bio::Emboss::ajStrSubstituteKK;
*Bio::Emboss::Str::ajStrSuffix = *Bio::Emboss::ajStrSuffix;
*Bio::Emboss::Str::ajStrTok = *Bio::Emboss::ajStrTok;
*Bio::Emboss::Str::ajStrTokC = *Bio::Emboss::ajStrTokC;
*Bio::Emboss::Str::ajStrToken = *Bio::Emboss::ajStrToken;
*Bio::Emboss::Str::ajStrTokenCount = *Bio::Emboss::ajStrTokenCount;
*Bio::Emboss::Str::ajStrTokenCountR = *Bio::Emboss::ajStrTokenCountR;
*Bio::Emboss::Str::ajStrTokenInit = *Bio::Emboss::ajStrTokenInit;
*Bio::Emboss::Str::ajStrTokenRest = *Bio::Emboss::ajStrTokenRest;
*Bio::Emboss::Str::ajStrToLower = *Bio::Emboss::ajStrToLower;
*Bio::Emboss::Str::ajStrToLowerII = *Bio::Emboss::ajStrToLowerII;
*Bio::Emboss::Str::ajStrToTitle = *Bio::Emboss::ajStrToTitle;
*Bio::Emboss::Str::ajStrToUpper = *Bio::Emboss::ajStrToUpper;
*Bio::Emboss::Str::ajStrToUpperII = *Bio::Emboss::ajStrToUpperII;
*Bio::Emboss::Str::ajStrTraceChars = *Bio::Emboss::ajStrTraceChars;
*Bio::Emboss::Str::ajStrTraceT = *Bio::Emboss::ajStrTraceT;
*Bio::Emboss::Str::ajStrTrim = *Bio::Emboss::ajStrTrim;
*Bio::Emboss::Str::ajStrTruncate = *Bio::Emboss::ajStrTruncate;
*Bio::Emboss::Str::ajStrWildPrefix = *Bio::Emboss::ajStrWildPrefix;
*Bio::Emboss::Str::ajStrWrap = *Bio::Emboss::ajStrWrap;
*Bio::Emboss::Str::ajStrWrapLeft = *Bio::Emboss::ajStrWrapLeft;
*Bio::Emboss::Str::ajStrUncomment = *Bio::Emboss::ajStrUncomment;
*Bio::Emboss::Str::ajStrUncommentStart = *Bio::Emboss::ajStrUncommentStart;

*Bio::Emboss::StrTok::ajStrTokenDel = *Bio::Emboss::ajStrTokenDel;
*Bio::Emboss::StrTok::ajStrTokenAssign = *Bio::Emboss::ajStrTokenAssign;
*Bio::Emboss::StrTok::ajStrTokenAssignC = *Bio::Emboss::ajStrTokenAssignC;
*Bio::Emboss::StrTok::ajStrTokenAssignS = *Bio::Emboss::ajStrTokenAssignS;
*Bio::Emboss::StrTok::ajStrTokenReset = *Bio::Emboss::ajStrTokenReset;
*Bio::Emboss::StrTok::ajStrTokenTrace = *Bio::Emboss::ajStrTokenTrace;
*Bio::Emboss::StrTok::ajStrTokenNextFind = *Bio::Emboss::ajStrTokenNextFind;
*Bio::Emboss::StrTok::ajStrTokenNextFindC = *Bio::Emboss::ajStrTokenNextFindC;
*Bio::Emboss::StrTok::ajStrTokenNextParse = *Bio::Emboss::ajStrTokenNextParse;
*Bio::Emboss::StrTok::ajStrTokenNextParseC = *Bio::Emboss::ajStrTokenNextParseC;
*Bio::Emboss::StrTok::ajStrTokenNextParseS = *Bio::Emboss::ajStrTokenNextParseS;
*Bio::Emboss::StrTok::ajStrTokenRestParse = *Bio::Emboss::ajStrTokenRestParse;
*Bio::Emboss::StrTok::ajStrTokenAss = *Bio::Emboss::ajStrTokenAss;
*Bio::Emboss::StrTok::ajStrTokenClear = *Bio::Emboss::ajStrTokenClear;

*Bio::Emboss::Table::ajTableGet = *Bio::Emboss::ajTableGet;
*Bio::Emboss::Table::ajTableKey = *Bio::Emboss::ajTableKey;
*Bio::Emboss::Table::ajTableTrace = *Bio::Emboss::ajTableTrace;
*Bio::Emboss::Table::ajStrTableTrace = *Bio::Emboss::ajStrTableTrace;
*Bio::Emboss::Table::ajTablePut = *Bio::Emboss::ajTablePut;
*Bio::Emboss::Table::ajTableLength = *Bio::Emboss::ajTableLength;
*Bio::Emboss::Table::ajTableRemove = *Bio::Emboss::ajTableRemove;
*Bio::Emboss::Table::ajTableToarray = *Bio::Emboss::ajTableToarray;
*Bio::Emboss::Table::ajTableFree = *Bio::Emboss::ajTableFree;
*Bio::Emboss::Table::ajStrTablePrint = *Bio::Emboss::ajStrTablePrint;
*Bio::Emboss::Table::ajStrTablePrintC = *Bio::Emboss::ajStrTablePrintC;
*Bio::Emboss::Table::ajStrTableFree = *Bio::Emboss::ajStrTableFree;

*Bio::Emboss::Time::ajTimeTrace = *Bio::Emboss::ajTimeTrace;
*Bio::Emboss::Time::ajTimeSetS = *Bio::Emboss::ajTimeSetS;
*Bio::Emboss::Time::ajTimeDel = *Bio::Emboss::ajTimeDel;

*Bio::Emboss::Tree::ajTreestrCopy = *Bio::Emboss::ajTreestrCopy;
*Bio::Emboss::Tree::ajTreeCopy = *Bio::Emboss::ajTreeCopy;
*Bio::Emboss::Tree::ajTreeLength = *Bio::Emboss::ajTreeLength;
*Bio::Emboss::Tree::ajTreestrLength = *Bio::Emboss::ajTreestrLength;
*Bio::Emboss::Tree::ajTreeFree = *Bio::Emboss::ajTreeFree;
*Bio::Emboss::Tree::ajTreestrFree = *Bio::Emboss::ajTreestrFree;
*Bio::Emboss::Tree::ajTreeDel = *Bio::Emboss::ajTreeDel;
*Bio::Emboss::Tree::ajTreestrDel = *Bio::Emboss::ajTreestrDel;
*Bio::Emboss::Tree::ajTreeToArray = *Bio::Emboss::ajTreeToArray;
*Bio::Emboss::Tree::ajTreestrToArray = *Bio::Emboss::ajTreestrToArray;
*Bio::Emboss::Tree::ajTreeAddData = *Bio::Emboss::ajTreeAddData;
*Bio::Emboss::Tree::ajTreeAddNode = *Bio::Emboss::ajTreeAddNode;
*Bio::Emboss::Tree::ajTreeAddSubNode = *Bio::Emboss::ajTreeAddSubNode;
*Bio::Emboss::Tree::ajTreeTrace = *Bio::Emboss::ajTreeTrace;

*Bio::Emboss::Trn::ajTrnDel = *Bio::Emboss::ajTrnDel;
*Bio::Emboss::Trn::ajTrnReadFile = *Bio::Emboss::ajTrnReadFile;
*Bio::Emboss::Trn::ajTrnCodon = *Bio::Emboss::ajTrnCodon;
*Bio::Emboss::Trn::ajTrnRevCodon = *Bio::Emboss::ajTrnRevCodon;
*Bio::Emboss::Trn::ajTrnCodonC = *Bio::Emboss::ajTrnCodonC;
*Bio::Emboss::Trn::ajTrnRevCodonC = *Bio::Emboss::ajTrnRevCodonC;
*Bio::Emboss::Trn::ajTrnCodonK = *Bio::Emboss::ajTrnCodonK;
*Bio::Emboss::Trn::ajTrnRevCodonK = *Bio::Emboss::ajTrnRevCodonK;
*Bio::Emboss::Trn::ajTrnC = *Bio::Emboss::ajTrnC;
*Bio::Emboss::Trn::ajTrnRevC = *Bio::Emboss::ajTrnRevC;
*Bio::Emboss::Trn::ajTrnAltRevC = *Bio::Emboss::ajTrnAltRevC;
*Bio::Emboss::Trn::ajTrnStr = *Bio::Emboss::ajTrnStr;
*Bio::Emboss::Trn::ajTrnRevStr = *Bio::Emboss::ajTrnRevStr;
*Bio::Emboss::Trn::ajTrnAltRevStr = *Bio::Emboss::ajTrnAltRevStr;
*Bio::Emboss::Trn::ajTrnSeq = *Bio::Emboss::ajTrnSeq;
*Bio::Emboss::Trn::ajTrnRevSeq = *Bio::Emboss::ajTrnRevSeq;
*Bio::Emboss::Trn::ajTrnAltRevSeq = *Bio::Emboss::ajTrnAltRevSeq;
*Bio::Emboss::Trn::ajTrnCFrame = *Bio::Emboss::ajTrnCFrame;
*Bio::Emboss::Trn::ajTrnStrFrame = *Bio::Emboss::ajTrnStrFrame;
*Bio::Emboss::Trn::ajTrnSeqFrame = *Bio::Emboss::ajTrnSeqFrame;
*Bio::Emboss::Trn::ajTrnSeqFramePep = *Bio::Emboss::ajTrnSeqFramePep;
*Bio::Emboss::Trn::ajTrnCDangle = *Bio::Emboss::ajTrnCDangle;
*Bio::Emboss::Trn::ajTrnStrDangle = *Bio::Emboss::ajTrnStrDangle;
*Bio::Emboss::Trn::ajTrnSeqOrig = *Bio::Emboss::ajTrnSeqOrig;
*Bio::Emboss::Trn::ajTrnGetTitle = *Bio::Emboss::ajTrnGetTitle;
*Bio::Emboss::Trn::ajTrnGetFileName = *Bio::Emboss::ajTrnGetFileName;
*Bio::Emboss::Trn::ajTrnStartStop = *Bio::Emboss::ajTrnStartStop;
*Bio::Emboss::Trn::ajTrnStartStopC = *Bio::Emboss::ajTrnStartStopC;

*Bio::Emboss::Vdwall::ajVdwallDel = *Bio::Emboss::ajVdwallDel;

*Bio::Emboss::Vdwres::ajVdwresDel = *Bio::Emboss::ajVdwresDel;

# --- list all methods of EMBOSS for the EXPORT :all tag

@ALL_METHODS = qw(
	embInitPerl
	ajGraphInitPerl
	ajAcdGetAlign
	ajAcdGetArray
	ajAcdGetBool
	ajAcdGetCodon
	ajAcdGetCpdb
	ajAcdGetDatafile
	ajAcdGetDirectory
	ajAcdGetDirectoryName
	ajAcdGetDirlist
	ajAcdGetDiscretestates
	ajAcdGetDiscretestatesSingle
	ajAcdGetDistances
	ajAcdGetFeat
	ajAcdGetFeatout
	ajAcdGetFilelist
	ajAcdGetFloat
	ajAcdGetFrequencies
	ajAcdGetGraph
	ajAcdGetGraphxy
	ajAcdGetInfile
	ajAcdGetInt
	ajAcdGetList
	ajAcdGetListSingle
	ajAcdGetMatrix
	ajAcdGetMatrixf
	ajAcdGetOutcodon
	ajAcdGetOutcpdb
	ajAcdGetOutdata
	ajAcdGetOutdir
	ajAcdGetOutdirName
	ajAcdGetOutdiscrete
	ajAcdGetOutdistance
	ajAcdGetOutfile
	ajAcdGetOutfileall
	ajAcdGetOutfreq
	ajAcdGetOutmatrix
	ajAcdGetOutmatrixf
	ajAcdGetOutproperties
	ajAcdGetOutscop
	ajAcdGetOuttree
	ajAcdGetPattern
	ajAcdGetProperties
	ajAcdGetRange
	ajAcdGetRegexp
	ajAcdGetRegexpSingle
	ajAcdGetReport
	ajAcdGetScop
	ajAcdGetSelect
	ajAcdGetSelectSingle
	ajAcdGetSeq
	ajAcdGetSeqall
	ajAcdGetSeqout
	ajAcdGetSeqoutall
	ajAcdGetSeqoutset
	ajAcdGetSeqset
	ajAcdGetSeqsetall
	ajAcdGetSeqsetallSingle
	ajAcdGetString
	ajAcdGetToggle
	ajAcdGetTree
	ajAcdGetTreeSingle
	ajAcdGetValue
	ajAcdSetControl
	ajAcdGetCmdline
	ajAcdGetInputs
	ajAcdGetProgram
	ajAcdPrintAppl
	ajAcdPrintQual
	ajAcdPrintType
	ajAcdExit
	ajAcdUnused
	ajAlignDefine
	ajAlignDefineSS
	ajAlignDefineCC
	ajAlignDel
	ajAlignReset
	ajAlignOpen
	ajAlignFormatDefault
	ajAlignGetFilename
	ajAlignGetFormat
	ajAlignFindFormat
	ajAlignValid
	ajAlignNew
	ajAlignWrite
	ajAlignClose
	ajAlignWriteHeader
	ajAlignWriteTail
	ajAlignSetHeader
	ajAlignSetHeaderC
	ajAlignSetHeaderApp
	ajAlignSetTail
	ajAlignSetTailC
	ajAlignSetTailApp
	ajAlignSetSubTail
	ajAlignSetSubTailC
	ajAlignSetSubTailApp
	ajAlignSetSubHeader
	ajAlignSetSubHeaderC
	ajAlignSetSubHeaderApp
	ajAlignSetSubHeaderPre
	ajAlignSetMatrixName
	ajAlignSetMatrixNameC
	ajAlignSetMatrixInt
	ajAlignSetMatrixFloat
	ajAlignSetGapI
	ajAlignSetGapR
	ajAlignSetScoreI
	ajAlignSetScoreL
	ajAlignSetScoreR
	ajAlignSetStats
	ajAlignSetSubStandard
	ajAlignSetType
	ajAlignSetExternal
	ajAlignSetRange
	ajAlignSetSubRange
	ajAlignTraceT
	ajAlignTrace
	ajAlignPrintFormat
	ajAlignConsStats
	ajAlignExit
	ajChararrNew
	ajChararrNewL
	ajChararrDel
	ajChararrGet
	ajChararrPut
	ajChararrChararr
	ajIntNew
	ajIntNewL
	ajIntDel
	ajIntGet
	ajIntPut
	ajIntInc
	ajIntDec
	ajIntInt
	ajIntLen
	ajFloatNew
	ajFloatNewL
	ajFloatDel
	ajFloatGet
	ajFloatPut
	ajFloatFloat
	ajFloatLen
	ajDoubleNew
	ajDoubleNewL
	ajDoubleDel
	ajDoubleGet
	ajDoublePut
	ajDoubleDouble
	ajDoubleLen
	ajShortNew
	ajShortNewL
	ajShortDel
	ajShortGet
	ajShortPut
	ajShortShort
	ajShortLen
	ajLongNew
	ajLongNewL
	ajLongDel
	ajLongGet
	ajLongPut
	ajLongLong
	ajLongLen
	ajFloatParse
	ajFloatStr
	ajFloatTrace
	ajArrCommaList
	ajArrIntLine
	ajInt2dNew
	ajInt2dNewL
	ajInt2dNewLL
	ajInt2dDel
	ajInt2dGet
	ajInt2dPut
	ajInt2dLen
	ajInt2dInt
	ajInt3dNew
	ajInt3dNewL
	ajInt3dDel
	ajInt3dGet
	ajInt3dPut
	ajInt3dLen
	ajInt3dInt
	ajFloat2dNew
	ajFloat2dNewL
	ajFloat2dDel
	ajFloat2dGet
	ajFloat2dPut
	ajFloat2dLen
	ajFloat2dFloat
	ajFloat3dNew
	ajFloat3dNewL
	ajFloat3dDel
	ajFloat3dGet
	ajFloat3dPut
	ajFloat3dLen
	ajFloat3dFloat
	ajDouble2dNew
	ajDouble2dNewL
	ajDouble2dDel
	ajDouble2dGet
	ajDouble2dPut
	ajDouble2dLen
	ajDouble2dDouble
	ajDouble3dNew
	ajDouble3dNewL
	ajDouble3dDel
	ajDouble3dGet
	ajDouble3dPut
	ajDouble3dLen
	ajDouble3dDouble
	ajShort2dNew
	ajShort2dNewL
	ajShort2dDel
	ajShort2dGet
	ajShort2dPut
	ajShort2dLen
	ajShort2dShort
	ajShort3dNew
	ajShort3dNewL
	ajShort3dDel
	ajShort3dGet
	ajShort3dPut
	ajShort3dLen
	ajShort3dShort
	ajLong2dNew
	ajLong2dNewL
	ajLong2dDel
	ajLong2dGet
	ajLong2dPut
	ajLong2dLen
	ajLong2dLong
	ajLong3dNew
	ajLong3dNewL
	ajLong3dDel
	ajLong3dGet
	ajLong3dPut
	ajLong3dLen
	ajLong3dLong
	ajArrExit
	ajBaseCodes
	ajAZToInt
	ajIntToAZ
	ajBinToAZ
	ajAZToBin
	ajAZToBinC
	ajBaseInit
	ajBaseAa1ToAa3
	ajBaseProb
	ajBaseExit
	ajCall
	ajCallExit
	ajCodNew
	ajCodNewCode
	ajCodDup
	ajCodDel
	ajCodBacktranslate
	ajCodBacktranslateAmbig
	ajCodBase
	ajCodCalcGribskov
	ajCodCalcNc
	ajCodCalculateUsage
	ajCodClear
	ajCodClearData
	ajCodCountTriplets
	ajCodIndex
	ajCodIndexC
	ajCodRead
	ajCodSetBacktranslate
	ajCodTriplet
	ajCodWriteOut
	ajCodWrite
	ajCodComp
	ajCodCalcCai
	ajCodCaiW
	ajCodCai
	ajCodGetName
	ajCodGetNameC
	ajCodGetDesc
	ajCodGetDescC
	ajCodGetSpecies
	ajCodGetSpeciesC
	ajCodGetDivision
	ajCodGetDivisionC
	ajCodGetRelease
	ajCodGetReleaseC
	ajCodGetNumcodon
	ajCodGetNumcds
	ajCodGetCode
	ajCodAssName
	ajCodAssNameC
	ajCodAssDesc
	ajCodAssDescC
	ajCodAssSpecies
	ajCodAssSpeciesC
	ajCodAssRelease
	ajCodAssReleaseC
	ajCodAssDivision
	ajCodAssDivisionC
	ajCodAssNumcodon
	ajCodAssNumcds
	ajCodAssCode
	ajCodOutFormat
	ajCodPrintFormat
	ajCodGetCodonlist
	ajCodExit
	ajMeltInit
	ajProbScore
	ajMeltEnergy
	ajTm
	ajMeltGC
	ajMeltEnergy2
	ajTm2
	ajProdTm
	ajAnneal
	ajMeltExit
	ajDmxScophitNew
	ajDmxScopalgNew
	ajDmxScopalgRead
	ajDmxScophitDel
	ajDmxScophitDelWrap
	ajDmxScopalgDel
	ajDmxScophitListCopy
	ajDmxScophitCopy
	ajDmxScophitTargetLowPriority
	ajDmxScophitTarget2
	ajDmxScophitTarget
	ajDmxScophitCheckTarget
	ajDmxScophitCompScore
	ajDmxScophitCompPval
	ajDmxScophitCompAcc
	ajDmxScophitCompSunid
	ajDmxScophitCompSpr
	ajDmxScophitCompEnd
	ajDmxScophitCompStart
	ajDmxScophitCompFam
	ajDmxScophitCompSfam
	ajDmxScophitCompClass
	ajDmxScophitCompFold
	ajDmxScopalgGetseqs
	ajDmxScophitsWrite
	ajDmxScophitsWriteFasta
	ajDmxScophitReadFasta
	ajDmxScopalgWrite
	ajDmxScopalgWriteClustal
	ajDmxScopalgWriteClustal2
	ajDmxScopalgWriteFasta
	ajDmxScopSeqFromSunid
	ajDmxDummyFunction
	ajCathReadAllNew
	ajCathReadAllRawNew
	ajCathReadCNew
	ajCathReadNew
	ajDomainReadAllNew
	ajScopReadAllNew
	ajScopReadAllRawNew
	ajCathNew
	ajDomainNew
	ajScopNew
	ajDomainReadNew
	ajScopReadNew
	ajDomainReadCNew
	ajScopReadCNew
	ajDomainDel
	ajScopDel
	ajCathDel
	ajDomainCopy
	ajCathCopy
	ajScopCopy
	ajScopMatchSunid
	ajScopMatchScopid
	ajScopMatchPdbId
	ajCathMatchPdbId
	ajDomainGetId
	ajDomainGetSeqPdb
	ajDomainGetSeqSpr
	ajDomainGetPdb
	ajDomainGetAcc
	ajDomainGetSpr
	ajDomainGetN
	ajScopArrFindScopid
	ajScopArrFindSunid
	ajScopArrFindPdbid
	ajCathArrFindPdbid
	ajPdbWriteDomain
	ajCathWrite
	ajDomainWrite
	ajScopWrite
	ajDomainDCFType
	ajDomainDummyFunction
	ajFeattabOutOpen
	ajFeattabOutFile
	ajFeattabOutFilename
	ajFeattabOutIsOpen
	ajFeattabOutIsLocal
	ajFeattabOutSet
	ajFeattabInNew
	ajFeattabInNewSS
	ajFeattabInNewSSF
	ajFeattabOutNew
	ajFeattabOutSetBasename
	ajFeattabOutNewSSF
	ajFeatRead
	ajFeatNew
	ajFeatNewII
	ajFeatNewIIRev
	ajFeatNewProt
	ajFeattabInDel
	ajFeattableDel
	ajFeatDel
	ajFeatUfoWrite
	ajFeattableWrite
	ajFeatSortByType
	ajFeatSortByStart
	ajFeatSortByEnd
	ajFeattableAdd
	ajFeattableClear
	ajFeatOutFormatDefault
	ajFeatWrite
	ajFeattableWriteGff
	ajFeattableWriteDdbj
	ajFeattableWriteEmbl
	ajFeattableWriteGenbank
	ajFeattableWriteSwiss
	ajFeattableWritePir
	ajFeattableGetName
	ajFeattableGetTypeC
	ajFeattableGetTypeS
	ajFeattableIsNuc
	ajFeattableIsProt
	ajFeattableBegin
	ajFeattableEnd
	ajFeattableLen
	ajFeattableSize
	ajFeattabInClear
	ajFeatLocToSeq
	ajFeatGetLocs
	ajFeatGetNote
	ajFeatGetNoteC
	ajFeatGetNoteCI
	ajFeatGetNoteI
	ajFeatGetTag
	ajFeatGetType
	ajFeatGetSource
	ajFeatGetStart
	ajFeatGetStrand
	ajFeatGetEnd
	ajFeatGetLength
	ajFeatGetScore
	ajFeatGetForward
	ajFeatGetFrame
	ajFeatGetTrans
	ajFeatTest
	ajFeatSetDescApp
	ajFeatSetDesc
	ajFeatSetScore
	ajFeatSetStrand
	ajFeattabInSetType
	ajFeattabInSetTypeC
	ajFeattabOutSetType
	ajFeattabOutSetTypeC
	ajFeatTagSetC
	ajFeatTagSet
	ajFeatTagAddCC
	ajFeatTagAddC
	ajFeatTagAdd
	ajFeattableNew
	ajFeatUfoRead
	ajFeattableSetNuc
	ajFeattableSetProt
	ajFeattableReverse
	ajFeatReverse
	ajFeattableSetRange
	ajFeattableNewDna
	ajFeattableNewSeq
	ajFeattableNewProt
	ajFeattableCopy
	ajFeatCopy
	ajFeatTrace
	ajFeatTagTrace
	ajFeatTagIter
	ajFeatTagval
	ajFeattableTrace
	ajFeatExit
	ajFeatUnused
	ajFeatIsLocal
	ajFeatIsLocalRange
	ajFeatIsChild
	ajFeatIsMultiple
	ajFeatIsCompMult
	ajFeattabOutDel
	ajFeattablePos
	ajFeattablePosI
	ajFeattablePosII
	ajFeattableTrimOff
	ajFeatTrimOffRange
	ajFeatDefName
	ajFeatPrintFormat
	ajOutfileNew
	ajDirNew
	ajDirNewS
	ajDirNewSS
	ajDiroutNew
	ajDiroutNewS
	ajDiroutNewSS
	ajDirName
	ajDirExt
	ajFileNew
	ajFileNewInPipe
	ajFileNewIn
	ajFileNewInC
	ajFileNewInList
	ajFileNewApp
	ajFileNewOut
	ajFileNewOutC
	ajFileNewOutD
	ajFileNewOutDir
	ajFileSetDir
	ajFileHasDir
	ajFileNewF
	ajOutfileClose
	ajOutfileDel
	ajDirDel
	ajDiroutDel
	ajFileClose
	ajFileOutClose
	ajFileDataNew
	ajFileDataNewC
	ajFileDataDirNew
	ajFileDataDirNewC
	ajFileSeek
	ajFileRead
	ajFileReadUint
	ajFileWrite
	ajFileNext
	ajFileReopen
	ajFileReadLine
	ajFileGetsTrimL
	ajFileGetsTrim
	ajFileGets
	ajFileGetsL
	ajFileUnbuffer
	ajFileReadAppend
	ajFileOutHeader
	ajFileNameShorten
	ajFileNameTrim
	ajFileDataNewWrite
	ajFileDir
	ajFileDirPath
	ajFileGetwd
	ajFileDirUp
	ajFileDirFix
	ajFileExit
	ajFileTrace
	ajOutfileFile
	ajOutfileFp
	ajOutfileFormat
	ajFileBuffSize
	ajFileName
	ajFileNameS
	ajFileGetApp
	ajFileGetName
	ajFileStat
	ajFileLength
	ajFileTell
	ajFileStdout
	ajFileStderr
	ajFileStdin
	ajFileFp
	ajFileEof
	ajFileBuffNewIn
	ajFileBuffNew
	ajFileBuffNewFile
	ajFileBuffSetFile
	ajFileBuffNewS
	ajFileBuffNewF
	ajFileBuffNewDW
	ajFileBuffNewDWE
	ajFileBuffNewDC
	ajFileBuffNewDF
	ajFileNewDW
	ajFileNewDWE
	ajFileNewDF
	ajFileNewDirF
	ajFileNewDC
	ajFileBuffNewInList
	ajFileBuffDel
	ajFileBuffGet
	ajFileBuffGetStore
	ajFileBuffGetStoreL
	ajFileBuffGetL
	ajFileBuffStripHtml
	ajFileBuffLoadC
	ajFileBuffLoadS
	ajFileBuffEof
	ajFileBuffEnd
	ajFileBuffReset
	ajFileBuffResetStore
	ajFileBuffResetPos
	ajFileBuffFix
	ajFileBuffFreeClear
	ajFileBuffClear
	ajFileBuffClearStore
	ajFileBuffNobuff
	ajFileBuffBuff
	ajFileBuffEmpty
	ajFileBuffTrace
	ajFileBuffTraceFull
	ajFileBuffPrint
	ajFileBuffIsBuffered
	ajFileBuffFp
	ajFileBuffFile
	ajFileBuffLoad
	ajFileNameDir
	ajFileNameDirSet
	ajFileNameDirSetC
	ajFileNameExt
	ajFileNameExtC
	ajFileScan
	ajFileTestSkip
	ajFileDirTrim
	ajFileExtnTrim
	ajFileDirExtnTrim
	ajFileTempName
	ajFileWriteByte
	ajFileWriteChar
	ajFileWriteInt2
	ajFileWriteInt4
	ajFileWriteInt8
	ajFileWriteStr
	ajFileBuffStripHtmlPre
	ajFileFileList
	ajFmtPrint
	ajFmtError
	ajFmtPrintF
	ajFmtPrintFp
	ajFmtPrintCL
	ajFmtStr
	ajFmtPrintS
	ajFmtPrintAppS
	ajFmtString
	ajFmtPrintSplit
	ajFmtScanS
	ajFmtScanC
	ajFmtScanF
	ajGraphSetDevice
	ajGraphSetName
	ajGraphLabel
	ajGraphSetPenWidth
	ajGraphOpenPlot
	ajGraphOpenWin
	ajGraphNewPage
	ajGraphCloseWin
	ajGraphOpen
	ajGraphLabelYRight
	ajGraphClose
	ajGraphSet
	ajGraphxySet
	ajGraphDumpDevices
	ajGraphTraceInt
	ajGraphTrace
	ajGraphPlpDataTrace
	ajGraphCircle
	ajGraphPolyFill
	ajGraphPoly
	ajGraphTriFill
	ajGraphTri
	ajGraphDiaFill
	ajGraphDia
	ajGraphBoxFill
	ajGraphBox
	ajGraphRectFill
	ajGraphRect
	ajGraphSetBackWhite
	ajGraphSetBackBlack
	ajGraphColourBack
	ajGraphColourFore
	ajGraphSetFore
	ajGraphCheckColour
	ajGraphGetBaseColour
	ajGraphGetBaseColourProt
	ajGraphGetBaseColourNuc
	ajGraphGetCharSize
	ajGraphGetOut
	ajGraphSetOri
	ajGraphPlenv
	ajGraphGetColour
	ajGraphGetSubTitle
	ajGraphGetSubTitleC
	ajGraphGetTitle
	ajGraphGetTitleC
	ajGraphGetXTitle
	ajGraphGetXTitleC
	ajGraphGetYTitle
	ajGraphGetYTitleC
	ajGraphSetLineStyle
	ajGraphSetFillPat
	ajGraphSetCharSize
	ajGraphLine
	ajGraphLines
	ajGraphDots
	ajGraphSymbols
	ajGraphTextLine
	ajGraphText
	ajGraphTextStart
	ajGraphTextEnd
	ajGraphTextMid
	ajGraphVertBars
	ajGraphHoriBars
	ajGraphInitSeq
	ajGraphSetOut
	ajGraphSetOutC
	ajGraphSetDir
	ajGraphPlpDataSetLineType
	ajGraphxySetXStart
	ajGraphxySetXEnd
	ajGraphxySetYStart
	ajGraphxySetYEnd
	ajGraphPlpDataSetColour
	ajGraphSetYTitle
	ajGraphSetYTitleC
	ajGraphSetXTitle
	ajGraphSetXTitleC
	ajGraphSetTitle
	ajGraphSetTitleC
	ajGraphSetSubTitle
	ajGraphSetSubTitleC
	ajGraphPlpDataSetYTitle
	ajGraphPlpDataSetYTitleC
	ajGraphPlpDataSetXTitle
	ajGraphPlpDataSetXTitleC
	ajGraphxyDel
	ajGraphPlpDataNew
	ajGraphPlpDataSetXY
	ajGraphPlpDataCalcXY
	ajGraphxySetXRangeII
	ajGraphxySetYRangeII
	ajGraphPlpDataNewI
	ajGraphDataAdd
	ajGraphDataReplace
	ajGraphNew
	ajGraphxyNewI
	ajGraphSetMulti
	ajGraphPlpDataSetTitle
	ajGraphPlpDataSetTitleC
	ajGraphPlpDataSetSubTitle
	ajGraphPlpDataSetSubTitleC
	ajGraphSetFlag
	ajGraphxySetOverLap
	ajGraphxySetGaps
	ajGraphxySetXBottom
	ajGraphxySetXTop
	ajGraphxySetYRight
	ajGraphxySetYLeft
	ajGraphxySetXTick
	ajGraphxySetYTick
	ajGraphxySetXLabel
	ajGraphxySetYLabel
	ajGraphSetTitleDo
	ajGraphSetSubTitleDo
	ajGraphxySetCirclePoints
	ajGraphxySetJoinPoints
	ajGraphxySetXLabelTop
	ajGraphxySetYLabelLeft
	ajGraphxySetXInvTicks
	ajGraphxySetYInvTicks
	ajGraphxySetXGrid
	ajGraphxySetYGrid
	ajGraphxySetMaxMin
	ajGraphPlpDataSetMaxMin
	ajGraphArrayMaxMin
	ajGraphPlpDataSetMaxima
	ajGraphPlpDataSetTypeC
	ajGraphxyCheckMaxMin
	ajGraphxyDisplay
	ajGraphAddRect
	ajGraphAddText
	ajGraphAddLine
	ajGraphPlpDataDel
	ajGraphClear
	ajGraphPlpDataAddRect
	ajGraphPlpDataAddText
	ajGraphPlpDataAddLine
	ajGraphPrintType
	ajGraphTextLength
	ajGraphTextHeight
	ajGraphDistPts
	ajGraphSetDefCharSize
	ajGraphFitTextOnLine
	ajGraphPartCircle
	ajComputeCoord
	ajGraphDrawTextOnCurve
	ajGraphRectangleOnCurve
	ajGraphInfo
	ajGraphFillRectangleOnCurve
	ajGraphIsData
	ajGraphUnused
	ajHistDisplay
	ajHistClose
	ajHistDelete
	ajHistNew
	ajHistNewG
	ajHistSetMultiTitle
	ajHistSetMultiTitleC
	ajHistSetMultiXTitle
	ajHistSetMultiXTitleC
	ajHistSetMultiYTitle
	ajHistSetMultiYTitleC
	ajHistSetPtrToData
	ajHistCopyData
	ajHistSetTitleC
	ajHistSetXAxisC
	ajHistSetYAxisLeftC
	ajHistSetYAxisRightC
	ajBtreeCacheNewC
	ajBtreeCacheDel
	ajBtreeCacheRead
	ajBtreeCacheSync
	ajBtreeCacheWrite
	ajBtreeCreateRootNode
	ajBtreeFindInsert
	ajBtreeIdNew
	ajBtreeIdDel
	ajBtreeInsertId
	ajBtreeIdFromKey
	ajBtreeWriteParams
	ajBtreeReadParams
	ajBtreeDeleteId
	ajBtreeWildNew
	ajBtreeWildDel
	ajBtreeKeyWildNew
	ajBtreeKeyWildDel
	ajBtreeFindInsertW
	ajBtreeIdFromKeyW
	ajBtreeListFromKeyW
	ajBtreeReplaceId
	ajBtreeReadEntries
	ajBtreeInsertDupId
	ajBtreeDupFromKey
	ajBtreePriNew
	ajBtreePriDel
	ajBtreeInsertKeyword
	ajBtreePriFromKeyword
	ajBtreeSecCacheNewC
	ajBtreeInsertSecId
	ajBtreeSecFromId
	ajBtreeSecFindInsert
	ajBtreeLockTest
	ajBtreeSecLeafList
	ajBtreeVerifyId
	ajBtreeIdFromKeywordW
	ajBtreeListFromKeywordW
	ajBtreeHybNew
	ajBtreeHybDel
	ajBtreeHybFindInsert
	ajBtreeHybInsertId
	ajBtreeNumFindInsert
	ajBtreeInsertNum
	ajBtreeFreePriArray
	ajBtreeFreeSecArray
	ajBtreeHybLeafList
	ajListNew
	ajListstrNew
	ajListPush
	ajListstrPush
	ajListTrace
	ajListstrTrace
	ajListNewArgs
	ajListstrNewArgs
	ajListNodesNew
	ajListAppend
	ajListPushApp
	ajListstrPushApp
	ajListstrCopy
	ajListCopy
	ajListstrClone
	ajListFirst
	ajListLast
	ajListNth
	ajListPop
	ajListPeek
	ajListstrPop
	ajListstrPeek
	ajListReverse
	ajListstrReverse
	ajListLength
	ajListstrLength
	ajListFree
	ajListstrFree
	ajListDel
	ajListstrDel
	ajListToArray
	ajListstrToArray
	ajListstrToArrayApp
	ajListIter
	ajListIterRead
	ajListIterBack
	ajListIterBackRead
	ajListIterDone
	ajListIterBackDone
	ajListIterFree
	ajListIterMore
	ajListIterBackMore
	ajListIterNext
	ajListIterBackNext
	ajListRemove
	ajListstrRemove
	ajListInsert
	ajListstrInsert
	ajListIterTrace
	ajListstrIterTrace
	ajListPushList
	ajListstrPushList
	ajListPopEnd
	ajListstrPopEnd
	ajListDummyFunction
	ajListExit
	ajRound
	ajRoundF
	ajRecToPol
	ajPolToRec
	ajDegToRad
	ajRadToDeg
	ajGaussProb
	ajGeoMean
	ajPosMod
	ajRandomSeed
	ajRandomNumber
	ajRandomNumberD
	ajSp64Crc
	ajMathPos
	ajMathPosI
	ajMatrixNew
	ajMatrixNewAsym
	ajMatrixfNew
	ajMatrixfNewAsym
	ajMatrixfDel
	ajMatrixDel
	ajMatrixArray
	ajMatrixfArray
	ajMatrixSize
	ajMatrixfSize
	ajMatrixCvt
	ajMatrixfCvt
	ajMatrixChar
	ajMatrixfChar
	ajMatrixName
	ajMatrixfName
	ajMatrixRead
	ajMatrixfRead
	ajMatrixSeqNum
	ajMatrixfSeqNum
	ajMatrixGetCodes
	ajMatrixfGetCodes
	ajMemAlloc
	ajMemCalloc
	ajMemCalloc0
	ajMemFree
	ajMemResize
	ajMemArrB
	ajMemArrI
	ajMemArrF
	ajMemStat
	ajMemExit
	ajMessInvokeDebugger
	ajMessBeep
	ajUser
	ajMessOut
	ajMessDump
	ajMessErrorCount
	ajErr
	ajDie
	ajWarn
	ajMessExitmsg
	ajMessCrashFL
	ajMessCaughtMessage
	ajMessSysErrorText
	ajMessErrorInit
	ajMessSetErr
	ajMessErrorSetFile
	ajMessOutCode
	ajMessErrorCode
	ajMessCrashCodeFL
	ajMessCodesDelete
	ajDebug
	ajDebugFile
	ajUserGet
	ajMessExit
	ajNamPrintDbAttr
	ajNamPrintRsAttr
	ajNamDbDetails
	ajNamListOrigin
	ajNamDebugOrigin
	ajNamListDatabases
	ajNamDebugDatabases
	ajNamDebugResources
	ajNamDebugVariables
	ajNamListListDatabases
	ajNamListListResources
	ajNamVariables
	ajNamIsDbname
	ajNamGetenv
	ajNamGetenvC
	ajNamGetValue
	ajNamGetValueC
	ajNamDatabase
	ajNamInit
	ajNamExit
	ajNamDbTest
	ajNamDbGetUrl
	ajNamDbGetDbalias
	ajNamDbData
	ajNamDbQuery
	ajNamRootInstall
	ajNamRootPack
	ajNamRootVersion
	ajNamRoot
	ajNamRootBase
	ajNamResolve
	ajNamSetControl
	ajNamRsAttrValue
	ajNamRsAttrValueC
	ajNamRsListValue
	ajNexusParse
	ajNexusNew
	ajNexusDel
	ajNexusTrace
	ajNexusGetTaxa
	ajNexusGetNtaxa
	ajNexusGetSequences
	ajPdbtospReadAllRawNew
	ajPdbtospReadNew
	ajPdbtospReadCNew
	ajPdbtospReadAllNew
	ajCmapReadINew
	ajCmapReadCNew
	ajCmapReadAllNew
	ajCmapReadNew
	ajVdwallReadNew
	ajHetReadNew
	ajHetReadRawNew
	ajPdbReadFirstModelNew
	ajPdbReadAllModelsNew
	ajPdbReadNew
	ajPdbReadoldNew
	ajPdbReadoldFirstModelNew
	ajAtomNew
	ajResidueNew
	ajChainNew
	ajPdbNew
	ajHetentNew
	ajHetNew
	ajVdwallNew
	ajVdwresNew
	ajCmapNew
	ajPdbtospNew
	ajAtomDel
	ajResidueDel
	ajChainDel
	ajPdbDel
	ajHetentDel
	ajHetDel
	ajVdwallDel
	ajVdwresDel
	ajCmapDel
	ajPdbtospDel
	ajAtomCopy
	ajResidueCopy
	ajAtomListCopy
	ajResidueListCopy
	ajPdbCopy
	ajResidueSSEnv
	ajResidueEnv1
	ajResidueEnv2
	ajResidueEnv3
	ajResidueEnv4
	ajResidueEnv5
	ajResidueEnv6
	ajResidueEnv7
	ajResidueEnv8
	ajResidueEnv9
	ajResidueEnv10
	ajResidueEnv11
	ajResidueEnv12
	ajResidueEnv13
	ajResidueEnv14
	ajResidueEnv15
	ajResidueEnv16
	ajPdbGetEStrideType
	ajPdbChnidToNum
	ajPdbtospArrFindPdbid
	ajPdbWriteAll
	ajPdbWriteSegment
	ajHetWrite
	ajPdbtospWrite
	ajCmapWrite
	ajPdbWriteDomainRecordRaw
	ajPdbWriteRecordRaw
	ajPdbWriteAllRaw
	ajPdbWriteDomainRaw
	ajPhyloDistNew
	ajPhyloFreqNew
	ajPhyloPropNew
	ajPhyloStateNew
	ajPhyloTreeNew
	ajPhyloDistDel
	ajPhyloFreqDel
	ajPhyloPropDel
	ajPhyloStateDel
	ajPhyloTreeDel
	ajPhyloDistRead
	ajPhyloDistTrace
	ajPhyloFreqRead
	ajPhyloFreqTrace
	ajPhyloPropRead
	ajPhyloPropGetSize
	ajPhyloPropTrace
	ajPhyloStateRead
	ajPhyloStateTrace
	ajPhyloTreeRead
	ajPhyloTreeTrace
	ajRangeNewI
	ajRangeCopy
	ajRangeDel
	ajRangeGet
	ajRangeGetLimits
	ajRangeFile
	ajRangeFileLimits
	ajRangeNumber
	ajRangeValues
	ajRangeText
	ajRangeChange
	ajRangeBegin
	ajRangeSeqExtractList
	ajRangeSeqExtract
	ajRangeSeqStuff
	ajRangeSeqMask
	ajRangeSeqToLower
	ajRangeStrExtractList
	ajRangeStrExtract
	ajRangeStrStuff
	ajRangeStrMask
	ajRangeStrToLower
	ajRangeOverlapSingle
	ajRangeOverlaps
	ajRangeOrdered
	ajRangeDefault
	ajRegComp
	ajRegCompC
	ajRegCompCase
	ajRegCompCaseC
	ajRegExec
	ajRegExecB
	ajRegExecC
	ajRegOffset
	ajRegOffsetI
	ajRegLenI
	ajRegPost
	ajRegPostC
	ajRegPre
	ajRegSubI
	ajRegFree
	ajRegTrace
	ajRegExit
	ajReportDel
	ajReportOpen
	ajReportFormatDefault
	ajReportFindFormat
	ajReportSetTags
	ajReportValid
	ajReportNew
	ajReportWrite
	ajReportClose
	ajReportLists
	ajReportWriteHeader
	ajReportWriteTail
	ajReportSetHeader
	ajReportSetHeaderC
	ajReportSetSubHeader
	ajReportSetSubHeaderC
	ajReportSetTail
	ajReportSetTailC
	ajReportSetSubTail
	ajReportSetSubTailC
	ajReportSetType
	ajReportSeqName
	ajReportFileAdd
	ajReportPrintFormat
	ajReportDummyFunction
	ajReportExit
	ajSeqNew
	ajSeqNewNameC
	ajSeqNewNameS
	ajSeqNewRangeC
	ajSeqNewRangeS
	ajSeqNewRes
	ajSeqNewSeq
	ajSeqAssignAccC
	ajSeqAssignAccS
	ajSeqAssignDescC
	ajSeqAssignDescS
	ajSeqAssignEntryC
	ajSeqAssignEntryS
	ajSeqAssignFileC
	ajSeqAssignFileS
	ajSeqAssignFullC
	ajSeqAssignFullS
	ajSeqAssignGiC
	ajSeqAssignGiS
	ajSeqAssignNameC
	ajSeqAssignNameS
	ajSeqAssignSeqC
	ajSeqAssignSeqLenC
	ajSeqAssignSeqS
	ajSeqAssignSvC
	ajSeqAssignSvS
	ajSeqAssignUfoC
	ajSeqAssignUfoS
	ajSeqAssignUsaC
	ajSeqAssignUsaS
	ajSeqSetOffsets
	ajSeqSetRange
	ajSeqSetRangeRev
	ajSeqComplementOnly
	ajSeqFmtLower
	ajSeqFmtUpper
	ajSeqReverseDo
	ajSeqReverseForce
	ajSeqReverseOnly
	ajSeqGetAccC
	ajSeqGetAccS
	ajSeqGetBegin
	ajSeqGetBeginTrue
	ajSeqGetDescC
	ajSeqGetDescS
	ajSeqGetEnd
	ajSeqGetEndTrue
	ajSeqGetEntryC
	ajSeqGetEntryS
	ajSeqGetFeat
	ajSeqGetFeatCopy
	ajSeqGetGiC
	ajSeqGetGiS
	ajSeqGetLen
	ajSeqGetLenTrue
	ajSeqGetNameC
	ajSeqGetNameS
	ajSeqGetOffend
	ajSeqGetOffset
	ajSeqGetRange
	ajSeqGetRev
	ajSeqGetSeqC
	ajSeqGetSeqS
	ajSeqGetSeqCopyC
	ajSeqGetSeqCopyS
	ajSeqGetSvC
	ajSeqGetSvS
	ajSeqGetTaxC
	ajSeqGetTaxS
	ajSeqGetUsaC
	ajSeqGetUsaS
	ajSeqIsNuc
	ajSeqIsProt
	ajSeqIsReversedTrue
	ajSeqIsReversed
	ajSeqIsTrimmed
	ajSeqCalcCheckgcg
	ajSeqCalcCount
	ajSeqCalcCrc
	ajSeqCalcMolwt
	ajSeqCalcTrueposMin
	ajSeqCalcTruepos
	ajSeqExit
	ajSeqallNew
	ajSeqallDel
	ajSeqallSetRange
	ajSeqallSetRangeRev
	ajSeqallBegin
	ajSeqallEnd
	ajSeqallGetFilename
	ajSeqallLen
	ajSeqallGetName
	ajSeqallGetNameSeq
	ajSeqallGetRange
	ajSeqallGetUsa
	ajSeqsetNew
	ajSeqsetDel
	ajSeqsetDelarray
	ajSeqsetGetFilename
	ajSeqsetGetFormat
	ajSeqsetGetRange
	ajSeqsetGetUsa
	ajSeqsetFill
	ajSeqsetReverse
	ajSeqsetSetRange
	ajSeqsetToLower
	ajSeqsetToUpper
	ajSeqsetTrim
	ajSeqsetAcc
	ajSeqsetBegin
	ajSeqsetEnd
	ajSeqsetLen
	ajSeqsetGetName
	ajSeqsetName
	ajSeqsetSeq
	ajSeqsetGetSeq
	ajSeqsetGetSeqArray
	ajSeqsetSize
	ajSeqsetTotweight
	ajSeqsetWeight
	ajSeqsetIsDna
	ajSeqsetIsNuc
	ajSeqsetIsProt
	ajSeqsetIsRna
	ajSeqDel
	ajSeqClear
	ajSeqallClear
	ajSeqMod
	ajSeqTrace
	ajSeqTraceT
	ajSeqNum
	ajSeqNumS
	ajSeqIsGarbage
	ajSeqCvtTrace
	ajSeqCvtNewZero
	ajSeqCvtNewZeroS
	ajSeqCvtNewZeroSS
	ajSeqCvtNew
	ajSeqCvtDel
	ajSeqCvtNewText
	ajSeqCvtLen
	ajSeqCvtK
	ajSeqCvtKS
	ajSeqCvtKSRow
	ajSeqCvtKSColumn
	ajSeqoutNew
	ajSeqoutNewF
	ajSeqoutDel
	ajSeqTrim
	ajSeqGapCount
	ajSeqGapCountS
	ajSeqGapStandard
	ajSeqGapStandardS
	ajSeqFill
	ajSeqDefName
	ajSeqBaseComp
	ajIsAccession
	ajIsSeqversion
	ajSeqstrReverse
	ajSeqstrComplementOnly
	ajSeqstrCalcMolwt
	ajSeqstrCalcCrc
	ajSeqGarbageOn
	ajSeqGarbageOff
	ajSeqABITest
	ajSeqABIReadSeq
	ajSeqABIMachineName
	ajSeqABIGetNData
	ajSeqABIGetNBase
	ajSeqABIGetData
	ajSeqABIGetBasePosition
	ajSeqABIGetSignal
	ajSeqABIGetBaseSpace
	ajSeqABIGetBaseOffset
	ajSeqABIGetBasePosOffset
	ajSeqABIGetFWO
	ajSeqABIGetPrimerOffset
	ajSeqABIGetPrimerPosition
	ajSeqABIGetTraceOffset
	ajSeqABISampleName
	ajSeqMethodTest
	ajSeqMethod
	ajSeqAccessAsis
	ajSeqAccessFile
	ajSeqAccessOffset
	ajSeqPrintAccess
	ajSeqDbExit
	ajSeqinNew
	ajSeqinDel
	ajSeqinUsa
	ajSeqinSetNuc
	ajSeqinSetProt
	ajSeqinSetRange
	ajSeqAllRead
	ajSeqallFile
	ajSeqallNext
	ajSeqinClearPos
	ajSeqinClear
	ajSeqRead
	ajSeqsetRead
	ajSeqsetallRead
	ajSeqsetFromList
	ajSeqsetFromPair
	ajSeqsetApp
	ajSeqPrintInFormat
	ajSeqFormatTest
	ajSeqQueryNew
	ajSeqQueryDel
	ajSeqQueryClear
	ajSeqQueryWild
	ajSeqQueryStarclear
	ajSeqQueryIs
	ajSeqQueryTrace
	ajSeqParseFasta
	ajSeqParseNcbi
	ajSeqGetFromUsa
	ajSeqsetGetFromUsa
	ajSeqReadExit
	ajSeqinTrace
	ajSeqTypeCheckS
	ajSeqTypeCheckIn
	ajSeqTypeNucS
	ajSeqTypeDnaS
	ajSeqTypeRnaS
	ajSeqTypeGapdnaS
	ajSeqTypeGaprnaS
	ajSeqTypeGapnucS
	ajSeqTypeAnyprotS
	ajSeqTypeProtS
	ajSeqTypeGapanyS
	ajSeqGap
	ajSeqGapLen
	ajSeqGapS
	ajSeqSetNuc
	ajSeqSetProt
	ajSeqsetSetNuc
	ajSeqsetSetProt
	ajSeqType
	ajSeqPrintType
	ajSeqTypeIsProt
	ajSeqTypeIsNuc
	ajSeqTypeIsAny
	ajSeqTypeSummary
	ajSeqTypeExit
	ajSeqAllWrite
	ajSeqsetWrite
	ajSeqWriteClose
	ajSeqWrite
	ajSeqFileNewOut
	ajSeqoutOpen
	ajSeqOutFormatSingle
	ajSeqOutSetFormat
	ajSeqOutSetFormatC
	ajSeqOutFormatDefault
	ajSeqoutUsa
	ajSeqoutClear
	ajSeqPrintOutFormat
	ajSeqFindOutFormat
	ajSeqoutCheckGcg
	ajSeqoutDefName
	ajSeqoutTrace
	ajSeqoutCount
	ajSeqWriteXyz
	ajSssWriteXyz
	ajSeqWriteExit
	ajSortFloatDecI
	ajSortIntDecI
	ajSortFloatIncI
	ajSortIntIncI
	ajSortTwoIntIncI
	ajSortFloatDec
	ajSortIntDec
	ajSortFloatInc
	ajSortIntInc
	ajCharNewC
	ajCharNewS
	ajCharNewRes
	ajCharNewResC
	ajCharNewResS
	ajCharNewResLenC
	ajCharDel
	ajCharFmtLower
	ajCharFmtUpper
	ajCharMatchC
	ajCharMatchCaseC
	ajCharMatchWildC
	ajCharMatchWildS
	ajCharMatchWildNextC
	ajCharMatchWildWordC
	ajCharPrefixC
	ajCharPrefixS
	ajCharPrefixCaseC
	ajCharPrefixCaseS
	ajCharSuffixC
	ajCharSuffixS
	ajCharSuffixCaseC
	ajCharSuffixCaseS
	ajCharCmpCase
	ajCharCmpCaseLen
	ajCharCmpWild
	ajCharParseC
	ajStrNew
	ajStrNewC
	ajStrNewS
	ajStrNewRef
	ajStrNewRes
	ajStrNewResC
	ajStrNewResS
	ajStrNewResLenC
	ajStrDel
	ajStrDelStatic
	ajStrDelarray
	ajStrAssignC
	ajStrAssignK
	ajStrAssignS
	ajStrAssignEmptyC
	ajStrAssignEmptyS
	ajStrAssignLenC
	ajStrAssignRef
	ajStrAssignResC
	ajStrAssignResS
	ajStrAssignSubC
	ajStrAssignSubS
	ajStrAppendC
	ajStrAppendK
	ajStrAppendS
	ajStrAppendCountK
	ajStrAppendLenC
	ajStrAppendSubS
	ajStrInsertC
	ajStrInsertK
	ajStrInsertS
	ajStrJoinC
	ajStrJoinS
	ajStrMask
	ajStrPasteS
	ajStrPasteCountK
	ajStrPasteMaxC
	ajStrPasteMaxS
	ajStrCutComments
	ajStrCutCommentsStart
	ajStrCutEnd
	ajStrCutRange
	ajStrCutStart
	ajStrKeepRange
	ajStrKeepSetC
	ajStrKeepSetAlphaC
	ajStrQuoteStrip
	ajStrQuoteStripAll
	ajStrRemoveGap
	ajStrRemoveHtml
	ajStrRemoveLastNewline
	ajStrRemoveSetC
	ajStrRemoveWhite
	ajStrRemoveWhiteExcess
	ajStrRemoveWild
	ajStrTrimC
	ajStrTrimEndC
	ajStrTrimStartC
	ajStrTrimWhite
	ajStrTrimWhiteEnd
	ajStrTruncateLen
	ajStrTruncatePos
	ajStrExchangeCC
	ajStrExchangeCS
	ajStrExchangeKK
	ajStrExchangeSC
	ajStrExchangeSS
	ajStrExchangeSetCC
	ajStrExchangeSetSS
	ajStrRandom
	ajStrReverse
	ajStrCalcCountC
	ajStrCalcCountK
	ajStrHasParentheses
	ajStrIsAlnum
	ajStrIsAlpha
	ajStrIsBool
	ajStrIsDouble
	ajStrIsFloat
	ajStrIsHex
	ajStrIsInt
	ajStrIsLong
	ajStrIsLower
	ajStrIsNum
	ajStrIsUpper
	ajStrIsWhite
	ajStrIsWild
	ajStrIsWord
	ajStrWhole
	ajStrGetCharFirst
	ajStrGetCharLast
	ajStrGetCharPos
	ajStrGetLen
	ajStrGetPtr
	ajStrGetRes
	ajStrGetRoom
	ajStrGetUse
	ajStrGetValid
	ajStrGetuniquePtr
	ajStrGetuniqueStr
	ajStrSetClear
	ajStrSetRes
	ajStrSetResRound
	ajStrSetValid
	ajStrSetValidLen
	ajStrToBool
	ajStrToDouble
	ajStrToFloat
	ajStrToHex
	ajStrToInt
	ajStrToLong
	ajStrFromBool
	ajStrFromDouble
	ajStrFromDoubleExp
	ajStrFromFloat
	ajStrFromInt
	ajStrFromLong
	ajStrFmtBlock
	ajStrFmtLower
	ajStrFmtLowerSub
	ajStrFmtQuote
	ajStrFmtTitle
	ajStrFmtUpper
	ajStrFmtUpperSub
	ajStrFmtWrap
	ajStrFmtWrapLeft
	ajStrMatchC
	ajStrMatchS
	ajStrMatchCaseC
	ajStrMatchCaseS
	ajStrMatchWildC
	ajStrMatchWildS
	ajStrMatchWildWordC
	ajStrMatchWildWordS
	ajStrMatchWordAllS
	ajStrMatchWordOneS
	ajStrPrefixC
	ajStrPrefixS
	ajStrPrefixCaseC
	ajStrPrefixCaseS
	ajStrSuffixC
	ajStrSuffixS
	ajStrCmpC
	ajStrCmpLenC
	ajStrCmpS
	ajStrCmpCaseS
	ajStrCmpLenS
	ajStrCmpWildC
	ajStrCmpWildS
	ajStrVcmp
	ajStrFindC
	ajStrFindS
	ajStrFindAnyC
	ajStrFindAnyK
	ajStrFindAnyS
	ajStrFindCaseC
	ajStrFindCaseS
	ajStrFindlastC
	ajStrFindlastS
	ajStrExtractFirst
	ajStrExtractWord
	ajStrParseC
	ajStrParseCount
	ajStrParseCountC
	ajStrParseCountS
	ajStrParseCountMultiC
	ajStrParseSplit
	ajStrParseWhite
	ajStrStat
	ajStrTrace
	ajStrTraceFull
	ajStrTraceTitle
	ajStrExit
	ajStrIterNew
	ajStrIterNewBack
	ajStrIterDel
	ajStrIterDone
	ajStrIterDoneBack
	ajStrIterBegin
	ajStrIterEnd
	ajStrIterGetC
	ajStrIterGetK
	ajStrIterPutK
	ajStrIterNext
	ajStrIterNextBack
	ajStrTokenNewC
	ajStrTokenNewS
	ajStrTokenDel
	ajStrTokenAssign
	ajStrTokenAssignC
	ajStrTokenAssignS
	ajStrTokenReset
	ajStrTokenTrace
	ajStrTokenNextFind
	ajStrTokenNextFindC
	ajStrTokenNextParse
	ajStrTokenNextParseC
	ajStrTokenNextParseS
	ajStrTokenRestParse
	ajSysBasename
	ajSysItoC
	ajSysItoUC
	ajSysWhich
	ajSystem
	ajSysUnlink
	ajSysCanon
	ajSysArglist
	ajSysArgListFree
	ajSysFdopen
	ajSysStrdup
	ajSysIsRegular
	ajSysIsDirectory
	ajSysStrtok
	ajSysStrtokR
	ajSysFgets
	ajSysFopen
	ajSysExit
	ajTableGet
	ajTableKey
	ajTableTrace
	ajStrTableTrace
	ajTablePut
	ajTableLength
	ajTableRemove
	ajTableToarray
	ajTableFree
	ajStrTableNewCaseC
	ajStrTableNewCase
	ajStrTableNewC
	ajStrTableNew
	ajStrTableHashCaseC
	ajStrTableHashCase
	ajStrTableHashC
	ajStrTableHash
	ajStrTableCmpCaseC
	ajStrTableCmpCase
	ajStrTableCmpC
	ajStrTableCmp
	ajStrTablePrint
	ajStrTablePrintC
	ajStrTableFree
	ajTableExit
	ajTimeTodayRef
	ajTimeToday
	ajTimeTodayF
	ajTimeTodayRefF
	ajTimeTrace
	ajTimeSet
	ajTimeSetS
	ajTimeLocal
	ajTimeNew
	ajTimeDel
	ajTimeExit
	ajTrnDel
	ajTrnNewC
	ajTrnNewI
	ajTrnNew
	ajTrnReadFile
	ajTrnNewPep
	ajTrnCodon
	ajTrnRevCodon
	ajTrnCodonC
	ajTrnRevCodonC
	ajTrnCodonK
	ajTrnRevCodonK
	ajTrnC
	ajTrnRevC
	ajTrnAltRevC
	ajTrnStr
	ajTrnRevStr
	ajTrnAltRevStr
	ajTrnSeq
	ajTrnRevSeq
	ajTrnAltRevSeq
	ajTrnCFrame
	ajTrnStrFrame
	ajTrnSeqFrame
	ajTrnSeqFramePep
	ajTrnCDangle
	ajTrnStrDangle
	ajTrnSeqOrig
	ajTrnGetTitle
	ajTrnGetFileName
	ajTrnStartStop
	ajTrnStartStopC
	ajTrnName
	ajTrnExit
	ajTreeNew
	ajTreestrNew
	ajTreestrCopy
	ajTreeCopy
	ajTreeLength
	ajTreestrLength
	ajTreeFree
	ajTreestrFree
	ajTreeDel
	ajTreestrDel
	ajTreeToArray
	ajTreestrToArray
	ajTreeDummyFunction
	ajTreeAddData
	ajTreeAddNode
	ajTreeAddSubNode
	ajTreeTrace
	ajTreeExit
	ajExit
	ajExitBad
	ajExitAbort
	ajLogInfo
	ajUtilUid
	ajUtilBigendian
	ajUtilRev2
	ajUtilRev4
	ajUtilRev8
	ajUtilRevShort
	ajUtilRevInt
	ajUtilRevLong
	ajUtilCatch
	aj3dVectorNew
	aj3dVectorCreate
	aj3dVectorDel
	aj3dVectorCrossProduct
	aj3dVectorBetweenPoints
	aj3dVectorLength
	aj3dVectorAngle
	aj3dVectorDihedralAngle
	aj3dVectorDotProduct
	aj3dVectorSum
	ajAcdDebug
	ajAcdDebugIsSet
	ajAcdFilter
	ajAcdGetDiscretestatesI
	ajAcdGetListI
	ajAcdGetSelectI
	ajAcdGetSeqsetallI
	ajAcdGetTreeI
	ajAcdProgram
	ajAcdProgramS
	ajAcdStdout
	ajAcdValue
	ajFeattableSetDna
	ajHistSetBlackandWhite
	ajHistSetColour
	ajHistSetPattern
	ajSeqallReverse
	ajSeqallToLower
	ajSeqallToUpper
	ajSeqAssAcc
	ajSeqAssAccC
	ajSeqAssDesc
	ajSeqAssDescC
	ajSeqAssEntry
	ajSeqAssEntryC
	ajSeqAssFile
	ajSeqAssFull
	ajSeqAssFullC
	ajSeqAssGi
	ajSeqAssGiC
	ajSeqAssName
	ajSeqAssNameC
	ajSeqAssSeq
	ajSeqAssSeqC
	ajSeqAssSeqCI
	ajSeqAssSv
	ajSeqAssSvC
	ajSeqAssUfo
	ajSeqAssUfoC
	ajSeqAssUsa
	ajSeqAssUsaC
	ajSeqBegin
	ajSeqChar
	ajSeqCharCopy
	ajSeqCharCopyL
	ajSeqCheckGcg
	ajSeqCompOnly
	ajSeqCompOnlyStr
	ajSeqCopyFeat
	ajSeqCount
	ajSeqCrc
	ajSeqEnd
	ajSeqGetAcc
	ajSeqGetDesc
	ajSeqGetEntry
	ajSeqGetGi
	ajSeqGetName
	ajSeqGetReverse
	ajSeqGetReversed
	ajSeqGetSv
	ajSeqGetTax
	ajSeqGetUsa
	ajSeqLen
	ajSeqMakeUsa
	ajSeqMakeUsaS
	ajSeqMW
	ajSeqName
	ajSeqNewC
	ajSeqNewL
	ajSeqNewS
	ajSeqNewRange
	ajSeqNewRangeCI
	ajSeqNewStr
	ajSeqOffset
	ajSeqOffend
	ajSeqPos
	ajSeqPosI
	ajSeqPosII
	ajSeqReplace
	ajSeqReplaceC
	ajSeqRev
	ajSeqReverse
	ajSeqReverseStr
	ajSeqRevOnly
	ajSeqSetRangeDir
	ajSeqStr
	ajSeqStrCopy
	ajSeqToLower
	ajSeqToUpper
	ajSeqTrueBegin
	ajSeqTrueEnd
	ajSeqTrueLen
	ajSeqTruePos
	ajSeqTruePosI
	ajSeqTruePosII
	ajCharFree
	ajCharNew
	ajCharNewL
	ajCharNewLS
	ajCharPos
	ajCharToLower
	ajCharToUpper
	ajStrApp
	ajStrAppC
	ajStrAppCI
	ajStrAppK
	ajStrAppKI
	ajStrAppSub
	ajStrArrayDel
	ajStrAss
	ajStrAssC
	ajStrAssCI
	ajStrAssCL
	ajStrAssI
	ajStrAssK
	ajStrAssL
	ajStrAssS
	ajStrAssSub
	ajStrAssSubC
	ajStrBlock
	ajStrChar
	ajStrCheck
	ajStrChomp
	ajStrChompC
	ajStrChompEnd
	ajStrChop
	ajStrClean
	ajStrCleanWhite
	ajStrClear
	ajStrCmpCase
	ajStrCmpCaseCC
	ajStrCmp
	ajStrCmpO
	ajStrCmpWild
	ajStrCmpWildCC
	ajStrConvert
	ajStrConvertCC
	ajStrCopy
	ajStrCopyC
	ajStrCountC
	ajStrCountK
	ajStrCut
	ajStrDegap
	ajStrDelim
	ajStrDelReuse
	ajStrDup
	ajStrFind
	ajStrFindAny
	ajStrFindCase
	ajStrFindK
	ajStrFill
	ajStrFix
	ajStrFixI
	ajStrFixTestI
	ajStrFromDoubleE
	ajStrInsert
	ajStrIsSpace
	ajStrIter
	ajStrIterBack
	ajStrIterBackNext
	ajStrIterFree
	ajStrJoin
	ajStrKeepAlphaC
	ajStrKeepC
	ajStrLen
	ajStrListToArray
	ajStrMatch
	ajStrMatchCase
	ajStrMatchCaseCC
	ajStrMatchCC
	ajStrMatchWild
	ajStrMatchWildCC
	ajStrMatchWildCO
	ajStrMatchWord
	ajStrMatchWordC
	ajStrMatchWordCC
	ajStrMod
	ajStrModL
	ajStrModMinL
	ajStrNCmpC
	ajStrNCmpCaseCC
	ajStrNCmpO
	ajStrNewCIL
	ajStrNewCL
	ajStrNewL
	ajStrNull
	ajStrParentheses
	ajStrPos
	ajStrPosI
	ajStrPosII
	ajStrPrefix
	ajStrPrefixCC
	ajStrPrefixCase
	ajStrPrefixCaseCC
	ajStrPrefixCaseCO
	ajStrPrefixCO
	ajStrQuote
	ajStrReplace
	ajStrReplaceC
	ajStrReplaceK
	ajStrReplaceS
	ajStrRef
	ajStrRemoveCharsC
	ajStrRemoveNewline
	ajStrRev
	ajStrRFindC
	ajStrRoom
	ajStrSet
	ajStrSetC
	ajStrSize
	ajStrStr
	ajStrStrMod
	ajStrSub
	ajStrSubstitute
	ajStrSubstituteCC
	ajStrSubstituteKK
	ajStrSuffix
	ajStrSuffixCC
	ajStrSuffixCO
	ajStrTok
	ajStrTokC
	ajStrTokCC
	ajStrToken
	ajStrTokenAss
	ajStrTokenClear
	ajStrTokenCount
	ajStrTokenCountR
	ajStrTokenInit
	ajStrTokenRest
	ajStrToLower
	ajStrToLowerII
	ajStrToTitle
	ajStrToUpper
	ajStrToUpperII
	ajStrTraceChars
	ajStrTraceT
	ajStrTrim
	ajStrTruncate
	ajStrWildPrefix
	ajStrWrap
	ajStrWrapLeft
	ajStrUncomment
	ajStrUncommentStart
	ajStrYN
	);

# --- list ajAcdGet... methods of EMBOSS for the EXPORT :acd tag

@ACD_METHODS = qw(
	ajAcdGetAlign
	ajAcdGetArray
	ajAcdGetBool
	ajAcdGetCodon
	ajAcdGetCpdb
	ajAcdGetDatafile
	ajAcdGetDirectory
	ajAcdGetDirectoryName
	ajAcdGetDirlist
	ajAcdGetDiscretestates
	ajAcdGetDiscretestatesSingle
	ajAcdGetDistances
	ajAcdGetFeat
	ajAcdGetFeatout
	ajAcdGetFilelist
	ajAcdGetFloat
	ajAcdGetFrequencies
	ajAcdGetGraph
	ajAcdGetGraphxy
	ajAcdGetInfile
	ajAcdGetInt
	ajAcdGetList
	ajAcdGetListSingle
	ajAcdGetMatrix
	ajAcdGetMatrixf
	ajAcdGetOutcodon
	ajAcdGetOutcpdb
	ajAcdGetOutdata
	ajAcdGetOutdir
	ajAcdGetOutdirName
	ajAcdGetOutdiscrete
	ajAcdGetOutdistance
	ajAcdGetOutfile
	ajAcdGetOutfileall
	ajAcdGetOutfreq
	ajAcdGetOutmatrix
	ajAcdGetOutmatrixf
	ajAcdGetOutproperties
	ajAcdGetOutscop
	ajAcdGetOuttree
	ajAcdGetPattern
	ajAcdGetProperties
	ajAcdGetRange
	ajAcdGetRegexp
	ajAcdGetRegexpSingle
	ajAcdGetReport
	ajAcdGetScop
	ajAcdGetSelect
	ajAcdGetSelectSingle
	ajAcdGetSeq
	ajAcdGetSeqall
	ajAcdGetSeqout
	ajAcdGetSeqoutall
	ajAcdGetSeqoutset
	ajAcdGetSeqset
	ajAcdGetSeqsetall
	ajAcdGetSeqsetallSingle
	ajAcdGetString
	ajAcdGetToggle
	ajAcdGetTree
	ajAcdGetTreeSingle
	ajAcdGetValue
	ajAcdGetCmdline
	ajAcdGetInputs
	ajAcdGetProgram
	ajAcdGetDiscretestatesI
	ajAcdGetListI
	ajAcdGetSelectI
	ajAcdGetSeqsetallI
	ajAcdGetTreeI
	);

1;
